--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
----------------------------------------------------------------------
-- The following variable needs to be changed for customization and
-- before running this script.
-- @SCHEMA@ = Collection name
----------------------------------------------------------------------
-- Scriptfile to upgrade schema (tables) in DB2 on iSeries
------------------------------------------------------------------------
-- The code assumes an implicit schema, i.e. the tables
-- and views have to be created in a collection that has
-- the name of the user connected to use the product.
-- You may want to create the collection using:
--     db2 create collection <username>
-- before applying this script
------------------------------------------------------------------------
-- Process this script in the DB2 command line processor
-- example: db2 -tf upgradeSchema612.sql


----------------
-- Drop views --
----------------

DROP VIEW @SCHEMA@.PROCESS_TEMPLATE;

DROP VIEW @SCHEMA@.PROCESS_TEMPL_ATTR;

DROP VIEW @SCHEMA@.PROCESS_INSTANCE;

DROP VIEW @SCHEMA@.PROCESS_ATTRIBUTE;

DROP VIEW @SCHEMA@.ACTIVITY;

DROP VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE;

DROP VIEW @SCHEMA@.EVENT;

DROP VIEW @SCHEMA@.WORK_ITEM;

DROP VIEW @SCHEMA@.ACTIVITY_SERVICE;

DROP VIEW @SCHEMA@.QUERY_PROPERTY;

DROP VIEW @SCHEMA@.QUERY_PROP_TEMPL;

DROP VIEW @SCHEMA@.AUDIT_LOG;

DROP VIEW @SCHEMA@.AUDIT_LOG_B;

DROP VIEW @SCHEMA@.APPLICATION_COMP;

DROP VIEW @SCHEMA@.TASK;

DROP VIEW @SCHEMA@.TASK_TEMPL;

DROP VIEW @SCHEMA@.ESCALATION;

DROP VIEW @SCHEMA@.ESC_TEMPL;

DROP VIEW @SCHEMA@.ESC_TEMPL_DESC;

DROP VIEW @SCHEMA@.TASK_TEMPL_CPROP;

DROP VIEW @SCHEMA@.ESC_TEMPL_CPROP;

DROP VIEW @SCHEMA@.TASK_TEMPL_DESC;

DROP VIEW @SCHEMA@.TASK_CPROP;

DROP VIEW @SCHEMA@.TASK_DESC;

DROP VIEW @SCHEMA@.ESCALATION_CPROP;

DROP VIEW @SCHEMA@.ESCALATION_DESC;

DROP VIEW @SCHEMA@.TASK_AUDIT_LOG;

------------------
-- Drop indexes --
------------------

DROP INDEX @SCHEMA@.SEM_REAS;

DROP INDEX @SCHEMA@.WI_AUTH_S;

DROP INDEX @SCHEMA@.WI_EVERYBODY;

DROP INDEX @SCHEMA@.TI_TI_TT_KND_ST;

DROP INDEX @SCHEMA@.TI_TI_KND_ORIG;

DROP INDEX @SCHEMA@.TI_TI_KND_STRT;

DROP INDEX @SCHEMA@.TI_TI_ORIG_KND;

DROP INDEX @SCHEMA@.TI_TI_KND;

DROP INDEX @SCHEMA@.TI_PAR_KND;

DROP INDEX @SCHEMA@.TI_KND_TOP_TI;

DROP INDEX @SCHEMA@.TI_PRI_ATM_KND;

DROP INDEX @SCHEMA@.COS_PIID;

DROP INDEX @SCHEMA@.CP_COORDHOME;

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( MPTID )
);

CREATE UNIQUE INDEX @SCHEMA@.MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, TARGET_PTID
);

CREATE INDEX @SCHEMA@.MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
);

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_OID                         CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_OID                         CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( MPTID, SOURCE_OID )
);

CREATE INDEX @SCHEMA@.IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
  CGTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  MANDATORY                          SMALLINT                          NOT NULL ,
  CHANGES                            CLOB(3900K)         CCSID 1208    NOT NULL ,
  PRIMARY KEY ( CGTID )
);

CREATE INDEX @SCHEMA@.CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX @SCHEMA@.CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
  CGTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_ATID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  RELATIONSHIP                       INTEGER                           NOT NULL ,
  PRIMARY KEY ( CGTID, SOURCE_ATID )
);

CREATE INDEX @SCHEMA@.CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX @SCHEMA@.CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_CTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_STID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( MPTID, TARGET_CTID )
);

CREATE INDEX @SCHEMA@.MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
  RTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  BEGIN_ATID                         CHAR(16)            FOR BIT DATA           ,
  END_ATID                           CHAR(16)            FOR BIT DATA           ,
  REGION_TYPE                        INTEGER                           NOT NULL ,
  BEGIN_ORDER_NUMBER                 INTEGER                           NOT NULL ,
  PARENT_RTID                        CHAR(16)            FOR BIT DATA           ,
  PRIMARY KEY ( RTID )
);

CREATE INDEX @SCHEMA@.RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
  RTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINED_ATID                     CHAR(16)            FOR BIT DATA  NOT NULL ,
  PTID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( RTID, CONTAINED_ATID )
);

CREATE INDEX @SCHEMA@.RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  PTID
);

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  PROPERTY                           INTEGER                           NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208    NOT NULL ,
  CHANGE_TYPE                        INTEGER                           NOT NULL ,
  SOURCE_PTID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  PRIMARY KEY ( PKID )
);

CREATE UNIQUE INDEX @SCHEMA@.CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  MPTID, PROPERTY, DISPLAY_ID_EXT
);

CREATE INDEX @SCHEMA@.CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
  NAME                               VARCHAR(32)         CCSID 1208    NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  TYPE                               INTEGER                           NOT NULL ,
  VERSION                            INTEGER                           NOT NULL ,
  LAST_UPDATED                       TIMESTAMP                         NOT NULL ,
  PRIMARY_VIEW                       VARCHAR(32)         CCSID 1208             ,
  DEFINITION                         BLOB(1073741823)                  NOT NULL ,
  VV_CFG                             BLOB(1073741823)                           ,
  DV_CFG                             BLOB(1073741823)                           ,
  MV_CFG                             BLOB(1073741823)                           ,
  MT_CFG                             BLOB(1073741823)                           ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( NAME )
);

CREATE INDEX @SCHEMA@.QT_KI ON @SCHEMA@.QUERY_TABLE_T
(   
  KIND
);

CREATE INDEX @SCHEMA@.QT_TY ON @SCHEMA@.QUERY_TABLE_T
(   
  TYPE
);

CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
  REFEREE                            VARCHAR(32)         CCSID 1208    NOT NULL ,
  SOURCE                             VARCHAR(32)         CCSID 1208    NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( REFEREE, SOURCE )
);

CREATE INDEX @SCHEMA@.QTR_SRC ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  SOURCE
);

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
  PIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  MPTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  AIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  STATE                              INTEGER                           NOT NULL ,
  SUB_STATE                          INTEGER                           NOT NULL ,
  STOP_REASON                        INTEGER                           NOT NULL ,
  SOURCE_ATID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_ATID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  MIGRATION_TIME                     TIMESTAMP                         NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PIID, MPTID, AIID )
);

CREATE INDEX @SCHEMA@.MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
  MPTID
);

CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
  SIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  COUNTER                            BIGINT                                     ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SIID )
);

CREATE INDEX @SCHEMA@.SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  PIID
);

CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
  QIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  GROUP_NAME                         VARCHAR(128)        CCSID 1208    NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( QIID, GROUP_NAME )
);

CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
  WSID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  HASH_CODE                          INTEGER                           NOT NULL ,
  OBJECT_TYPE                        INTEGER                           NOT NULL ,
  LAST_CHECK                         TIMESTAMP                         NOT NULL ,
  UNUSED                             SMALLINT                          NOT NULL ,
  AUTH_INFO_RETRIEVED_USER           SMALLINT                          NOT NULL ,
  AUTH_INFO_OWNER_ID                 SMALLINT                          NOT NULL ,
  AUTH_INFO_EVERYBODY                SMALLINT                          NOT NULL ,
  AUTH_INFO_GROUP                    SMALLINT                          NOT NULL ,
  AUTH_INFO_RETRIEVED_GROUP          SMALLINT                          NOT NULL ,
  AUTH_INFO_EMPTY                    SMALLINT                          NOT NULL ,
  SHARING_PATTERN                    INTEGER                           NOT NULL ,
  REASONS                            CHAR(32)            FOR BIT DATA  NOT NULL ,
  PARAMETER_A                        INTEGER                                    ,
  PARAMETER_B                        INTEGER                                    ,
  PARAMETER_C                        INTEGER                                    ,
  PARAMETER_D                        CHAR(16)            FOR BIT DATA           ,
  PARAMETER_E                        TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WSID )
);

CREATE TABLE @SCHEMA@.WIS_EMPTY_T
(
  WIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  WSID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  HASH_CODE                          INTEGER                           NOT NULL ,
  WIS_HASH_CODE                      INTEGER                                    ,
  PARENT_WIID                        CHAR(16)            FOR BIT DATA           ,
  REASON                             INTEGER                           NOT NULL ,
  INHERITED                          SMALLINT                                   ,
  QIID                               CHAR(16)            FOR BIT DATA           ,
  OBJECT_TYPE                        INTEGER                           NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  SHARING_PATTERN                    INTEGER                           NOT NULL ,
  ACCESS_KEY                         INTEGER                           NOT NULL ,
  PARAMETER_A                        INTEGER                                    ,
  PARAMETER_B                        INTEGER                                    ,
  PARAMETER_C                        INTEGER                                    ,
  PARAMETER_D                        CHAR(16)            FOR BIT DATA           ,
  PARAMETER_E                        TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WIID )
);

CREATE TABLE @SCHEMA@.SHARED_WORK_ITEM_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  WIID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PARENT_WIID                        CHAR(16)            FOR BIT DATA           ,
  OWNER_ID                           VARCHAR(128)        CCSID 1208             ,
  GROUP_NAME                         VARCHAR(128)        CCSID 1208             ,
  EVERYBODY                          SMALLINT                          NOT NULL ,
  QIID                               CHAR(16)            FOR BIT DATA           ,
  OBJECT_TYPE                        INTEGER                           NOT NULL ,
  REASON                             INTEGER                           NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  AUTH_INFO                          INTEGER                           NOT NULL ,
  SHARING_PATTERN                    INTEGER                           NOT NULL ,
  ACCESS_KEY                         INTEGER                           NOT NULL ,
  WSID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  HASH_CODE                          INTEGER                           NOT NULL ,
  WIS_HASH_CODE                      INTEGER                                    ,
  INHERITED                          SMALLINT                                   ,
  PARAMETER_A                        INTEGER                                    ,
  PARAMETER_B                        INTEGER                                    ,
  PARAMETER_C                        INTEGER                                    ,
  PARAMETER_D                        CHAR(16)            FOR BIT DATA           ,
  PARAMETER_E                        TIMESTAMP                                  ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
);

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
  CMTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  TKTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  COMPL_CONDITION                    BLOB(3900K)                                ,
  CRITERION_FOR                      VARCHAR(254)        CCSID 1208             ,
  COMPLETION_NAME                    VARCHAR(220)        CCSID 1208             ,
  IS_DEFAULT_COMPLETION              SMALLINT                          NOT NULL ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CMTID )
);

CREATE INDEX @SCHEMA@.CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  TKTID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
  RATID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  CMTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  TKTID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  AGGR_PART                          VARCHAR(254)        CCSID 1208             ,
  AGGR_LOCATION                      BLOB(3900K)                                ,
  AGGR_FUNCTION                      VARCHAR(254)        CCSID 1208    NOT NULL ,
  AGGR_CONDITION                     BLOB(3900K)                                ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  PRIMARY KEY ( RATID )
);

CREATE INDEX @SCHEMA@.RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, ORDER_NUMBER, TKTID
);

CREATE INDEX @SCHEMA@.RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
  PKID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  EVENT                              INTEGER                           NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  PARENT_TKIID                       CHAR(16)            FOR BIT DATA           ,
  ESIID                              CHAR(16)            FOR BIT DATA           ,
  REASON                             INTEGER                           NOT NULL ,
  EVENT_TIME                         TIMESTAMP                         NOT NULL ,
  NEXT_TIME                          TIMESTAMP                                  ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  PRINCIPAL                          VARCHAR(128)        CCSID 1208    NOT NULL ,
  WORK_ITEM_KIND                     INTEGER                           NOT NULL ,
  FROM_ID                            VARCHAR(128)        CCSID 1208             ,
  TO_ID                              VARCHAR(128)        CCSID 1208             ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( PKID )
);

CREATE INDEX @SCHEMA@.TH_TKIID ON @SCHEMA@.TASK_HISTORY_T
(   
  TKIID
);

CREATE INDEX @SCHEMA@.TH_CTXID ON @SCHEMA@.TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
  CMIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  COMPL_CONDITION                    BLOB(3900K)                                ,
  CRITERION_FOR                      VARCHAR(254)        CCSID 1208             ,
  CRITERION_FOR_TIME                 TIMESTAMP                                  ,
  COMPLETION_NAME                    VARCHAR(220)        CCSID 1208             ,
  IS_DEFAULT_COMPLETION              SMALLINT                          NOT NULL ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                          NOT NULL ,
  SCHEDULER_ID                       VARCHAR(254)        CCSID 1208             ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( CMIID )
);

CREATE INDEX @SCHEMA@.CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  TKIID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
  RAIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  ORDER_NUMBER                       INTEGER                           NOT NULL ,
  CMIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  TKIID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  AGGR_PART                          VARCHAR(254)        CCSID 1208             ,
  AGGR_LOCATION                      BLOB(3900K)                                ,
  AGGR_FUNCTION                      VARCHAR(254)        CCSID 1208    NOT NULL ,
  AGGR_CONDITION                     BLOB(3900K)                                ,
  PREFIX_MAP                         BLOB(3900K)                                ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( RAIID )
);

CREATE INDEX @SCHEMA@.RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, ORDER_NUMBER
);

CREATE INDEX @SCHEMA@.RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
  STMID                              CHAR(16)            FOR BIT DATA  NOT NULL ,
  RELATED_OID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  CONTAINMENT_CONTEXT_ID             CHAR(16)            FOR BIT DATA  NOT NULL ,
  KIND                               INTEGER                           NOT NULL ,
  SCHEDULER_ID                       VARCHAR(254)        CCSID 1208             ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  EXPECTED_ARRIVAL_TIME              TIMESTAMP                         NOT NULL ,
  MESSAGE                            BLOB(1073741823)                           ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( STMID )
);

CREATE INDEX @SCHEMA@.STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  RELATED_OID
);

CREATE INDEX @SCHEMA@.STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
);

CREATE INDEX @SCHEMA@.STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
  WBID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  NAME                               VARCHAR(254)        CCSID 1208    NOT NULL ,
  TYPE                               INTEGER                           NOT NULL ,
  OWNER                              VARCHAR(128)        CCSID 1208             ,
  SUBSTITUTION_POLICY                INTEGER                           NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)        CCSID 1208    NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)         CCSID 1208             ,
  CUSTOM_TEXT1                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT2                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT3                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT4                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT5                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT6                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT7                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT8                       VARCHAR(254)        CCSID 1208             ,
  EXTENDED_DATA                      BLOB(3900K)                                ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP                         NOT NULL ,
  CREATED_WITH_VERSION               INTEGER                           NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WBID )
);

CREATE INDEX @SCHEMA@.WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
  NAME
);

CREATE INDEX @SCHEMA@.WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
  TYPE
);

CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
  WBID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  LOCALE                             VARCHAR(32)         CCSID 1208    NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  DISPLAY_NAME                       VARCHAR(64)         CCSID 1208             ,
  DESCRIPTION                        VARCHAR(254)        CCSID 1208             ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( WBID, LOCALE )
);

CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
  SOURCE_WBID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  TARGET_WBID                        CHAR(16)            FOR BIT DATA  NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( SOURCE_WBID, TARGET_WBID )
);

CREATE INDEX @SCHEMA@.WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
);

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
  BCID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  PARENT_BCID                        CHAR(16)            FOR BIT DATA           ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  NAME                               VARCHAR(254)        CCSID 1208    NOT NULL ,
  PRIORITY                           INTEGER                                    ,
  SUBSTITUTION_POLICY                INTEGER                           NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)        CCSID 1208    NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)         CCSID 1208             ,
  CUSTOM_TEXT1                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT2                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT3                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT4                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT5                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT6                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT7                       VARCHAR(254)        CCSID 1208             ,
  CUSTOM_TEXT8                       VARCHAR(254)        CCSID 1208             ,
  EXTENDED_DATA                      BLOB(3900K)                                ,
  CREATION_TIME                      TIMESTAMP                         NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP                         NOT NULL ,
  CREATED_WITH_VERSION               INTEGER                           NOT NULL ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( BCID )
);

CREATE INDEX @SCHEMA@.BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  PARENT_BCID
);

CREATE INDEX @SCHEMA@.BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  NAME
);

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
  BCID                               CHAR(16)            FOR BIT DATA  NOT NULL ,
  LOCALE                             VARCHAR(32)         CCSID 1208    NOT NULL ,
  WSID_1                             CHAR(16)            FOR BIT DATA           ,
  WSID_1_HC                          INTEGER                                    ,
  WSID_2                             CHAR(16)            FOR BIT DATA           ,
  WSID_2_HC                          INTEGER                                    ,
  DISPLAY_NAME                       VARCHAR(64)         CCSID 1208             ,
  DESCRIPTION                        VARCHAR(254)        CCSID 1208             ,
  VERSION_ID                         SMALLINT                          NOT NULL ,
  PRIMARY KEY ( BCID, LOCALE )
);
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    EAR_VERSION                        INTEGER                           DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    IS_IMPLICIT                        SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    HAS_COMPENSATION_HANDLER           SMALLINT                          DEFAULT 1 NOT NULL ;

ALTER TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION                     INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION_NAME                VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION_EXECUTE_AT          INTEGER                           DEFAULT 3 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    SOURCES_TYPE                       INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    TARGETS_TYPE                       INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_EXPRESSION                    CLOB(3900K)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    COMPENSATION_ATID                  CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_IN_GFLOW                        SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_REGION_BEGIN                    SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    CORRESPONDING_IORATID              CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_GFLOW                           SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_EXPRESSION_MAP                BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    GENERATED_BY                       VARCHAR(220)        CCSID 1208   ;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    FAULT_LINK_SOURCE_ATID             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    FAULT_LINK_TARGET_ATID             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    GENERATED_BY                       VARCHAR(220)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    RTID                               CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    GENERATED_BY                       VARCHAR(220)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    SEQUENCE_NUMBER                    INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_VARIABLE_CTID                 CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER2                    VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER3                    BLOB(3900K)                      ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER3_LANGUAGE           INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_EXPRESSION_MAP                BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;

ALTER TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
 ADD 
    STAFF_VERB                         BLOB(3900K)                      ;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    SHARED_PC_ID                       CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    IS_MIGRATED                        SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    CREATED_WITH_VERSION               INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
 ADD 
    HAS_COMPENSATION_WORK              SMALLINT                          DEFAULT 1 NOT NULL ;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    INVOKED_INSTANCE_ID                CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    INVOKED_INSTANCE_TYPE              INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PREVIOUS_STATE                     INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    SUB_STATE                          INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PENDING_REQUEST_DATA               BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    XTID                               CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    EXPIRATION_COUNTER                 INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PREVIOUS_EXPIRATION_DATE           TIMESTAMP                        ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    TARGET_IORAIID                     CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)         CCSID 1208   ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    MAX_COMPENSATION_NUMBER            BIGINT                           ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    HAS_WORK_ITEM                      SMALLINT                         ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    ATID                               CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    COMPENSATE_AIID                    CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.CONFIG_INFO_T
 ADD 
    COUNTER                            BIGINT                           ;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    DATA_TYPE                          VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    "DATA"                             BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.PROCESS_CONTEXT_T
 ADD 
    SHARED                             SMALLINT                         ;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    DATA_TYPE                          VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    "DATA"                             BLOB(1073741823)                 ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
 ADD 
    PIID                               CHAR(16)            FOR BIT DATA ;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.WI_ASSOC_OID_T
 ADD 
    MIGRATED                           SMALLINT                          DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    "NORMALIZED"                       SMALLINT                         ;
ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    DENORMALIZED                       SMALLINT                         ;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    AUTONOMY                           INTEGER                           DEFAULT 1 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    ASSIGNMENT_TYPE                    INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    INHERITED_AUTH                     INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    PARALLEL_INHERITED_AUTH            INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    NATIVE_LOOKUP_NAME                 VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    WORK_BASKET                        VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    EAR_VERSION                        INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    SCHEMA_VERSION                     INTEGER                           DEFAULT 0 NOT NULL ;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    ESCALATION_TIME                    TIMESTAMP                        ;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_CHILD                           SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    HAS_ESCALATIONS                    SMALLINT                         ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    DELETION_TIME                      TIMESTAMP                        ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    ASSIGNMENT_TYPE                    INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INHERITED_AUTH                     INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    PARALLEL_INHERITED_AUTH            INTEGER                           DEFAULT 2 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INVOKED_INSTANCE_ID                CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INVOKED_INSTANCE_TYPE              INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WORK_BASKET                        VARCHAR(254)        CCSID 1208   ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_READ                            SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_TRANSFERRED_TO_WORK_BASKET      SMALLINT                          DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    CREATED_WITH_VERSION               INTEGER                           DEFAULT 0 NOT NULL ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1_HC                          INTEGER                          ;
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_2                             CHAR(16)            FOR BIT DATA ;
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_2_HC                          INTEGER                          ;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER DEFINITION_NAME                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER DISPLAY_NAME                        SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER APPLICATION_NAME                    SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER TARGET_NAMESPACE                    SET DATA TYPE VARCHAR(250)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER VERSION                             SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER ABSTRACT_BASE_NAME                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER S_BEAN_LOOKUP_NAME                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER S_BEAN60_LOOKUP_NAME                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER E_BEAN_LOOKUP_NAME                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER PROCESS_BASE_NAME                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER S_BEAN_HOME_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ALTER E_BEAN_HOME_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
 ALTER ATTR_KEY                            SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
 ALTER VALUE                               SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
 ALTER PORT_TYPE_NAME                      SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
 ALTER OPERATION_NAME                      SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
 ALTER PARTNER_LINK_NAME                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
 ALTER MODULE_NAME                         SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
 ALTER EXPORT_NAME                         SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_LOCATION_TEMPLATE_B_T
 ALTER COMPONENT_NAME                      SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.SERVICE_FAULT_TEMPLATE_B_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER DISPLAY_NAME                        SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER JOIN_CONDITION_NAME                 SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER SCRIPT_NAME                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ALTER EXPRESSION                          SET DATA TYPE CLOB(3900K)          CCSID 1208;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ALTER EXPRESSION_NAME                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ALTER DURATION                            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ALTER CALENDAR                            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ALTER CALENDAR_JNDI_NAME                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ALTER REPEAT_EXP_NAME                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ALTER TRANSITION_CONDITION_NAME           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ALTER EXPRESSION                          SET DATA TYPE CLOB(3900K)          CCSID 1208;

ALTER TABLE @SCHEMA@.VARIABLE_MAPPING_TEMPLATE_B_T
 ALTER PARAMETER                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.VARIABLE_STACK_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_FAULT_TEMPLATE_B_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER PARTNER_LINK_NAME                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER PROCESS_NAME                        SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER TARGET_NAMESPACE                    SET DATA TYPE VARCHAR(250)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER MY_ROLE_LOCALNAME                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER MY_ROLE_NAMESPACE                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER THEIR_ROLE_LOCALNAME                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ALTER THEIR_ROLE_NAMESPACE                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.URI_TEMPLATE_B_T
 ALTER URI                                 SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
 ALTER FROM_PARAMETER2                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
 ALTER TO_PARAMETER2                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
 ALTER PROPERTY_NAME                       SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
 ALTER JAVA_TYPE                           SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
 ALTER MSG_TYPE_NAME                       SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
 ALTER PROPERTY_TYPE_NAME                  SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
 ALTER "PART"                              SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T
 ALTER "QUERY"                             SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER EXPRESSION_NAME                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER DURATION                            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER CALENDAR                            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER CALENDAR_JNDI_NAME                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER REPEAT_EXP_NAME                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER REPEAT_DURATION                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER REPEAT_CALENDAR                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ALTER REPEAT_CALENDAR_JNDI_NAME           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_EXT_TEMPLATE_B_T
 ALTER LOCALNAME                           SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
 ALTER LOCALNAME                           SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_TEMPLATE_B_T
 ALTER PURPOSE                             SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_CELL_MAP_T
 ALTER CELL                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
 ALTER ATTR_KEY                            SET DATA TYPE VARCHAR(192)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
 ALTER ATTR_VALUE                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
 ALTER FOR_EACH_METHOD                     SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
 ALTER SOURCE                              SET DATA TYPE VARCHAR(100)         CCSID 1208;

ALTER TABLE @SCHEMA@.GRAPHICAL_PROCESS_MODEL_T
 ALTER KIND                                SET DATA TYPE VARCHAR(100)         CCSID 1208;

ALTER TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
 ALTER T_QUERY                             SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER PARENT_NAME                         SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER TOP_LEVEL_NAME                      SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER COMPENSATION_SPHERE_NAME            SET DATA TYPE VARCHAR(100)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER STARTER                             SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ALTER SCHEDULER_TASK_ID                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ALTER OWNER                               SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ALTER SCHEDULER_TASK_ID                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.PARTNER_LINK_INSTANCE_B_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CROSSING_LINK_INSTANCE_B_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EVENT_HANDLER_INSTANCE_B_T
 ALTER SCHEDULER_TASK_ID                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
 ALTER PROCESS_NAME                        SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
 ALTER "DATA"                              SET DATA TYPE VARCHAR(3072)        CCSID 1208;

ALTER TABLE @SCHEMA@.CORRELATION_SET_INSTANCE_B_T
 ALTER DATA_LONG                           SET DATA TYPE CLOB(3900K)          CCSID 1208;

ALTER TABLE @SCHEMA@.UNDO_ACTION_B_T
 ALTER PROCESS_NAME                        SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.UNDO_ACTION_B_T
 ALTER CSCOPE_ID                           SET DATA TYPE VARCHAR(100)         CCSID 1208;

ALTER TABLE @SCHEMA@.UNDO_ACTION_B_T
 ALTER UUID                                SET DATA TYPE VARCHAR(100)         CCSID 1208;

ALTER TABLE @SCHEMA@.UNDO_ACTION_B_T
 ALTER PROCESS_ADMIN                       SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
 ALTER LOCALNAME                           SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.CUSTOM_STMT_INSTANCE_B_T
 ALTER PURPOSE                             SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.COMP_WORK_PENDING_B_T
 ALTER CSCOPE_ID                           SET DATA TYPE VARCHAR(100)         CCSID 1208;

ALTER TABLE @SCHEMA@.RESTART_EVENT_B_T
 ALTER PORT_TYPE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.RESTART_EVENT_B_T
 ALTER OPERATION                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.RESTART_EVENT_B_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.CONFIG_INFO_T
 ALTER IDENTIFIER                          SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.CONFIG_INFO_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ALTER ATTR_KEY                            SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ALTER VALUE                               SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ALTER ATTR_KEY                            SET DATA TYPE VARCHAR(189)         CCSID 1208;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ALTER ATTR_VALUE                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
 ALTER TYPE_SYSTEM                         SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER NAME                                SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER OWNER_ID                            SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER SELECT_CLAUSE                       SET DATA TYPE CLOB(20K)            CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER WHERE_CLAUSE                        SET DATA TYPE CLOB(20K)            CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER ORDER_CLAUSE                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER TIMEZONE                            SET DATA TYPE VARCHAR(63)          CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER CREATOR                             SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.STORED_QUERY_T
 ALTER TYPE                                SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ALTER VARIABLE_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ALTER PROPERTY_NAME                       SET DATA TYPE VARCHAR(255)         CCSID 1208;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ALTER PROPERTY_NAMESPACE                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ALTER GENERIC_VALUE                       SET DATA TYPE VARCHAR(512)         CCSID 1208;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ALTER STRING_VALUE                        SET DATA TYPE VARCHAR(512)         CCSID 1208;

ALTER TABLE @SCHEMA@.SYNC_T
 ALTER IDENTIFIER                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.MV_CTR_T
 ALTER SELECT_CLAUSE                       SET DATA TYPE VARCHAR(1024)        CCSID 1208;

ALTER TABLE @SCHEMA@.MV_CTR_T
 ALTER WHERE_CLAUSE                        SET DATA TYPE VARCHAR(1024)        CCSID 1208;

ALTER TABLE @SCHEMA@.MV_CTR_T
 ALTER ORDER_CLAUSE                        SET DATA TYPE VARCHAR(512)         CCSID 1208;

ALTER TABLE @SCHEMA@.MV_CTR_T
 ALTER TBL_SPACE                           SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
 ALTER SCHEDULER_ID                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.SCHEDULER_ACTION_T
 ALTER SCHEDULER_ID                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER VARIABLE_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER PROCESS_TEMPL_NAME                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER PROCESS_INST_NAME                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER TOP_LEVEL_PI_NAME                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER PARENT_PI_NAME                      SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER ACTIVITY_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER CONTROL_LINK_NAME                   SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER IMPL_NAME                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER PRINCIPAL                           SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER TERMINAL_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER EXCEPTION_TEXT                      SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER CORR_SET_INFO                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER USER_NAME                           SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.AUDIT_LOG_T
 ALTER ADDITIONAL_INFO                     SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.WORK_ITEM_T
 ALTER OWNER_ID                            SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.WORK_ITEM_T
 ALTER GROUP_NAME                          SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.RETRIEVED_USER_T
 ALTER OWNER_ID                            SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ALTER GROUP_NAME                          SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ALTER CONTEXT_VALUES                      SET DATA TYPE VARCHAR(3072)        CCSID 1208;

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ALTER CONTEXT_VALUES_LONG                 SET DATA TYPE CLOB(3096K)          CCSID 1208;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ALTER NAME                                SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ALTER CALENDAR_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ALTER JNDI_NAME_CALENDAR                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ALTER JNDI_NAME_STAFF_PROVIDER            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ALTER DURATION_UNTIL_DELETED              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ALTER EVENT_HANDLER_NAME                  SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
 ALTER DURATION_UNTIL_ESCALATION           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_TEMPLATE_T
 ALTER DURATION_UNTIL_REPEATS              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
 ALTER STRING_VALUE                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_CPROP_T
 ALTER DATA_TYPE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
 ALTER DISPLAY_NAME                        SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_TEMPL_LDESC_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
 ALTER MESSAGE_TYPE_NS                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TTASK_MESSAGE_DEFINITION_T
 ALTER MESSAGE_TYPE_NAME                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER DEFINITION_NAME                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER TARGET_NAMESPACE                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER APPLICATION_NAME                    SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER DEFAULT_LOCALE                      SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER CALENDAR_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER DURATION_UNTIL_DELETED              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER DURATION_UNTIL_DUE                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER DURATION_UNTIL_EXPIRES              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER JNDI_NAME_CALENDAR                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER JNDI_NAME_STAFF_PROVIDER            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER TYPE                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER EVENT_HANDLER_NAME                  SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ALTER PRIORITY_DEFINITION                 SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
 ALTER DATA_TYPE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_CPROP_T
 ALTER STRING_VALUE                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
 ALTER DISPLAY_NAME                        SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TEMPL_LDESC_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER SERVICE_REF_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER OPERATION                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER PORT                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER PORT_TYPE_NS                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER PORT_TYPE_NAME                      SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER S_BEAN_JNDI_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TSERVICE_DESCRIPTION_T
 ALTER SERVICE                             SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_CELL_MAP_T
 ALTER CELL                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TMAIL_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.TMAIL_T
 ALTER SUBJECT                             SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TMAIL_T
 ALTER BODY_TEXT                           SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ALTER DURATION_UNTIL_ESCALATION           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ALTER DURATION_UNTIL_REPEATS              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ALTER SCHEDULER_ID                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ALTER STRING_VALUE                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ALTER DATA_TYPE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ALTER DISPLAY_NAME                        SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.EIDOCUMENTATION_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.EIDOCUMENTATION_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER SERVICE_REF_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER OPERATION                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER PORT                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER PORT_TYPE_NS                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER PORT_TYPE_NAME                      SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER S_BEAN_JNDI_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ISERVICE_DESCRIPTION_T
 ALTER SERVICE                             SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER APPLICATION_NAME                    SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER TYPE                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER DEFAULT_LOCALE                      SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER DURATION_UNTIL_DELETED              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER DURATION_UNTIL_DUE                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER DURATION_UNTIL_EXPIRES              SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER CALENDAR_NAME                       SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER JNDI_NAME_CALENDAR                  SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER JNDI_NAME_STAFF_PROVIDER            SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER ORIGINATOR                          SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER STARTER                             SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER OWNER                               SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER SCHEDULER_ID                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER SERVICE_TICKET                      SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ALTER EVENT_HANDLER_NAME                  SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_TIMER_T
 ALTER SCHEDULER_ID                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ALTER NAME                                SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ALTER DATA_TYPE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ALTER STRING_VALUE                        SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ALTER DISPLAY_NAME                        SET DATA TYPE VARCHAR(64)          CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ALTER DESCRIPTION                         SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TIDOCUMENTATION_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.TIDOCUMENTATION_T
 ALTER DOCUMENTATION                       SET DATA TYPE CLOB(4096)           CCSID 1208;

ALTER TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
 ALTER MESSAGE_TYPE_NS                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.ITASK_MESSAGE_DEFINITION_T
 ALTER MESSAGE_TYPE_NAME                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
 ALTER MESSAGE_TYPE_NS                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_MESSAGE_INSTANCE_T
 ALTER MESSAGE_TYPE_NAME                   SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER NAME                                SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER NAMESPACE                           SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER PARENT_TASK_NAME                    SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER PARENT_TASK_NAMESPACE               SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER FAULT_TYPE_NAME                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER FAULT_NAMESPACE                     SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER FAULT_NAME                          SET DATA TYPE VARCHAR(220)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER NEW_USER                            SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER OLD_USER                            SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER PRINCIPAL                           SET DATA TYPE VARCHAR(128)         CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER USERS                               SET DATA TYPE CLOB(8192)           CCSID 1208;

ALTER TABLE @SCHEMA@.TASK_AUDIT_LOG_T
 ALTER DESCRIPTION                         SET DATA TYPE CLOB(8192)           CCSID 1208;

ALTER TABLE @SCHEMA@.IMAIL_T
 ALTER LOCALE                              SET DATA TYPE VARCHAR(32)          CCSID 1208;

ALTER TABLE @SCHEMA@.IMAIL_T
 ALTER SUBJECT                             SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.IMAIL_T
 ALTER URI                                 SET DATA TYPE VARCHAR(254)         CCSID 1208;

ALTER TABLE @SCHEMA@.IMAIL_T
 ALTER BODY_TEXT                           SET DATA TYPE CLOB(4096)           CCSID 1208;



CREATE INDEX @SCHEMA@.PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
);

CREATE INDEX @SCHEMA@.AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
);

CREATE INDEX @SCHEMA@.AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ATID, STATE
);

CREATE INDEX @SCHEMA@.RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  PIID
);

CREATE INDEX @SCHEMA@.PIA_DATY ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
);

CREATE INDEX @SCHEMA@.AIA_DATY ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
);

CREATE INDEX @SCHEMA@.NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  PIID
);

CREATE INDEX @SCHEMA@.AWI_AIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  AIID
);

CREATE INDEX @SCHEMA@.SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, CREATION_TIME
);

CREATE INDEX @SCHEMA@.WI_AUTH_U ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, QIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_O ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OWNER_ID DESC
);

CREATE INDEX @SCHEMA@.WI_AUTH_G ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME
);

CREATE INDEX @SCHEMA@.WI_AUTH_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, EVERYBODY
);

CREATE INDEX @SCHEMA@.WI_AUTH_R ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, REASON DESC
);

CREATE INDEX @SCHEMA@.WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, OBJECT_ID
);

CREATE INDEX @SCHEMA@.WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, QIID
);

CREATE INDEX @SCHEMA@.WI_AUTH_GR_O_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME, OWNER_ID, EVERYBODY
);

CREATE INDEX @SCHEMA@.WIASS_MIG ON @SCHEMA@.WI_ASSOC_OID_T
(   
  MIGRATED, WIID, OBJECT_ID, OBJECT_TYPE, ASSOCIATED_OID, REASON
);

CREATE INDEX @SCHEMA@.TT_NATLOOK_ADHOC ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NATIVE_LOOKUP_NAME, IS_AD_HOC
);

CREATE INDEX @SCHEMA@.TI_ST_KND_TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE, KIND, TKIID, NAME
);

CREATE INDEX @SCHEMA@.TI_TT_KND ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, KIND
);

CREATE INDEX @SCHEMA@.TI_WOBA ON @SCHEMA@.TASK_INSTANCE_T
(   
  WORK_BASKET
);

CREATE INDEX @SCHEMA@.TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
  TYPE
);

-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T;

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID IS NULL OR @SCHEMA@.WORK_ITEM_T.EVERYBODY = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_TYPE, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WI_ASSOC_OID_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.WI_ASSOC_OID_T
 WHERE @SCHEMA@.WORK_ITEM_T.WIID = @SCHEMA@.WI_ASSOC_OID_T.WIID AND (@SCHEMA@.WORK_ITEM_T.QIID IS NULL OR @SCHEMA@.WORK_ITEM_T.EVERYBODY = 1)
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_TYPE, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WI_ASSOC_OID_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T, @SCHEMA@.WI_ASSOC_OID_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND @SCHEMA@.WORK_ITEM_T.WIID = @SCHEMA@.WI_ASSOC_OID_T.WIID;

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T;

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID, @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME, @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME, @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_INSTANCE_T.DUE_TIME, @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC, @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED, @SCHEMA@.TASK_INSTANCE_T.IS_INLINE, @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, @SCHEMA@.TASK_INSTANCE_T.KIND, @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME, @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE, @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER, @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.PRIORITY, @SCHEMA@.TASK_INSTANCE_T.START_TIME, @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION, @SCHEMA@.TASK_INSTANCE_T.IS_CHILD, @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID, @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES, @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.IS_READ, @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2
 FROM @SCHEMA@.TASK_INSTANCE_T;

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME, @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME, @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC, @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND, @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM, @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY, @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH, @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET
 FROM @SCHEMA@.TASK_TEMPLATE_T;

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T;

-- update schema version to: 700
-- (a warning for the following statement can be ignored)
DELETE FROM @SCHEMA@.SCHEMA_VERSION WHERE SCHEMA_VERSION = 700;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 1 );

