--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
-- Scriptfile to create database and schema for Informix
----------------------------------------------------------------------
-- Before running this script, you need to replace all occurences of
-- the replacement variables listed below with values appropriate for
-- your environment. Replacement variables are of the form: @VARIABLE@.
-- 
-- Note: if you do not find any replacement variables in this script 
--       this step might be already completed by a pre-processor.
-- 
-- @DB_NAME@      = name you want to use for your database, for example BPEDB
----------------------------------------------------------------------
-- Run this script using the dbaccess command line processor
--    example:  dbaccess - createDatabase.sql
--

-- create the database
CREATE DATABASE @DB_NAME@ WITH LOG;

-------------------
-- Create tables --
-------------------

CREATE TABLE SCHEMA_VERSION
(
  SCHEMA_VERSION                     INTEGER                       NOT NULL  PRIMARY KEY,
  DATA_MIGRATION                     SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE PROCESS_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  DEFINITION_NAME                    VARCHAR(220)                                       ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  APPLICATION_NAME                   VARCHAR(220)                                       ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  EXECUTION_MODE                     INTEGER                       NOT NULL             ,
  IS_SHARED                          SMALLINT                      NOT NULL             ,
  IS_AD_HOC                          SMALLINT                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  VALID_FROM                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  TARGET_NAMESPACE                   VARCHAR(250)                                       ,
  CREATED                            DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  AUTO_DELETE                        SMALLINT                      NOT NULL             ,
  EXTENDED_AUTO_DELETE               INTEGER                       NOT NULL             ,
  VERSION                            VARCHAR(32)                                        ,
  SCHEMA_VERSION                     INTEGER                       NOT NULL             ,
  ABSTRACT_BASE_NAME                 VARCHAR(254)                                       ,
  S_BEAN_LOOKUP_NAME                 VARCHAR(254)                                       ,
  S_BEAN60_LOOKUP_NAME               VARCHAR(254)                                       ,
  E_BEAN_LOOKUP_NAME                 VARCHAR(254)                                       ,
  PROCESS_BASE_NAME                  VARCHAR(254)                                       ,
  S_BEAN_HOME_NAME                   VARCHAR(254)                                       ,
  E_BEAN_HOME_NAME                   VARCHAR(254)                                       ,
  BPEWS_UTID                         CHAR(24)                                           ,
  WPC_UTID                           CHAR(24)                                           ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  ADMINISTRATOR_QTID                 CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  A_TKTID                            CHAR(24)                                           ,
  A_TKTIDFOR_ACTS                    CHAR(24)                                           ,
  COMPENSATION_SPHERE                INTEGER                       NOT NULL             ,
  AUTONOMY                           INTEGER                       NOT NULL             ,
  CAN_CALL                           SMALLINT                      NOT NULL             ,
  CAN_INITIATE                       SMALLINT                      NOT NULL             ,
  CONTINUE_ON_ERROR                  SMALLINT                      NOT NULL             ,
  IGNORE_MISSING_DATA                INTEGER                       NOT NULL             ,
  EAR_VERSION                        INTEGER                       NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX PTB_NAME_VALID ON PROCESS_TEMPLATE_B_T
(   
  NAME, VALID_FROM
);

CREATE INDEX PTB_NAME_VF_STATE ON PROCESS_TEMPLATE_B_T
(   
  NAME, VALID_FROM, STATE, PTID
);

CREATE INDEX PTB_TOP_APP ON PROCESS_TEMPLATE_B_T
(   
  APPLICATION_NAME
);

CREATE INDEX PTB_STATE_PTID ON PROCESS_TEMPLATE_B_T
(   
  STATE, PTID
);

CREATE INDEX PTB_NAME ON PROCESS_TEMPLATE_B_T
(   
  PTID, NAME
);

CREATE INDEX PTB_SBLKN ON PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
);

CREATE TABLE PROCESS_TEMPLATE_ATTRIBUTE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  ATTR_KEY                           VARCHAR(220)                  NOT NULL             ,
  VALUE                              VARCHAR(254)                                       ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( PTID, ATTR_KEY )
) LOCK MODE ROW;

CREATE INDEX PTAB_PTID ON PROCESS_TEMPLATE_ATTRIBUTE_B_T
(   
  PTID
);

CREATE TABLE SCOPE_TEMPLATE_B_T
(
  STID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_STID                        CHAR(24)                                           ,
  PTID                               CHAR(24)                      NOT NULL             ,
  COMP_HANDLER_ATID                  CHAR(24)                                           ,
  IMPLEMENTS_EHTID                   CHAR(24)                                           ,
  FOR_EACH_ATID                      CHAR(24)                                           ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  ISOLATED                           SMALLINT                      NOT NULL             ,
  IS_COMPENSABLE                     SMALLINT                      NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  A_TKTID                            CHAR(24)                                           ,
  IS_IMPLICIT                        SMALLINT                      NOT NULL             ,
  HAS_COMPENSATION_HANDLER           SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX ST_PTID ON SCOPE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE SERVICE_TEMPLATE_B_T
(
  VTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PORT_TYPE_NAME                     VARCHAR(254)                  NOT NULL             ,
  PORT_TYPE_UTID                     CHAR(24)                      NOT NULL             ,
  OPERATION_NAME                     VARCHAR(254)                  NOT NULL             ,
  NAME                               VARCHAR(254)                                       ,
  PTID                               CHAR(24)                      NOT NULL             ,
  TRANSACTION_BEHAVIOR               INTEGER                       NOT NULL             ,
  IS_TWO_WAY                         SMALLINT                      NOT NULL             ,
  NUMBER_OF_RECEIVE_ACTS             INTEGER                       NOT NULL             
) LOCK MODE ROW;

CREATE INDEX VT_VTID_PTUTID ON SERVICE_TEMPLATE_B_T
(   
  VTID, PORT_TYPE_UTID
);

CREATE INDEX VT_PTID ON SERVICE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE ACTIVITY_SERVICE_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  PARTNER_LINK_NAME                  VARCHAR(220)                                       ,
  INPUT_CTID                         CHAR(24)                                           ,
  OUTPUT_CTID                        CHAR(24)                                           ,
  LINK_ORDER_NUMBER                  INTEGER                                            ,
  POTENTIAL_OWNER_QTID               CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  EDITOR_QTID                        CHAR(24)                                           ,
  TKTID                              CHAR(24)                                           ,
  UNDO_MSG_TEMPLATE                  BYTE                                               ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( ATID, VTID, KIND )
) LOCK MODE ROW;

CREATE INDEX AST_PTID ON ACTIVITY_SERVICE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE SERVICE_LOCATION_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  MODULE_NAME                        VARCHAR(220)                  NOT NULL             ,
  EXPORT_NAME                        TEXT                                               ,
  COMPONENT_NAME                     TEXT                          NOT NULL             ,
  PRIMARY KEY ( PTID, VTID )
) LOCK MODE ROW;

CREATE INDEX SLT_PTID ON SERVICE_LOCATION_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE SERVICE_FAULT_TEMPLATE_B_T
(
  VTID                               CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(220)                  NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  MESSAGE_DEFINITION                 BYTE                          NOT NULL             ,
  PRIMARY KEY ( VTID, FAULT_NAME )
) LOCK MODE ROW;

CREATE INDEX SFT_PTID ON SERVICE_FAULT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE ACTIVITY_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_STID                        CHAR(24)                                           ,
  IMPLEMENTS_STID                    CHAR(24)                                           ,
  PTID                               CHAR(24)                      NOT NULL             ,
  IMPLEMENTS_EHTID                   CHAR(24)                                           ,
  ENCLOSING_FOR_EACH_ATID            CHAR(24)                                           ,
  IS_EVENT_HANDLER_END_ACTIVITY      SMALLINT                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  NAME                               VARCHAR(220)                                       ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  JOIN_CONDITION                     INTEGER                       NOT NULL             ,
  JOIN_CONDITION_NAME                VARCHAR(254)                                       ,
  EXIT_CONDITION                     INTEGER                       NOT NULL             ,
  EXIT_CONDITION_NAME                VARCHAR(254)                                       ,
  EXIT_CONDITION_EXECUTE_AT          INTEGER                       NOT NULL             ,
  NUMBER_OF_LINKS                    INTEGER                       NOT NULL             ,
  SUPPRESS_JOIN_FAILURE              SMALLINT                      NOT NULL             ,
  SOURCES_TYPE                       INTEGER                       NOT NULL             ,
  TARGETS_TYPE                       INTEGER                       NOT NULL             ,
  CREATE_INSTANCE                    SMALLINT                                           ,
  IS_END_ACTIVITY                    SMALLINT                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  HAS_OWN_FAULT_HANDLER              SMALLINT                      NOT NULL             ,
  COMPLEX_BEGIN_ATID                 CHAR(24)                                           ,
  CORRESPONDING_END_ATID             CHAR(24)                                           ,
  PARENT_ATID                        CHAR(24)                                           ,
  HAS_CROSSING_LINK                  SMALLINT                                           ,
  SCRIPT_NAME                        VARCHAR(254)                                       ,
  AFFILIATION                        INTEGER                       NOT NULL             ,
  TRANSACTION_BEHAVIOR               INTEGER                       NOT NULL             ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  FAULT_NAME_UTID                    CHAR(24)                                           ,
  FAULT_VARIABLE_CTID                CHAR(24)                                           ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  IS_TRANSACTIONAL                   SMALLINT                      NOT NULL             ,
  CONTINUE_ON_ERROR                  SMALLINT                      NOT NULL             ,
  ENCLOSED_FTID                      CHAR(24)                                           ,
  EXPRESSION                         TEXT                                               ,
  EXIT_EXPRESSION                    TEXT                                               ,
  HAS_INBOUND_LINK                   SMALLINT                      NOT NULL             ,
  COMPENSATION_STID                  CHAR(24)                                           ,
  COMPENSATION_ATID                  CHAR(24)                                           ,
  A_TKTID                            CHAR(24)                                           ,
  IS_IN_GFLOW                        SMALLINT                      NOT NULL             ,
  IS_REGION_BEGIN                    SMALLINT                      NOT NULL             ,
  CORRESPONDING_IORATID              CHAR(24)                                           ,
  IS_GFLOW                           SMALLINT                      NOT NULL             ,
  CUSTOM_IMPLEMENTATION              BYTE                                               ,
  EXPRESSION_MAP                     BYTE                                               ,
  EXIT_EXPRESSION_MAP                BYTE                                               ,
  GENERATED_BY                       VARCHAR(220)                                       
) LOCK MODE ROW;

CREATE INDEX ATB_PTID ON ACTIVITY_TEMPLATE_B_T
(   
  PTID
);

CREATE INDEX ATB_NAME ON ACTIVITY_TEMPLATE_B_T
(   
  NAME
);

CREATE INDEX ATB_KIND_BR_NAME ON ACTIVITY_TEMPLATE_B_T
(   
  KIND, BUSINESS_RELEVANCE, NAME
);

CREATE TABLE ALARM_TEMPLATE_B_T
(
  XTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  EXPRESSION                         BYTE                                               ,
  EXPRESSION_NAME                    VARCHAR(254)                                       ,
  DURATION                           VARCHAR(254)                                       ,
  CALENDAR                           VARCHAR(254)                                       ,
  CALENDAR_JNDI_NAME                 VARCHAR(254)                                       ,
  REPEAT_KIND                        INTEGER                       NOT NULL             ,
  REPEAT_EXPRESSION                  BYTE                                               ,
  REPEAT_EXP_NAME                    VARCHAR(254)                                       ,
  ON_ALARM_ORDER_NUMBER              INTEGER                                            ,
  EXPRESSION_MAP                     BYTE                                               ,
  REPEAT_EXPRESSION_MAP              BYTE                                               ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) LOCK MODE ROW;

CREATE INDEX XT_PTID ON ALARM_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE FAULT_HANDLER_TEMPLATE_B_T
(
  FTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  CTID                               CHAR(24)                                           ,
  STID                               CHAR(24)                                           ,
  ATID                               CHAR(24)                                           ,
  FAULT_LINK_SOURCE_ATID             CHAR(24)                                           ,
  FAULT_LINK_TARGET_ATID             CHAR(24)                                           ,
  IMPLEMENTATION_ATID                CHAR(24)                      NOT NULL             ,
  FAULT_NAME_UTID                    CHAR(24)                                           ,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) LOCK MODE ROW;

CREATE INDEX FT_PTID ON FAULT_HANDLER_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE LINK_TEMPLATE_B_T
(
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  FLOW_BEGIN_ATID                    CHAR(24)                                           ,
  ENCLOSING_FOR_EACH_ATID            CHAR(24)                                           ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  NAME                               VARCHAR(254)                                       ,
  PTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  LIFETIME                           INTEGER                       NOT NULL             ,
  TRANSITION_CONDITION               INTEGER                       NOT NULL             ,
  TRANSITION_CONDITION_NAME          VARCHAR(254)                                       ,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  SEQUENCE_NUMBER                    INTEGER                       NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  EXPRESSION                         TEXT                                               ,
  IS_INBOUND_LINK                    SMALLINT                      NOT NULL             ,
  OUTBOUND_ATID                      CHAR(24)                                           ,
  EXPRESSION_MAP                     BYTE                                               ,
  GENERATED_BY                       VARCHAR(220)                                       ,
  RTID                               CHAR(24)                                           ,
  PRIMARY KEY ( SOURCE_ATID, TARGET_ATID )
) LOCK MODE ROW;

CREATE INDEX LNK_PTID ON LINK_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE LINK_BOUNDARY_TEMPLATE_B_T
(
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  BOUNDARY_STID                      CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  IS_OUTMOST_BOUNDARY                SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( SOURCE_ATID, TARGET_ATID, BOUNDARY_STID )
) LOCK MODE ROW;

CREATE INDEX BND_PTID ON LINK_BOUNDARY_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE RESET_TEMPLATE_B_T
(
  LOOP_ENTRY_ATID                    CHAR(24)                      NOT NULL             ,
  LOOP_BODY_ATID                     CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PRIMARY KEY ( LOOP_ENTRY_ATID, LOOP_BODY_ATID )
) LOCK MODE ROW;

CREATE INDEX RST_PTID ON RESET_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE VARIABLE_MAPPING_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  SOURCE_CTID                        CHAR(24)                      NOT NULL             ,
  TARGET_CTID                        CHAR(24)                      NOT NULL             ,
  PARAMETER                          VARCHAR(254)                  NOT NULL             ,
  PRIMARY KEY ( PTID, ATID, VTID, SOURCE_CTID, TARGET_CTID )
) LOCK MODE ROW;

CREATE INDEX VMT_TCTID ON VARIABLE_MAPPING_TEMPLATE_B_T
(   
  PTID, ATID, VTID, TARGET_CTID
);

CREATE TABLE VARIABLE_TEMPLATE_B_T
(
  CTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  EHTID                              CHAR(24)                                           ,
  STID                               CHAR(24)                                           ,
  FTID                               CHAR(24)                                           ,
  DERIVED                            SMALLINT                      NOT NULL             ,
  DISPLAY_ID                         INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  FROM_SPEC                          INTEGER                       NOT NULL             ,
  NAME                               VARCHAR(254)                  NOT NULL             ,
  MESSAGE_TEMPLATE                   BYTE                                               ,
  IS_QUERYABLE                       SMALLINT                      NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  GENERATED_BY                       VARCHAR(220)                                       ,
  SEQUENCE_NUMBER                    INTEGER                       NOT NULL             ,
  FROM_VARIABLE_CTID                 CHAR(24)                                           ,
  FROM_PARAMETER2                    VARCHAR(254)                                       ,
  FROM_PARAMETER3                    BYTE                                               ,
  FROM_PARAMETER3_LANGUAGE           INTEGER                       NOT NULL             ,
  FROM_EXPRESSION_MAP                BYTE                                               
) LOCK MODE ROW;

CREATE INDEX CT_PTID ON VARIABLE_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE VARIABLE_STACK_TEMPLATE_B_T
(
  VSID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  CTID                               CHAR(24)                      NOT NULL             ,
  STID                               CHAR(24)                      NOT NULL             ,
  FTID                               CHAR(24)                                           ,
  EHTID                              CHAR(24)                                           ,
  NAME                               LVARCHAR                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX VS_PTID ON VARIABLE_STACK_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE ACTIVITY_FAULT_TEMPLATE_B_T
(
  AFID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                  NOT NULL             ,
  FAULT_UTID                         CHAR(24)                                           ,
  MESSAGE                            BYTE                          NOT NULL             
) LOCK MODE ROW;

CREATE INDEX AF_PTID ON ACTIVITY_FAULT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE PARTNER_LINK_TEMPLATE_B_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  PARTNER_LINK_NAME                  VARCHAR(220)                  NOT NULL             ,
  PROCESS_NAME                       VARCHAR(220)                                       ,
  TARGET_NAMESPACE                   VARCHAR(250)                                       ,
  RESOLUTION_SCOPE                   INTEGER                       NOT NULL             ,
  MY_ROLE                            SMALLINT                      NOT NULL             ,
  MY_ROLE_IMPL                       BYTE                                               ,
  MY_ROLE_LOCALNAME                  VARCHAR(220)                                       ,
  MY_ROLE_NAMESPACE                  VARCHAR(220)                                       ,
  THEIR_ROLE                         SMALLINT                      NOT NULL             ,
  THEIR_ROLE_IMPL                    BYTE                                               ,
  THEIR_ROLE_LOCALNAME               VARCHAR(220)                                       ,
  THEIR_ROLE_NAMESPACE               VARCHAR(220)                                       ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( PTID, PARTNER_LINK_NAME )
) LOCK MODE ROW;

CREATE TABLE URI_TEMPLATE_B_T
(
  UTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  URI                                VARCHAR(220)                  NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX UT_PTID_URI ON URI_TEMPLATE_B_T
(   
  PTID, URI
);

CREATE INDEX UT_UTID_URI ON URI_TEMPLATE_B_T
(   
  UTID, URI
);

CREATE TABLE CLIENT_SETTING_TEMPLATE_B_T
(
  CSID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                                           ,
  PTID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                                           ,
  SETTINGS                           BYTE                                               
) LOCK MODE ROW;

CREATE INDEX CS_PTID ON CLIENT_SETTING_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE ASSIGN_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  FROM_SPEC                          INTEGER                       NOT NULL             ,
  FROM_VARIABLE_CTID                 CHAR(24)                                           ,
  FROM_PARAMETER2                    VARCHAR(254)                                       ,
  FROM_PARAMETER3                    BYTE                                               ,
  FROM_PARAMETER3_LANGUAGE           INTEGER                       NOT NULL             ,
  TO_SPEC                            INTEGER                       NOT NULL             ,
  TO_VARIABLE_CTID                   CHAR(24)                                           ,
  TO_PARAMETER2                      VARCHAR(254)                                       ,
  TO_PARAMETER3                      BYTE                                               ,
  TO_PARAMETER3_LANGUAGE             INTEGER                       NOT NULL             ,
  FROM_EXPRESSION_MAP                BYTE                                               ,
  TO_EXPRESSION_MAP                  BYTE                                               ,
  PRIMARY KEY ( ATID, ORDER_NUMBER )
) LOCK MODE ROW;

CREATE INDEX ASTB_PTID ON ASSIGN_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE CORRELATION_SET_TEMPLATE_B_T
(
  COID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  STID                               CHAR(24)                      NOT NULL             ,
  NAME                               LVARCHAR                      NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) LOCK MODE ROW;

CREATE INDEX CSTB_PTID ON CORRELATION_SET_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE CORRELATION_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  IS_FOR_EVENT_HANDLER               SMALLINT                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  INITIATE                           INTEGER                       NOT NULL             ,
  PATTERN                            INTEGER                       NOT NULL             ,
  PRIMARY KEY ( ATID, VTID, COID, IS_FOR_EVENT_HANDLER )
) LOCK MODE ROW;

CREATE INDEX COID_PTID ON CORRELATION_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE PROPERTY_ALIAS_TEMPLATE_B_T
(
  PAID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  SEQUENCE_NUMBER                    INTEGER                       NOT NULL             ,
  PROPERTY_UTID                      CHAR(24)                      NOT NULL             ,
  PROPERTY_NAME                      LVARCHAR                      NOT NULL             ,
  JAVA_TYPE                          LVARCHAR                      NOT NULL             ,
  MSG_TYPE_UTID                      CHAR(24)                      NOT NULL             ,
  MSG_TYPE_NAME                      LVARCHAR                      NOT NULL             ,
  MSG_TYPE_KIND                      INTEGER                       NOT NULL             ,
  PROPERTY_TYPE_UTID                 CHAR(24)                                           ,
  PROPERTY_TYPE_NAME                 LVARCHAR                                           ,
  PART                               LVARCHAR                                           ,
  QUERY                              LVARCHAR                                           ,
  QUERY_LANGUAGE                     INTEGER                       NOT NULL             ,
  IS_DEFINED_INLINE                  SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX PATB_COID_UTID ON PROPERTY_ALIAS_TEMPLATE_B_T
(   
  COID, MSG_TYPE_UTID
);

CREATE INDEX PATB_PTID_UTIDS ON PROPERTY_ALIAS_TEMPLATE_B_T
(   
  PTID, MSG_TYPE_UTID, PROPERTY_UTID
);

CREATE TABLE EVENT_HANDLER_TEMPLATE_B_T
(
  EHTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  STID                               CHAR(24)                      NOT NULL             ,
  IMPL_ATID                          CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                                           ,
  INPUT_CTID                         CHAR(24)                                           ,
  TKTID                              CHAR(24)                                           ,
  KIND                               INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        
) LOCK MODE ROW;

CREATE INDEX EHT_PTID ON EVENT_HANDLER_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE EHALARM_TEMPLATE_B_T
(
  EHTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  EXPRESSION                         BYTE                                               ,
  EXPRESSION_NAME                    VARCHAR(254)                                       ,
  DURATION                           VARCHAR(254)                                       ,
  CALENDAR                           VARCHAR(254)                                       ,
  CALENDAR_JNDI_NAME                 VARCHAR(254)                                       ,
  REPEAT_KIND                        INTEGER                       NOT NULL             ,
  REPEAT_EXPRESSION                  BYTE                                               ,
  REPEAT_EXP_NAME                    VARCHAR(254)                                       ,
  REPEAT_DURATION                    VARCHAR(254)                                       ,
  REPEAT_CALENDAR                    VARCHAR(254)                                       ,
  REPEAT_CALENDAR_JNDI_NAME          VARCHAR(254)                                       ,
  EXPRESSION_MAP                     BYTE                                               ,
  REPEAT_EXPRESSION_MAP              BYTE                                               
) LOCK MODE ROW;

CREATE INDEX EXT_PTID ON EHALARM_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE CUSTOM_EXT_TEMPLATE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  NAMESPACE                          VARCHAR(220)                  NOT NULL             ,
  LOCALNAME                          VARCHAR(220)                  NOT NULL             ,
  TEMPLATE_INFO                      BYTE                                               ,
  INSTANCE_INFO                      BYTE                                               
) LOCK MODE ROW;

CREATE INDEX CETB_PTID ON CUSTOM_EXT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE CUSTOM_STMT_TEMPLATE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  NAMESPACE                          VARCHAR(220)                  NOT NULL             ,
  LOCALNAME                          VARCHAR(220)                  NOT NULL             ,
  PURPOSE                            VARCHAR(220)                  NOT NULL             ,
  STATEMENT                          BYTE                                               
) LOCK MODE ROW;

CREATE INDEX CST_PTID ON CUSTOM_STMT_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE PROCESS_CELL_MAP_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  CELL                               VARCHAR(220)                  NOT NULL             ,
  PRIMARY KEY ( PTID, CELL )
) LOCK MODE ROW;

CREATE TABLE ACTIVITY_TEMPLATE_ATTR_B_T
(
  ATID                               CHAR(24)                      NOT NULL             ,
  ATTR_KEY                           VARCHAR(192)                  NOT NULL             ,
  ATTR_VALUE                         VARCHAR(254)                                       ,
  PTID                               CHAR(24)                      NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  PRIMARY KEY ( ATID, ATTR_KEY )
) LOCK MODE ROW;

CREATE INDEX ATAB_PTID ON ACTIVITY_TEMPLATE_ATTR_B_T
(   
  PTID
);

CREATE INDEX ATAB_VALUE ON ACTIVITY_TEMPLATE_ATTR_B_T
(   
  ATTR_VALUE
);

CREATE TABLE FOR_EACH_TEMPLATE_B_T
(
  ATID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  COUNTER_CTID                       CHAR(24)                      NOT NULL             ,
  SUCCESSFUL_BRANCHES_ONLY           SMALLINT                      NOT NULL             ,
  START_COUNTER_LANGUAGE             INTEGER                       NOT NULL             ,
  FINAL_COUNTER_LANGUAGE             INTEGER                       NOT NULL             ,
  COMPLETION_CONDITION_LANGUAGE      INTEGER                       NOT NULL             ,
  START_COUNTER_EXPRESSION           BYTE                                               ,
  FINAL_COUNTER_EXPRESSION           BYTE                                               ,
  COMPLETION_COND_EXPRESSION         BYTE                                               ,
  FOR_EACH_METHOD                    VARCHAR(254)                                       ,
  START_COUNTER_EXPRESSION_MAP       BYTE                                               ,
  FINAL_COUNTER_EXPRESSION_MAP       BYTE                                               ,
  COMPLETION_COND_EXPRESSION_MAP     BYTE                                               
) LOCK MODE ROW;

CREATE INDEX FET_PTID ON FOR_EACH_TEMPLATE_B_T
(   
  PTID
);

CREATE TABLE GRAPHICAL_PROCESS_MODEL_T
(
  PTID                               CHAR(24)                      NOT NULL             ,
  SOURCE                             VARCHAR(100)                  NOT NULL             ,
  KIND                               VARCHAR(100)                  NOT NULL             ,
  GRAPHICAL_DATA                     BYTE                                               ,
  ID_MAPPING                         BYTE                                               ,
  PRIMARY KEY ( PTID, SOURCE, KIND )
) LOCK MODE ROW;

CREATE TABLE QUERYABLE_VARIABLE_TEMPLATE_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PAID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  QUERY_TYPE                         INTEGER                       NOT NULL             
) LOCK MODE ROW;

CREATE INDEX QVT_PTID ON QUERYABLE_VARIABLE_TEMPLATE_T
(   
  PTID
);

CREATE TABLE MIGRATION_PLAN_TEMPLATE_T
(
  MPTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  TARGET_PTID                        CHAR(24)                      NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX MPT_PTIDS ON MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, TARGET_PTID
);

CREATE INDEX MPT_TPTID ON MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
);

CREATE TABLE IDMAPPING_TEMPLATE_T
(
  MPTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_OID                         CHAR(24)                      NOT NULL             ,
  TARGET_OID                         CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  PRIMARY KEY ( MPTID, SOURCE_OID )
) LOCK MODE ROW;

CREATE INDEX IDMT_PTID ON IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE CHANGE_GROUP_TEMPLATE_T
(
  CGTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  MPTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  MANDATORY                          SMALLINT                      NOT NULL             ,
  CHANGES                            TEXT                          NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CGT_MT ON CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX CGT_PT ON CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE CHANGE_GROUP_IMPACT_TEMPLATE_T
(
  CGTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  MPTID                              CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  RELATIONSHIP                       INTEGER                       NOT NULL             ,
  PRIMARY KEY ( CGTID, SOURCE_ATID )
) LOCK MODE ROW;

CREATE INDEX CGIT_MT ON CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
);

CREATE INDEX CGIT_PT ON CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE MIGRATION_PLAN_VAR_TEMPLATE_T
(
  MPTID                              CHAR(24)                      NOT NULL             ,
  TARGET_CTID                        CHAR(24)                      NOT NULL             ,
  TARGET_STID                        CHAR(24)                      NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             ,
  PRIMARY KEY ( MPTID, TARGET_CTID )
) LOCK MODE ROW;

CREATE INDEX MPVT_PT ON MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE REGION_TEMPLATE_T
(
  RTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  BEGIN_ATID                         CHAR(24)                                           ,
  END_ATID                           CHAR(24)                                           ,
  REGION_TYPE                        INTEGER                       NOT NULL             ,
  BEGIN_ORDER_NUMBER                 INTEGER                       NOT NULL             ,
  PARENT_RTID                        CHAR(24)                                           
) LOCK MODE ROW;

CREATE INDEX RGT_PTID ON REGION_TEMPLATE_T
(   
  PTID
);

CREATE TABLE REGION_CONTENT_TEMPLATE_T
(
  RTID                               CHAR(24)                      NOT NULL             ,
  CONTAINED_ATID                     CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  PRIMARY KEY ( RTID, CONTAINED_ATID )
) LOCK MODE ROW;

CREATE INDEX RCT_PTID ON REGION_CONTENT_TEMPLATE_T
(   
  PTID
);

CREATE TABLE CHANGE_TEMPLATE_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  MPTID                              CHAR(24)                      NOT NULL             ,
  PROPERTY                           INTEGER                       NOT NULL             ,
  DISPLAY_ID_EXT                     VARCHAR(32)                   NOT NULL             ,
  CHANGE_TYPE                        INTEGER                       NOT NULL             ,
  SOURCE_PTID                        CHAR(24)                      NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX CT_MTPDIS ON CHANGE_TEMPLATE_T
(   
  MPTID, PROPERTY, DISPLAY_ID_EXT
);

CREATE INDEX CGT_PTID ON CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
);

CREATE TABLE STAFF_QUERY_TEMPLATE_T
(
  QTID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ASSOCIATED_OBJECT_TYPE             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                      NOT NULL             ,
  T_QUERY                            VARCHAR(32)                   NOT NULL             ,
  QUERY                              BYTE                          NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  STAFF_VERB                         BYTE                                               
) LOCK MODE ROW;

CREATE INDEX SQT_HASH ON STAFF_QUERY_TEMPLATE_T
(   
  ASSOCIATED_OID, HASH_CODE, T_QUERY, ASSOCIATED_OBJECT_TYPE
);

CREATE TABLE PROCESS_INSTANCE_B_T
(
  PIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  SHARED_PC_ID                       CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  PENDING_REQUEST                    INTEGER                       NOT NULL             ,
  CREATED                            DATETIME YEAR TO FRACTION(3)                       ,
  STARTED                            DATETIME YEAR TO FRACTION(3)                       ,
  COMPLETED                          DATETIME YEAR TO FRACTION(3)                       ,
  LAST_STATE_CHANGE                  DATETIME YEAR TO FRACTION(3)                       ,
  LAST_MODIFIED                      DATETIME YEAR TO FRACTION(3)                       ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  PARENT_NAME                        VARCHAR(220)                                       ,
  TOP_LEVEL_NAME                     VARCHAR(220)                  NOT NULL             ,
  COMPENSATION_SPHERE_NAME           VARCHAR(100)                                       ,
  STARTER                            VARCHAR(128)                                       ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  INPUT_SNID                         CHAR(24)                                           ,
  INPUT_ATID                         CHAR(24)                                           ,
  INPUT_VTID                         CHAR(24)                                           ,
  OUTPUT_SNID                        CHAR(24)                                           ,
  OUTPUT_ATID                        CHAR(24)                                           ,
  OUTPUT_VTID                        CHAR(24)                                           ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  TOP_LEVEL_PIID                     CHAR(24)                      NOT NULL             ,
  PARENT_PIID                        CHAR(24)                                           ,
  PARENT_AIID                        CHAR(24)                                           ,
  TKIID                              CHAR(24)                                           ,
  TERMIN_ON_REC                      SMALLINT                      NOT NULL             ,
  AWAITED_SUB_PROC                   SMALLINT                      NOT NULL             ,
  IS_CREATING                        SMALLINT                      NOT NULL             ,
  PREVIOUS_STATE                     INTEGER                                            ,
  EXECUTING_ISOLATED_SCOPE           SMALLINT                      NOT NULL             ,
  SCHEDULER_TASK_ID                  VARCHAR(254)                                       ,
  RESUMES                            DATETIME YEAR TO FRACTION(3)                       ,
  PENDING_SKIP_REQUEST               SMALLINT                      NOT NULL             ,
  IS_MIGRATED                        SMALLINT                      NOT NULL             ,
  UNHANDLED_EXCEPTION                BYTE                                               ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX PIB_NAME ON PROCESS_INSTANCE_B_T
(   
  NAME
);

CREATE INDEX PIB_TOP ON PROCESS_INSTANCE_B_T
(   
  TOP_LEVEL_PIID
);

CREATE INDEX PIB_PAP ON PROCESS_INSTANCE_B_T
(   
  PARENT_PIID
);

CREATE INDEX PIB_PAR ON PROCESS_INSTANCE_B_T
(   
  PARENT_AIID
);

CREATE INDEX PIB_PTID ON PROCESS_INSTANCE_B_T
(   
  PTID
);

CREATE INDEX PIB_PIID_STATE ON PROCESS_INSTANCE_B_T
(   
  PIID, STATE
);

CREATE INDEX PIB_STATE ON PROCESS_INSTANCE_B_T
(   
  STATE
);

CREATE INDEX PIB_PIID_PTID_STAT ON PROCESS_INSTANCE_B_T
(   
  PIID, PTID, STATE, STARTER, STARTED
);

CREATE TABLE SCOPE_INSTANCE_B_T
(
  SIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_SIID                        CHAR(24)                                           ,
  STID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  ENCLOSING_FEIID                    CHAR(24)                                           ,
  ENCLOSING_FOR_EACH_END_AIID        CHAR(24)                                           ,
  COMPENSATE_AIID                    CHAR(24)                                           ,
  PARENT_COMP_SIID                   CHAR(24)                                           ,
  LAST_COMP_SIID                     CHAR(24)                                           ,
  RUNNING_EVENT_HANDLERS             INTEGER                       NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  NOTIFY_PARENT                      SMALLINT                      NOT NULL             ,
  AWAITED_SCOPES                     INTEGER                       NOT NULL             ,
  AWAITED_SUB_PROCESSES              INTEGER                       NOT NULL             ,
  BPEL_EXCEPTION                     BYTE                                               ,
  IS_ACTIVE                          SMALLINT                      NOT NULL             ,
  INITIATED_COMP                     SMALLINT                      NOT NULL             ,
  IS_TERMINATION_FROM_FOR_EACH       SMALLINT                      NOT NULL             ,
  TOTAL_COMPL_NUMBER                 INT8                          NOT NULL             ,
  SCOPE_COMPL_NUMBER                 INT8                          NOT NULL             ,
  A_TKIID                            CHAR(24)                                           ,
  HAS_COMPENSATION_WORK              SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SI_PI_ST_EH_STA_FE ON SCOPE_INSTANCE_B_T
(   
  PIID, STID, STATE, EHIID, ENCLOSING_FEIID
);

CREATE INDEX SI_PI_ST_EH_ACT_FE ON SCOPE_INSTANCE_B_T
(   
  PIID, STID, IS_ACTIVE, EHIID, ENCLOSING_FEIID
);

CREATE INDEX SI_PIID_PARSI ON SCOPE_INSTANCE_B_T
(   
  PIID, PARENT_SIID, IS_ACTIVE
);

CREATE INDEX SI_PARCOMP_STA_ST ON SCOPE_INSTANCE_B_T
(   
  PARENT_COMP_SIID, STATE, STID
);

CREATE INDEX SI_PIID_STATE ON SCOPE_INSTANCE_B_T
(   
  PIID, STATE
);

CREATE INDEX SI_LAST_COMPSIID ON SCOPE_INSTANCE_B_T
(   
  LAST_COMP_SIID
);

CREATE TABLE ACTIVITY_INSTANCE_B_T
(
  AIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  ATID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                                           ,
  PIID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  ENCLOSING_FEIID                    CHAR(24)                                           ,
  P_TKIID                            CHAR(24)                                           ,
  A_TKIID                            CHAR(24)                                           ,
  INVOKED_INSTANCE_ID                CHAR(24)                                           ,
  INVOKED_INSTANCE_TYPE              INTEGER                       NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  TRANS_COND_VALUES                  CHAR(88)                      NOT NULL             ,
  NUMBER_LINKS_EVALUATED             INTEGER                       NOT NULL             ,
  FINISHED                           DATETIME YEAR TO FRACTION(3)                       ,
  ACTIVATED                          DATETIME YEAR TO FRACTION(3)                       ,
  FIRST_ACTIVATED                    DATETIME YEAR TO FRACTION(3)                       ,
  STARTED                            DATETIME YEAR TO FRACTION(3)                       ,
  LAST_MODIFIED                      DATETIME YEAR TO FRACTION(3)                       ,
  LAST_STATE_CHANGE                  DATETIME YEAR TO FRACTION(3)                       ,
  OWNER                              VARCHAR(128)                                       ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  LINK_ORDER_NUMBER                  INTEGER                                            ,
  SCHEDULER_TASK_ID                  VARCHAR(254)                                       ,
  EXPIRES                            DATETIME YEAR TO FRACTION(3)                       ,
  CONTINUE_ON_ERROR                  SMALLINT                      NOT NULL             ,
  UNHANDLED_EXCEPTION                BYTE                                               ,
  STOP_REASON                        INTEGER                       NOT NULL             ,
  PREVIOUS_STATE                     INTEGER                                            ,
  INVOCATION_COUNTER                 INTEGER                       NOT NULL             ,
  FOR_EACH_START_COUNTER_VALUE       INT8                                               ,
  FOR_EACH_FINAL_COUNTER_VALUE       INT8                                               ,
  FOR_EACH_CURRENT_COUNTER_VALUE     INT8                                               ,
  FOR_EACH_COMPLETED_BRANCHES        INT8                                               ,
  FOR_EACH_FAILED_BRANCHES           INT8                                               ,
  FOR_EACH_MAX_COMPL_BRANCHES        INT8                                               ,
  FOR_EACH_AWAITED_BRANCHES          INT8                                               ,
  IS51_ACTIVITY                      SMALLINT                      NOT NULL             ,
  MAY_HAVE_SUBPROCESS                SMALLINT                                           ,
  SKIP_REQUESTED                     SMALLINT                      NOT NULL             ,
  JUMP_TARGET_ATID                   CHAR(24)                                           ,
  SUB_STATE                          INTEGER                       NOT NULL             ,
  PENDING_REQUEST_DATA               BYTE                                               ,
  XTID                               CHAR(24)                                           ,
  EXPIRATION_COUNTER                 INTEGER                                            ,
  PREVIOUS_EXPIRATION_DATE           DATETIME YEAR TO FRACTION(3)                       ,
  TARGET_IORAIID                     CHAR(24)                                           ,
  DISPLAY_ID_EXT                     VARCHAR(32)                                        ,
  MAX_COMPENSATION_NUMBER            INT8                                               ,
  HAS_WORK_ITEM                      SMALLINT                                           ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX AIB_PI_ATID_EH_FE ON ACTIVITY_INSTANCE_B_T
(   
  PIID, ATID, EHIID, ENCLOSING_FEIID
);

CREATE INDEX AIB_PI_DIS_EH_FE ON ACTIVITY_INSTANCE_B_T
(   
  PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
);

CREATE INDEX AIB_PTID ON ACTIVITY_INSTANCE_B_T
(   
  PTID
);

CREATE INDEX AIB_PIID_STAT_AIID ON ACTIVITY_INSTANCE_B_T
(   
  PIID, STATE, AIID, ACTIVATED
);

CREATE INDEX AIB_AI_AT_STAT_PI ON ACTIVITY_INSTANCE_B_T
(   
  AIID, ATID, STATE, PIID, OWNER, ACTIVATED
);

CREATE INDEX AIB_SIID ON ACTIVITY_INSTANCE_B_T
(   
  SIID
);

CREATE INDEX AIB_ATID_STAT ON ACTIVITY_INSTANCE_B_T
(   
  ATID, STATE
);

CREATE TABLE VARIABLE_INSTANCE_B_T
(
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( CTID, PIID )
) LOCK MODE ROW;

CREATE INDEX CI_PIID ON VARIABLE_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE SCOPED_VARIABLE_INSTANCE_B_T
(
  SVIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  DATA                               BYTE                                               ,
  IS_ACTIVE                          SMALLINT                      NOT NULL             ,
  IS_INITIALIZED                     SMALLINT                      NOT NULL             ,
  IS_QUERYABLE                       SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SVI_PI_CT_EH_FE ON SCOPED_VARIABLE_INSTANCE_B_T
(   
  PIID, CTID, IS_ACTIVE, EHIID, FEIID
);

CREATE INDEX SVI_CT_SI_EH_AC ON SCOPED_VARIABLE_INSTANCE_B_T
(   
  SIID, CTID, IS_ACTIVE, EHIID
);

CREATE TABLE STAFF_MESSAGE_INSTANCE_B_T
(
  AIID                               CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( AIID, KIND )
) LOCK MODE ROW;

CREATE INDEX SMI_PIID ON STAFF_MESSAGE_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE EVENT_INSTANCE_B_T
(
  EIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  IS_TWO_WAY                         SMALLINT                      NOT NULL             ,
  IS_PRIMARY_EVENT_INSTANCE          SMALLINT                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  AIID                               CHAR(24)                                           ,
  EHTID                              CHAR(24)                                           ,
  SIID                               CHAR(24)                                           ,
  TKIID                              CHAR(24)                                           ,
  NEXT_POSTED_EVENT                  CHAR(24)                                           ,
  LAST_POSTED_EVENT                  CHAR(24)                                           ,
  POST_COUNT                         INTEGER                       NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  MESSAGE                            BYTE                                               ,
  REPLY_CONTEXT                      BYTE                                               ,
  POST_TIME                          DATETIME YEAR TO FRACTION(3)                       ,
  MAX_NUMBER_OF_POSTS                INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX EI_PIID_PRIM ON EVENT_INSTANCE_B_T
(   
  PIID, IS_PRIMARY_EVENT_INSTANCE, STATE
);

CREATE INDEX EI_PIID_VTID ON EVENT_INSTANCE_B_T
(   
  PIID, VTID, IS_PRIMARY_EVENT_INSTANCE
);

CREATE INDEX EI_AIID ON EVENT_INSTANCE_B_T
(   
  AIID
);

CREATE INDEX EI_STATE_VTID ON EVENT_INSTANCE_B_T
(   
  VTID, STATE, EIID, AIID, PIID
);

CREATE TABLE REQUEST_INSTANCE_B_T
(
  RIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  VTID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  TKIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  INSTANTIATING                      SMALLINT                      NOT NULL             ,
  REPLY_CONTEXT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX RI_PIID_VTID_EHIID ON REQUEST_INSTANCE_B_T
(   
  PIID, VTID
);

CREATE TABLE PARTNER_LINK_INSTANCE_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  ENDPOINT_REFERENCE                 BYTE                                               ,
  SERVICE_DEFINITION                 BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, NAME )
) LOCK MODE ROW;

CREATE INDEX PA_PIID ON PARTNER_LINK_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE VARIABLE_SNAPSHOT_B_T
(
  SNID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  COPY_VERSION                       SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SN_PIID_CTID ON VARIABLE_SNAPSHOT_B_T
(   
  PIID, CTID
);

CREATE TABLE SUSPENDED_MESSAGE_INSTANCE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  ENGINE_MESSAGE                     BYTE                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX PIID ON SUSPENDED_MESSAGE_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE CROSSING_LINK_INSTANCE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  CONDITION_VALUE                    INTEGER                       NOT NULL             ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CL_PI_TAT_EH_FE_SA ON CROSSING_LINK_INSTANCE_B_T
(   
  PIID, TARGET_ATID, EHIID, FEIID, SOURCE_ATID
);

CREATE TABLE INVOKE_RESULT_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  INVOKE_RESULT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, ATID )
) LOCK MODE ROW;

CREATE TABLE INVOKE_RESULT2_B_T
(
  IRID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  INVOKE_RESULT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX IR2_PI_AT_EH_FE ON INVOKE_RESULT2_B_T
(   
  PIID, ATID, EHIID, FEIID
);

CREATE TABLE EVENT_HANDLER_INSTANCE_B_T
(
  EHIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  EHTID                              CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  PARENT_EHIID                       CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  SCHEDULER_TASK_ID                  VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX EHI_PIID_EHTID ON EVENT_HANDLER_INSTANCE_B_T
(   
  PIID, EHTID
);

CREATE INDEX EHI_SIID_EHTID ON EVENT_HANDLER_INSTANCE_B_T
(   
  SIID, EHTID
);

CREATE TABLE CORRELATION_SET_INSTANCE_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  PROCESS_NAME                       VARCHAR(220)                  NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  STATUS                             INTEGER                       NOT NULL             ,
  HASH_CODE                          CHAR(24)                      NOT NULL             ,
  DATA                               TEXT                                               ,
  DATA_LONG                          TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, COID, SIID )
) LOCK MODE ROW;

CREATE UNIQUE INDEX CSIB_HASH_PN ON CORRELATION_SET_INSTANCE_B_T
(   
  HASH_CODE, PROCESS_NAME
);

CREATE INDEX CSIB_PIID ON CORRELATION_SET_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE CORRELATION_SET_PROPERTIES_B_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  COID                               CHAR(24)                      NOT NULL             ,
  SIID                               CHAR(24)                      NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, COID, SIID )
) LOCK MODE ROW;

CREATE TABLE UNDO_ACTION_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  PARENT_ATID                        CHAR(24)                                           ,
  PARENT_PIID                        CHAR(24)                                           ,
  PARENT_AIID                        CHAR(24)                                           ,
  PARENT_EHIID                       CHAR(24)                                           ,
  PARENT_FEIID                       CHAR(24)                                           ,
  PROCESS_NAME                       VARCHAR(220)                  NOT NULL             ,
  CSCOPE_ID                          VARCHAR(100)                  NOT NULL             ,
  UUID                               VARCHAR(100)                  NOT NULL             ,
  COMP_CREATION_TIME                 DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  DO_OP_WAS_TXNAL                    SMALLINT                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  INPUT_DATA                         BYTE                          NOT NULL             ,
  FAULT_DATA                         BYTE                                               ,
  CREATED                            INTEGER                       NOT NULL             ,
  PROCESS_ADMIN                      VARCHAR(128)                  NOT NULL             ,
  IS_VISIBLE                         SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX UA_CSID_DOOP_UUID ON UNDO_ACTION_B_T
(   
  CSCOPE_ID, DO_OP_WAS_TXNAL, UUID
);

CREATE INDEX UA_CSID_STATE_CCT ON UNDO_ACTION_B_T
(   
  CSCOPE_ID, STATE, UUID
);

CREATE INDEX UA_STATE_ISV ON UNDO_ACTION_B_T
(   
  STATE, IS_VISIBLE
);

CREATE INDEX UA_AIID_STATE_UUID ON UNDO_ACTION_B_T
(   
  PARENT_AIID, STATE, UUID
);

CREATE INDEX UA_PIID ON UNDO_ACTION_B_T
(   
  PARENT_PIID
);

CREATE INDEX UA_PT_AT_CS_UU_CCT ON UNDO_ACTION_B_T
(   
  PTID, ATID, CSCOPE_ID, UUID, COMP_CREATION_TIME
);

CREATE TABLE CUSTOM_STMT_INSTANCE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  SVIID                              CHAR(24)                                           ,
  NAMESPACE                          VARCHAR(220)                  NOT NULL             ,
  LOCALNAME                          VARCHAR(220)                  NOT NULL             ,
  PURPOSE                            VARCHAR(220)                  NOT NULL             ,
  STATEMENT                          BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CSI_PIID_NS ON CUSTOM_STMT_INSTANCE_B_T
(   
  PIID, NAMESPACE
);

CREATE INDEX CSI_SVIID_NS ON CUSTOM_STMT_INSTANCE_B_T
(   
  SVIID, NAMESPACE
);

CREATE TABLE COMP_WORK_PENDING_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_PIID                        CHAR(24)                      NOT NULL             ,
  PARENT_ATID                        CHAR(24)                      NOT NULL             ,
  PARENT_EHIID                       CHAR(24)                                           ,
  PARENT_FEIID                       CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  CSCOPE_ID                          VARCHAR(100)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CWP_PI_AT_CS_EH_FE ON COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, PARENT_ATID, CSCOPE_ID, PARENT_EHIID, PARENT_FEIID
);

CREATE INDEX CWP_PI_AT_EHI ON COMP_WORK_PENDING_B_T
(   
  PARENT_PIID, PARENT_ATID, PARENT_EHIID
);

CREATE TABLE COMP_PARENT_ACTIVITY_INST_B_T
(
  AIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  SIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                                           ,
  PIID                               CHAR(24)                      NOT NULL             ,
  COMPLETION_NUMBER                  INT8                          NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  COMPENSATE_AIID                    CHAR(24)                                           ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CPAI_SI_S_CN_AI_PI ON COMP_PARENT_ACTIVITY_INST_B_T
(   
  SIID, STATE, COMPLETION_NUMBER, AIID, PIID
);

CREATE INDEX CPAI_PIID ON COMP_PARENT_ACTIVITY_INST_B_T
(   
  PIID
);

CREATE TABLE RESTART_EVENT_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  PORT_TYPE                          VARCHAR(254)                  NOT NULL             ,
  OPERATION                          VARCHAR(254)                  NOT NULL             ,
  NAMESPACE                          VARCHAR(254)                  NOT NULL             ,
  INPUT_MESSAGE                      BYTE                                               ,
  REPLY_CTX                          BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX REB_PIID ON RESTART_EVENT_B_T
(   
  PIID
);

CREATE TABLE PROGRESS_COUNTER_T
(
  PIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  COUNTER                            INT8                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE RELEVANT_SCOPE_ATASK_T
(
  SIID                               CHAR(24)                      NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( SIID, TKIID )
) LOCK MODE ROW;

CREATE INDEX RSAT_PIID ON RELEVANT_SCOPE_ATASK_T
(   
  PIID
);

CREATE TABLE CONFIG_INFO_T
(
  IDENTIFIER                         VARCHAR(64)                   NOT NULL  PRIMARY KEY,
  DESCRIPTION                        VARCHAR(128)                                       ,
  PROPERTY                           INTEGER                                            ,
  COUNTER                            INT8                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE PROCESS_INSTANCE_ATTRIBUTE_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  ATTR_KEY                           VARCHAR(220)                  NOT NULL             ,
  VALUE                              VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, ATTR_KEY )
) LOCK MODE ROW;

CREATE INDEX PIA_VALUE ON PROCESS_INSTANCE_ATTRIBUTE_T
(   
  VALUE
);

CREATE INDEX PIA_DATY ON PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
);

CREATE TABLE PROCESS_CONTEXT_T
(
  PIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  SHARED                             SMALLINT                                           ,
  REPLY_CONTEXT                      BYTE                                               ,
  SERVICE_CONTEXT                    BYTE                                               ,
  STARTER_EXPIRES                    DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE ACTIVITY_INSTANCE_ATTR_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  ATID                               CHAR(24)                      NOT NULL             ,
  EHIID                              CHAR(24)                                           ,
  FEIID                              CHAR(24)                                           ,
  AIID                               CHAR(24)                                           ,
  ATTR_KEY                           VARCHAR(189)                  NOT NULL             ,
  ATTR_VALUE                         VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX AIA_UNIQUE ON ACTIVITY_INSTANCE_ATTR_B_T
(   
  PIID, ATID, EHIID, FEIID, ATTR_KEY
);

CREATE INDEX AIA_AIID ON ACTIVITY_INSTANCE_ATTR_B_T
(   
  AIID
);

CREATE INDEX AIA_VALUE ON ACTIVITY_INSTANCE_ATTR_B_T
(   
  ATTR_VALUE
);

CREATE INDEX AIA_DATY ON ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
);

CREATE TABLE NAVIGATION_EXCEPTION_T
(
  CORRELATION_ID                     CHAR(296)                     NOT NULL             ,
  EXCEPTION_TYPE                     INTEGER                       NOT NULL             ,
  PIID                               CHAR(24)                                           ,
  OUTPUT_MESSAGE                     BYTE                                               ,
  TYPE_SYSTEM                        VARCHAR(32)                                        ,
  PROCESS_EXCEPTION                  BYTE                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( CORRELATION_ID, EXCEPTION_TYPE )
) LOCK MODE ROW;

CREATE INDEX NE_PIID ON NAVIGATION_EXCEPTION_T
(   
  PIID
);

CREATE TABLE AWAITED_INVOCATION_T
(
  CORRELATION_ID                     CHAR(340)                     NOT NULL  PRIMARY KEY,
  CORRELATION_INFO                   BYTE                          NOT NULL             ,
  AIID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX AWI_PIID ON AWAITED_INVOCATION_T
(   
  PIID
);

CREATE INDEX AWI_AIID ON AWAITED_INVOCATION_T
(   
  AIID
);

CREATE TABLE STORED_QUERY_T
(
  SQID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  KIND                               INTEGER                       NOT NULL             ,
  NAME                               VARCHAR(64)                   NOT NULL             ,
  OWNER_ID                           VARCHAR(128)                  NOT NULL             ,
  SELECT_CLAUSE                      TEXT                          NOT NULL             ,
  WHERE_CLAUSE                       TEXT                                               ,
  ORDER_CLAUSE                       VARCHAR(254)                                       ,
  THRESHOLD                          INTEGER                                            ,
  TIMEZONE                           VARCHAR(63)                                        ,
  CREATOR                            VARCHAR(128)                                       ,
  TYPE                               VARCHAR(128)                                       ,
  PROPERTY                           BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX SQ_NAME ON STORED_QUERY_T
(   
  KIND, OWNER_ID, NAME
);

CREATE TABLE FOR_EACH_INSTANCE_B_T
(
  FEIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_FEIID                       CHAR(24)                                           ,
  PIID                               CHAR(24)                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX FEI_PIID ON FOR_EACH_INSTANCE_B_T
(   
  PIID
);

CREATE TABLE QUERYABLE_VARIABLE_INSTANCE_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  CTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                      NOT NULL             ,
  PAID                               CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VARIABLE_NAME                      VARCHAR(254)                  NOT NULL             ,
  PROPERTY_NAME                      LVARCHAR                      NOT NULL             ,
  PROPERTY_NAMESPACE                 VARCHAR(254)                  NOT NULL             ,
  TYPE                               INTEGER                       NOT NULL             ,
  GENERIC_VALUE                      LVARCHAR                                           ,
  STRING_VALUE                       LVARCHAR                                           ,
  NUMBER_VALUE                       INT8                                               ,
  DECIMAL_VALUE                      DOUBLE PRECISION                                   ,
  TIMESTAMP_VALUE                    DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX QVI_PI_CT_PA ON QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, CTID, PAID
);

CREATE INDEX QVI_PI_NUM ON QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, NUMBER_VALUE
);

CREATE INDEX QVI_PI_DEC ON QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, DECIMAL_VALUE
);

CREATE INDEX QVI_PI_TIME ON QUERYABLE_VARIABLE_INSTANCE_T
(   
  PIID, TIMESTAMP_VALUE
);

CREATE TABLE SYNC_T
(
  IDENTIFIER                         VARCHAR(254)                  NOT NULL  PRIMARY KEY,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE MV_CTR_T
(
  ID                                 INTEGER                       NOT NULL  PRIMARY KEY,
  SELECT_CLAUSE                      LVARCHAR                      NOT NULL             ,
  WHERE_CLAUSE                       LVARCHAR                                           ,
  ORDER_CLAUSE                       LVARCHAR                                           ,
  TBL_SPACE                          VARCHAR(32)                   NOT NULL             ,
  UPDATED                            DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  UPD_STARTED                        DATETIME YEAR TO FRACTION(3)                       ,
  AVG_UPD_TIME                       INT8                                               ,
  UPD_INTERVAL                       INT8                          NOT NULL             ,
  IS_UPDATING                        SMALLINT                      NOT NULL             ,
  ACTIVE_MV                          SMALLINT                      NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE MV_MODS_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  OID                                CHAR(24)                      NOT NULL             ,
  MODIFIED                           DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE SAVED_ENGINE_MESSAGE_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                                           ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  REASON                             INTEGER                       NOT NULL             ,
  ENGINE_MESSAGE_S                   CHAR(2668)                                         ,
  ENGINE_MESSAGE_L                   BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SEM_PIID ON SAVED_ENGINE_MESSAGE_B_T
(   
  PIID
);

CREATE INDEX SEM_REAS ON SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, CREATION_TIME
);

CREATE TABLE NAVIGATION_CLEANUP_TIMER_B_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  SCHEDULED_TIME                     DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE SCHEDULER_ACTION_T
(
  SCHEDULER_ID                       VARCHAR(254)                  NOT NULL  PRIMARY KEY,
  OID                                CHAR(24)                      NOT NULL             ,
  ACTION_OBJECT                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SCEACT_OID ON SCHEDULER_ACTION_T
(   
  OID
);

CREATE TABLE QUERY_TABLE_T
(
  NAME                               VARCHAR(32)                   NOT NULL  PRIMARY KEY,
  KIND                               INTEGER                       NOT NULL             ,
  TYPE                               INTEGER                       NOT NULL             ,
  VERSION                            INTEGER                       NOT NULL             ,
  LAST_UPDATED                       DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  PRIMARY_VIEW                       VARCHAR(32)                                        ,
  DEFINITION                         BYTE                          NOT NULL             ,
  VV_CFG                             BYTE                                               ,
  DV_CFG                             BYTE                                               ,
  MV_CFG                             BYTE                                               ,
  MT_CFG                             BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX QT_KI ON QUERY_TABLE_T
(   
  KIND
);

CREATE INDEX QT_TY ON QUERY_TABLE_T
(   
  TYPE
);

CREATE TABLE QUERY_TABLE_REF_T
(
  REFEREE                            VARCHAR(32)                   NOT NULL             ,
  SOURCE                             VARCHAR(32)                   NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( REFEREE, SOURCE )
) LOCK MODE ROW;

CREATE INDEX QTR_SRC ON QUERY_TABLE_REF_T
(   
  SOURCE
);

CREATE TABLE MIGRATION_FRONT_T
(
  PIID                               CHAR(24)                      NOT NULL             ,
  MPTID                              CHAR(24)                      NOT NULL             ,
  AIID                               CHAR(24)                      NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  SUB_STATE                          INTEGER                       NOT NULL             ,
  STOP_REASON                        INTEGER                       NOT NULL             ,
  SOURCE_ATID                        CHAR(24)                      NOT NULL             ,
  TARGET_ATID                        CHAR(24)                      NOT NULL             ,
  MIGRATION_TIME                     DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( PIID, MPTID, AIID )
) LOCK MODE ROW;

CREATE INDEX MGF_MPTID ON MIGRATION_FRONT_T
(   
  MPTID
);

CREATE TABLE SCOPE_COMPLETION_COUNTER_T
(
  SIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PIID                               CHAR(24)                      NOT NULL             ,
  COUNTER                            INT8                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SCC_PIID ON SCOPE_COMPLETION_COUNTER_T
(   
  PIID
);

CREATE TABLE AUDIT_LOG_T
(
  ALID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  EVENT_TIME                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  EVENT_TIME_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  AUDIT_EVENT                        INTEGER                       NOT NULL             ,
  PTID                               CHAR(24)                      NOT NULL             ,
  PIID                               CHAR(24)                                           ,
  AIID                               CHAR(24)                                           ,
  SIID                               CHAR(24)                                           ,
  VARIABLE_NAME                      VARCHAR(254)                                       ,
  PROCESS_TEMPL_NAME                 VARCHAR(254)                  NOT NULL             ,
  PROCESS_INST_NAME                  VARCHAR(254)                                       ,
  TOP_LEVEL_PI_NAME                  VARCHAR(254)                                       ,
  TOP_LEVEL_PIID                     CHAR(24)                                           ,
  PARENT_PI_NAME                     VARCHAR(254)                                       ,
  PARENT_PIID                        CHAR(24)                                           ,
  VALID_FROM                         DATETIME YEAR TO FRACTION(3)                       ,
  VALID_FROM_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  ATID                               CHAR(24)                                           ,
  ACTIVITY_NAME                      VARCHAR(254)                                       ,
  ACTIVITY_KIND                      INTEGER                                            ,
  ACTIVITY_STATE                     INTEGER                                            ,
  CONTROL_LINK_NAME                  VARCHAR(254)                                       ,
  IMPL_NAME                          VARCHAR(254)                                       ,
  PRINCIPAL                          VARCHAR(128)                                       ,
  TERMINAL_NAME                      VARCHAR(254)                                       ,
  VARIABLE_DATA                      BYTE                                               ,
  EXCEPTION_TEXT                     TEXT                                               ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  CORR_SET_INFO                      TEXT                                               ,
  USER_NAME                          VARCHAR(128)                                       ,
  ADDITIONAL_INFO                    TEXT                                               ,
  OBJECT_META_TYPE                   INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE WORK_ITEM_T
(
  WIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_WIID                        CHAR(24)                                           ,
  OWNER_ID                           VARCHAR(128)                                       ,
  GROUP_NAME                         VARCHAR(128)                                       ,
  EVERYBODY                          SMALLINT                      NOT NULL             ,
  EXCLUDE                            SMALLINT                      NOT NULL             ,
  QIID                               CHAR(24)                                           ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  OBJECT_ID                          CHAR(24)                      NOT NULL             ,
  ASSOCIATED_OBJECT_TYPE             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                                           ,
  REASON                             INTEGER                       NOT NULL             ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  AUTH_INFO                          INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX WI_ASSOBJ_REASON ON WORK_ITEM_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE, REASON, PARENT_WIID
);

CREATE INDEX WI_OBJID_TYPE_QIID ON WORK_ITEM_T
(   
  OBJECT_ID, OBJECT_TYPE, QIID
);

CREATE INDEX WI_OBJID_TYPE_REAS ON WORK_ITEM_T
(   
  OBJECT_ID, OBJECT_TYPE, REASON
);

CREATE INDEX WI_GROUP_NAME ON WORK_ITEM_T
(   
  GROUP_NAME
);

CREATE INDEX WI_AUTH_U ON WORK_ITEM_T
(   
  AUTH_INFO, QIID
);

CREATE INDEX WI_AUTH_O ON WORK_ITEM_T
(   
  AUTH_INFO, OWNER_ID DESC
);

CREATE INDEX WI_AUTH_G ON WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME
);

CREATE INDEX WI_AUTH_E ON WORK_ITEM_T
(   
  AUTH_INFO, EVERYBODY
);

CREATE INDEX WI_AUTH_R ON WORK_ITEM_T
(   
  AUTH_INFO, REASON DESC
);

CREATE INDEX WI_REASON ON WORK_ITEM_T
(   
  REASON
);

CREATE INDEX WI_OWNER ON WORK_ITEM_T
(   
  OWNER_ID, OBJECT_ID, REASON, OBJECT_TYPE
);

CREATE INDEX WI_QIID ON WORK_ITEM_T
(   
  QIID
);

CREATE INDEX WI_QRY ON WORK_ITEM_T
(   
  OBJECT_ID, REASON, EVERYBODY, OWNER_ID
);

CREATE INDEX WI_QI_OID_RS_OWN ON WORK_ITEM_T
(   
  QIID, OBJECT_ID, REASON, OWNER_ID
);

CREATE INDEX WI_QI_OID_OWN ON WORK_ITEM_T
(   
  QIID, OBJECT_ID, OWNER_ID
);

CREATE INDEX WI_OT_OID_RS ON WORK_ITEM_T
(   
  OBJECT_TYPE, OBJECT_ID, REASON
);

CREATE INDEX WI_WI_QI ON WORK_ITEM_T
(   
  WIID, QIID
);

CREATE INDEX WI_PWIID_OID ON WORK_ITEM_T
(   
  PARENT_WIID, OBJECT_ID
);

CREATE INDEX WI_PWIID_QIID ON WORK_ITEM_T
(   
  PARENT_WIID, QIID
);

CREATE TABLE RETRIEVED_USER_T
(
  QIID                               CHAR(24)                      NOT NULL             ,
  OWNER_ID                           VARCHAR(128)                  NOT NULL             ,
  REASON                             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                                           ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( QIID, OWNER_ID )
) LOCK MODE ROW;

CREATE INDEX RUT_OWN_QIID ON RETRIEVED_USER_T
(   
  OWNER_ID, QIID
);

CREATE INDEX RUT_ASSOC ON RETRIEVED_USER_T
(   
  ASSOCIATED_OID
);

CREATE INDEX RUT_QIID ON RETRIEVED_USER_T
(   
  QIID
);

CREATE INDEX RUT_OWN_QIDESC ON RETRIEVED_USER_T
(   
  OWNER_ID, QIID DESC
);

CREATE TABLE RETRIEVED_GROUP_T
(
  QIID                               CHAR(24)                      NOT NULL             ,
  GROUP_NAME                         VARCHAR(128)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( QIID, GROUP_NAME )
) LOCK MODE ROW;

CREATE TABLE WIS_META_DATA_T
(
  WSID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  LAST_CHECK                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  UNUSED                             SMALLINT                      NOT NULL             ,
  AUTH_INFO_RETRIEVED_USER           SMALLINT                      NOT NULL             ,
  AUTH_INFO_OWNER_ID                 SMALLINT                      NOT NULL             ,
  AUTH_INFO_EVERYBODY                SMALLINT                      NOT NULL             ,
  AUTH_INFO_GROUP                    SMALLINT                      NOT NULL             ,
  AUTH_INFO_RETRIEVED_GROUP          SMALLINT                      NOT NULL             ,
  AUTH_INFO_EMPTY                    SMALLINT                      NOT NULL             ,
  SHARING_PATTERN                    INTEGER                       NOT NULL             ,
  REASONS                            CHAR(44)                      NOT NULL             ,
  PARAMETER_A                        INTEGER                                            ,
  PARAMETER_B                        INTEGER                                            ,
  PARAMETER_C                        INTEGER                                            ,
  PARAMETER_D                        CHAR(24)                                           ,
  PARAMETER_E                        DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE WIS_EMPTY_T
(
  WIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  WSID                               CHAR(24)                      NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  WIS_HASH_CODE                      INTEGER                                            ,
  PARENT_WIID                        CHAR(24)                                           ,
  REASON                             INTEGER                       NOT NULL             ,
  INHERITED                          SMALLINT                                           ,
  QIID                               CHAR(24)                                           ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  SHARING_PATTERN                    INTEGER                       NOT NULL             ,
  ACCESS_KEY                         INTEGER                       NOT NULL             ,
  PARAMETER_A                        INTEGER                                            ,
  PARAMETER_B                        INTEGER                                            ,
  PARAMETER_C                        INTEGER                                            ,
  PARAMETER_D                        CHAR(24)                                           ,
  PARAMETER_E                        DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE SHARED_WORK_ITEM_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  WIID                               CHAR(24)                      NOT NULL             ,
  PARENT_WIID                        CHAR(24)                                           ,
  OWNER_ID                           VARCHAR(128)                                       ,
  GROUP_NAME                         VARCHAR(128)                                       ,
  EVERYBODY                          SMALLINT                      NOT NULL             ,
  QIID                               CHAR(24)                                           ,
  OBJECT_TYPE                        INTEGER                       NOT NULL             ,
  REASON                             INTEGER                       NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  AUTH_INFO                          INTEGER                       NOT NULL             ,
  SHARING_PATTERN                    INTEGER                       NOT NULL             ,
  ACCESS_KEY                         INTEGER                       NOT NULL             ,
  WSID                               CHAR(24)                      NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  WIS_HASH_CODE                      INTEGER                                            ,
  INHERITED                          SMALLINT                                           ,
  PARAMETER_A                        INTEGER                                            ,
  PARAMETER_B                        INTEGER                                            ,
  PARAMETER_C                        INTEGER                                            ,
  PARAMETER_D                        CHAR(24)                                           ,
  PARAMETER_E                        DATETIME YEAR TO FRACTION(3)                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE STAFF_QUERY_INSTANCE_T
(
  QIID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  QTID                               CHAR(24)                      NOT NULL             ,
  EVERYBODY                          SMALLINT                      NOT NULL             ,
  NOBODY                             SMALLINT                      NOT NULL             ,
  IS_SHAREABLE                       SMALLINT                      NOT NULL             ,
  IS_TRANSFERRED                     SMALLINT                      NOT NULL             ,
  SR_HASH_CODE                       INTEGER                                            ,
  GROUP_NAME                         VARCHAR(128)                                       ,
  CONTEXT_VALUES                     TEXT                                               ,
  CONTEXT_VALUES_LONG                TEXT                                               ,
  HASH_CODE                          INTEGER                                            ,
  EXPIRES                            DATETIME YEAR TO FRACTION(3)                       ,
  ASSOCIATED_OBJECT_TYPE             INTEGER                       NOT NULL             ,
  ASSOCIATED_OID                     CHAR(24)                      NOT NULL             ,
  NORMALIZED                         SMALLINT                                           ,
  DENORMALIZED                       SMALLINT                                           ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX SQI_QTID ON STAFF_QUERY_INSTANCE_T
(   
  QTID, HASH_CODE
);

CREATE INDEX SQI_ASSOCID ON STAFF_QUERY_INSTANCE_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE
);

CREATE INDEX SQI_QIIDGN ON STAFF_QUERY_INSTANCE_T
(   
  QIID, GROUP_NAME
);

CREATE INDEX SQI_QIIDTREX ON STAFF_QUERY_INSTANCE_T
(   
  QIID, IS_TRANSFERRED, EXPIRES
);

CREATE TABLE STAFF_LOCK_T
(
  QTID                               CHAR(24)                      NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( QTID, HASH_CODE )
) LOCK MODE ROW;

CREATE TABLE APPLICATION_COMPONENT_T
(
  ACOID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(64)                   NOT NULL             ,
  CALENDAR_NAME                      VARCHAR(254)                                       ,
  JNDI_NAME_CALENDAR                 VARCHAR(254)                                       ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  DURATION_UNTIL_DELETED             VARCHAR(254)                                       ,
  EVENT_HANDLER_NAME                 VARCHAR(64)                                        ,
  INSTANCE_CREATOR_QTID              CHAR(24)                                           ,
  SUPPORTS_AUTO_CLAIM                SMALLINT                      NOT NULL             ,
  SUPPORTS_FOLLOW_ON_TASK            SMALLINT                      NOT NULL             ,
  SUPPORTS_CLAIM_SUSPENDED           SMALLINT                      NOT NULL             ,
  SUPPORTS_DELEGATION                SMALLINT                      NOT NULL             ,
  SUPPORTS_SUB_TASK                  SMALLINT                      NOT NULL             ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             
) LOCK MODE ROW;

CREATE UNIQUE INDEX ACO_NAME ON APPLICATION_COMPONENT_T
(   
  NAME
);

CREATE TABLE ESCALATION_TEMPLATE_T
(
  ESTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  FIRST_ESTID                        CHAR(24)                                           ,
  PREVIOUS_ESTID                     CHAR(24)                                           ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  MNTID                              CHAR(24)                                           ,
  NAME                               VARCHAR(220)                                       ,
  ACTIVATION_STATE                   INTEGER                       NOT NULL             ,
  AT_LEAST_EXPECTED_STATE            INTEGER                       NOT NULL             ,
  DURATION_UNTIL_ESCALATION          VARCHAR(254)                                       ,
  DURATION_UNTIL_REPEATS             VARCHAR(254)                                       ,
  INCREASE_PRIORITY                  INTEGER                       NOT NULL             ,
  ACTION                             INTEGER                       NOT NULL             ,
  ESCALATION_RECEIVER_QTID           CHAR(24)                                           ,
  RECEIVER_EMAIL_QTID                CHAR(24)                                           
) LOCK MODE ROW;

CREATE INDEX ET_TKTID ON ESCALATION_TEMPLATE_T
(   
  TKTID
);

CREATE INDEX ET_CCID ON ESCALATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE ESC_TEMPL_CPROP_T
(
  ESTID                              CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  PRIMARY KEY ( ESTID, NAME )
) LOCK MODE ROW;

CREATE INDEX ETCP_TKTID ON ESC_TEMPL_CPROP_T
(   
  TKTID
);

CREATE INDEX ETCP_CCID ON ESC_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE ESC_TEMPL_LDESC_T
(
  ESTID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  PRIMARY KEY ( ESTID, LOCALE )
) LOCK MODE ROW;

CREATE INDEX ETLD_TKTID ON ESC_TEMPL_LDESC_T
(   
  TKTID
);

CREATE INDEX ETLD_CCID ON ESC_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TTASK_MESSAGE_DEFINITION_T
(
  TMTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKTID                              CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  MESSAGE_TYPE_NS                    VARCHAR(220)                  NOT NULL             ,
  MESSAGE_TYPE_NAME                  VARCHAR(220)                  NOT NULL             ,
  MESSAGE_DEFINITION                 BYTE                                               
) LOCK MODE ROW;

CREATE INDEX TTMD_TKTID ON TTASK_MESSAGE_DEFINITION_T
(   
  TKTID
);

CREATE INDEX TTMD_CCID ON TTASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_TEMPLATE_T
(
  TKTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  DEFINITION_NAME                    VARCHAR(220)                  NOT NULL             ,
  NAMESPACE                          VARCHAR(254)                  NOT NULL             ,
  TARGET_NAMESPACE                   VARCHAR(254)                  NOT NULL             ,
  VALID_FROM                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  APPLICATION_NAME                   VARCHAR(220)                                       ,
  APPLICATION_DEFAULTS_ID            CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                                           ,
  SVTID                              CHAR(24)                                           ,
  KIND                               INTEGER                       NOT NULL             ,
  STATE                              INTEGER                       NOT NULL             ,
  AUTO_DELETE_MODE                   INTEGER                       NOT NULL             ,
  IS_AD_HOC                          SMALLINT                      NOT NULL             ,
  IS_INLINE                          SMALLINT                      NOT NULL             ,
  IS_SHARED                          SMALLINT                      NOT NULL             ,
  SUPPORTS_CLAIM_SUSPENDED           SMALLINT                      NOT NULL             ,
  SUPPORTS_AUTO_CLAIM                SMALLINT                      NOT NULL             ,
  SUPPORTS_FOLLOW_ON_TASK            SMALLINT                      NOT NULL             ,
  SUPPORTS_DELEGATION                SMALLINT                      NOT NULL             ,
  SUPPORTS_SUB_TASK                  SMALLINT                      NOT NULL             ,
  CONTEXT_AUTHORIZATION              INTEGER                       NOT NULL             ,
  AUTONOMY                           INTEGER                       NOT NULL             ,
  ADMIN_QTID                         CHAR(24)                                           ,
  EDITOR_QTID                        CHAR(24)                                           ,
  INSTANCE_CREATOR_QTID              CHAR(24)                                           ,
  POTENTIAL_STARTER_QTID             CHAR(24)                                           ,
  POTENTIAL_OWNER_QTID               CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  DEFAULT_LOCALE                     VARCHAR(32)                                        ,
  CALENDAR_NAME                      VARCHAR(254)                                       ,
  DURATION_UNTIL_DELETED             VARCHAR(254)                                       ,
  DURATION_UNTIL_DUE                 VARCHAR(254)                                       ,
  DURATION_UNTIL_EXPIRES             VARCHAR(254)                                       ,
  JNDI_NAME_CALENDAR                 VARCHAR(254)                                       ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  TYPE                               VARCHAR(254)                                       ,
  EVENT_HANDLER_NAME                 VARCHAR(64)                                        ,
  PRIORITY                           INTEGER                                            ,
  PRIORITY_DEFINITION                VARCHAR(254)                                       ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  CONTACTS_QTIDS                     BYTE                                               ,
  UI_SETTINGS                        BYTE                                               ,
  ASSIGNMENT_TYPE                    INTEGER                       NOT NULL             ,
  INHERITED_AUTH                     INTEGER                       NOT NULL             ,
  PARALLEL_INHERITED_AUTH            INTEGER                       NOT NULL             ,
  NATIVE_LOOKUP_NAME                 VARCHAR(254)                                       ,
  WORK_BASKET                        VARCHAR(254)                                       ,
  EAR_VERSION                        INTEGER                       NOT NULL             ,
  SCHEMA_VERSION                     INTEGER                       NOT NULL             
) LOCK MODE ROW;

CREATE INDEX TT_NAME_VF ON TASK_TEMPLATE_T
(   
  NAME, VALID_FROM
);

CREATE INDEX TT_CCID_STATE ON TASK_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID, STATE
);

CREATE INDEX TT_KND_INLN_VAL ON TASK_TEMPLATE_T
(   
  KIND, IS_INLINE, VALID_FROM
);

CREATE INDEX TT_NATLOOK ON TASK_TEMPLATE_T
(   
  NATIVE_LOOKUP_NAME
);

CREATE TABLE TASK_TEMPL_CPROP_T
(
  TKTID                              CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  PRIMARY KEY ( TKTID, NAME )
) LOCK MODE ROW;

CREATE INDEX TTCP_TKTID ON TASK_TEMPL_CPROP_T
(   
  TKTID
);

CREATE INDEX TTCP_CCID ON TASK_TEMPL_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_TEMPL_LDESC_T
(
  TKTID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  DOCUMENTATION                      TEXT                                               ,
  PRIMARY KEY ( TKTID, LOCALE )
) LOCK MODE ROW;

CREATE INDEX TTLD_TKTID ON TASK_TEMPL_LDESC_T
(   
  TKTID
);

CREATE INDEX TTLD_CCID ON TASK_TEMPL_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX TTLD_TT_LOC ON TASK_TEMPL_LDESC_T
(   
  TKTID, LOCALE DESC
);

CREATE TABLE TSERVICE_DESCRIPTION_T
(
  SVTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  IS_ONE_WAY                         SMALLINT                      NOT NULL             ,
  SERVICE_REF_NAME                   VARCHAR(254)                                       ,
  OPERATION                          VARCHAR(254)                  NOT NULL             ,
  PORT                               VARCHAR(254)                                       ,
  PORT_TYPE_NS                       VARCHAR(254)                  NOT NULL             ,
  PORT_TYPE_NAME                     VARCHAR(254)                  NOT NULL             ,
  S_BEAN_JNDI_NAME                   VARCHAR(254)                                       ,
  SERVICE                            VARCHAR(254)                                       
) LOCK MODE ROW;

CREATE INDEX TSD_TKTID ON TSERVICE_DESCRIPTION_T
(   
  TKTID
);

CREATE INDEX TSD_CCID ON TSERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_CELL_MAP_T
(
  TKTID                              CHAR(24)                      NOT NULL             ,
  CELL                               VARCHAR(220)                  NOT NULL             ,
  PRIMARY KEY ( TKTID, CELL )
) LOCK MODE ROW;

CREATE TABLE TMAIL_T
(
  MNTID                              CHAR(24)                      NOT NULL             ,
  FROM_STATE                         INTEGER                       NOT NULL             ,
  TO_STATE                           INTEGER                       NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  HASH_CODE                          INTEGER                       NOT NULL             ,
  SUBJECT                            VARCHAR(254)                  NOT NULL             ,
  BODY_TEXT                          TEXT                                               ,
  PRIMARY KEY ( MNTID, FROM_STATE, TO_STATE, LOCALE )
) LOCK MODE ROW;

CREATE INDEX EMT_HC ON TMAIL_T
(   
  HASH_CODE
);

CREATE TABLE COMPLETION_TEMPLATE_T
(
  CMTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  COMPL_CONDITION                    BYTE                                               ,
  CRITERION_FOR                      VARCHAR(254)                                       ,
  COMPLETION_NAME                    VARCHAR(220)                                       ,
  IS_DEFAULT_COMPLETION              SMALLINT                      NOT NULL             ,
  PREFIX_MAP                         BYTE                                               ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CMPT_TKTID_ORDER ON COMPLETION_TEMPLATE_T
(   
  TKTID, ORDER_NUMBER
);

CREATE INDEX CMPT_CCID ON COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE RESULT_AGGREGATION_TEMPLATE_T
(
  RATID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  CMTID                              CHAR(24)                      NOT NULL             ,
  TKTID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  AGGR_PART                          VARCHAR(254)                                       ,
  AGGR_LOCATION                      BYTE                                               ,
  AGGR_FUNCTION                      VARCHAR(254)                  NOT NULL             ,
  AGGR_CONDITION                     BYTE                                               ,
  PREFIX_MAP                         BYTE                                               
) LOCK MODE ROW;

CREATE INDEX RAGT_CMTID_ORD_TT ON RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, ORDER_NUMBER, TKTID
);

CREATE INDEX RAGT_CCID ON RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE ESCALATION_INSTANCE_T
(
  ESIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ESTID                              CHAR(24)                                           ,
  FIRST_ESIID                        CHAR(24)                                           ,
  PREVIOUS_ESIID                     CHAR(24)                                           ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  MNTID                              CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(220)                                       ,
  STATE                              INTEGER                       NOT NULL             ,
  ACTIVATION_STATE                   INTEGER                       NOT NULL             ,
  AT_LEAST_EXPECTED_STATE            INTEGER                       NOT NULL             ,
  ACTIVATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  ESCALATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  DURATION_UNTIL_ESCALATION          VARCHAR(254)                                       ,
  DURATION_UNTIL_REPEATS             VARCHAR(254)                                       ,
  INCREASE_PRIORITY                  INTEGER                       NOT NULL             ,
  ACTION                             INTEGER                       NOT NULL             ,
  ESCALATION_RECEIVER_QTID           CHAR(24)                                           ,
  RECEIVER_EMAIL_QTID                CHAR(24)                                           ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX ESI_FIRST ON ESCALATION_INSTANCE_T
(   
  FIRST_ESIID
);

CREATE INDEX ESI_TKIID_ASTATE ON ESCALATION_INSTANCE_T
(   
  TKIID, ACTIVATION_STATE, STATE
);

CREATE INDEX ESI_TKIID_STATE ON ESCALATION_INSTANCE_T
(   
  TKIID, STATE
);

CREATE INDEX ESI_PREV ON ESCALATION_INSTANCE_T
(   
  PREVIOUS_ESIID
);

CREATE INDEX ESI_ESTID ON ESCALATION_INSTANCE_T
(   
  ESTID
);

CREATE INDEX ESI_CCID ON ESCALATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX ESI_EST_ESI ON ESCALATION_INSTANCE_T
(   
  ESTID, ESIID
);

CREATE TABLE ESC_INST_CPROP_T
(
  ESIID                              CHAR(24)                      NOT NULL             ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( ESIID, NAME )
) LOCK MODE ROW;

CREATE INDEX EICP_CCID ON ESC_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE ESC_INST_LDESC_T
(
  ESIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( ESIID, LOCALE )
) LOCK MODE ROW;

CREATE INDEX EILD_CCID ON ESC_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE EIDOCUMENTATION_T
(
  ESIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DOCUMENTATION                      TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( ESIID, LOCALE )
) LOCK MODE ROW;

CREATE INDEX EIDOC_CCID ON EIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE ISERVICE_DESCRIPTION_T
(
  SVTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  IS_ONE_WAY                         SMALLINT                      NOT NULL             ,
  SERVICE_REF_NAME                   VARCHAR(254)                                       ,
  OPERATION                          VARCHAR(254)                  NOT NULL             ,
  PORT                               VARCHAR(254)                                       ,
  PORT_TYPE_NS                       VARCHAR(254)                  NOT NULL             ,
  PORT_TYPE_NAME                     VARCHAR(254)                  NOT NULL             ,
  S_BEAN_JNDI_NAME                   VARCHAR(254)                                       ,
  SERVICE                            VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX ISD_TKIID ON ISERVICE_DESCRIPTION_T
(   
  TKIID
);

CREATE INDEX ISD_CCID ON ISERVICE_DESCRIPTION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_INSTANCE_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  NAMESPACE                          VARCHAR(254)                  NOT NULL             ,
  TKTID                              CHAR(24)                                           ,
  TOP_TKIID                          CHAR(24)                      NOT NULL             ,
  FOLLOW_ON_TKIID                    CHAR(24)                                           ,
  APPLICATION_NAME                   VARCHAR(220)                                       ,
  APPLICATION_DEFAULTS_ID            CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                                           ,
  PARENT_CONTEXT_ID                  CHAR(24)                                           ,
  STATE                              INTEGER                       NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  AUTO_DELETE_MODE                   INTEGER                       NOT NULL             ,
  HIERARCHY_POSITION                 INTEGER                       NOT NULL             ,
  TYPE                               VARCHAR(254)                                       ,
  SVTID                              CHAR(24)                                           ,
  SUPPORTS_CLAIM_SUSPENDED           SMALLINT                      NOT NULL             ,
  SUPPORTS_AUTO_CLAIM                SMALLINT                      NOT NULL             ,
  SUPPORTS_FOLLOW_ON_TASK            SMALLINT                      NOT NULL             ,
  IS_AD_HOC                          SMALLINT                      NOT NULL             ,
  IS_ESCALATED                       SMALLINT                      NOT NULL             ,
  IS_INLINE                          SMALLINT                      NOT NULL             ,
  IS_SUSPENDED                       SMALLINT                      NOT NULL             ,
  IS_WAITING_FOR_SUBTASK             SMALLINT                      NOT NULL             ,
  SUPPORTS_DELEGATION                SMALLINT                      NOT NULL             ,
  SUPPORTS_SUB_TASK                  SMALLINT                      NOT NULL             ,
  IS_CHILD                           SMALLINT                      NOT NULL             ,
  HAS_ESCALATIONS                    SMALLINT                                           ,
  START_TIME                         DATETIME YEAR TO FRACTION(3)                       ,
  ACTIVATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  LAST_MODIFICATION_TIME             DATETIME YEAR TO FRACTION(3)                       ,
  LAST_STATE_CHANGE_TIME             DATETIME YEAR TO FRACTION(3)                       ,
  COMPLETION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  DUE_TIME                           DATETIME YEAR TO FRACTION(3)                       ,
  EXPIRATION_TIME                    DATETIME YEAR TO FRACTION(3)                       ,
  FIRST_ACTIVATION_TIME              DATETIME YEAR TO FRACTION(3)                       ,
  DEFAULT_LOCALE                     VARCHAR(32)                                        ,
  DURATION_UNTIL_DELETED             VARCHAR(254)                                       ,
  DURATION_UNTIL_DUE                 VARCHAR(254)                                       ,
  DURATION_UNTIL_EXPIRES             VARCHAR(254)                                       ,
  CALENDAR_NAME                      VARCHAR(254)                                       ,
  JNDI_NAME_CALENDAR                 VARCHAR(254)                                       ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                                       ,
  CONTEXT_AUTHORIZATION              INTEGER                       NOT NULL             ,
  ORIGINATOR                         VARCHAR(128)                                       ,
  STARTER                            VARCHAR(128)                                       ,
  OWNER                              VARCHAR(128)                                       ,
  ADMIN_QTID                         CHAR(24)                                           ,
  EDITOR_QTID                        CHAR(24)                                           ,
  POTENTIAL_OWNER_QTID               CHAR(24)                                           ,
  POTENTIAL_STARTER_QTID             CHAR(24)                                           ,
  READER_QTID                        CHAR(24)                                           ,
  PRIORITY                           INTEGER                                            ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  SERVICE_TICKET                     VARCHAR(254)                                       ,
  EVENT_HANDLER_NAME                 VARCHAR(64)                                        ,
  BUSINESS_RELEVANCE                 SMALLINT                      NOT NULL             ,
  RESUMES                            DATETIME YEAR TO FRACTION(3)                       ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  DELETION_TIME                      DATETIME YEAR TO FRACTION(3)                       ,
  ASSIGNMENT_TYPE                    INTEGER                       NOT NULL             ,
  INHERITED_AUTH                     INTEGER                       NOT NULL             ,
  PARALLEL_INHERITED_AUTH            INTEGER                       NOT NULL             ,
  INVOKED_INSTANCE_ID                CHAR(24)                                           ,
  INVOKED_INSTANCE_TYPE              INTEGER                       NOT NULL             ,
  WORK_BASKET                        VARCHAR(254)                                       ,
  IS_READ                            SMALLINT                      NOT NULL             ,
  IS_TRANSFERRED_TO_WORK_BASKET      SMALLINT                      NOT NULL             ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX TI_PARENT ON TASK_INSTANCE_T
(   
  PARENT_CONTEXT_ID
);

CREATE INDEX TI_ACOID ON TASK_INSTANCE_T
(   
  APPLICATION_DEFAULTS_ID
);

CREATE INDEX TI_NAME ON TASK_INSTANCE_T
(   
  NAME
);

CREATE INDEX TI_STATE ON TASK_INSTANCE_T
(   
  STATE
);

CREATE INDEX TI_SERVICET ON TASK_INSTANCE_T
(   
  SERVICE_TICKET
);

CREATE INDEX TI_CCID ON TASK_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE INDEX TI_TK_TOPTK ON TASK_INSTANCE_T
(   
  TKTID, TKIID, TOP_TKIID
);

CREATE INDEX TI_TOPTKIID ON TASK_INSTANCE_T
(   
  TOP_TKIID
);

CREATE INDEX TI_TI_KND_ST ON TASK_INSTANCE_T
(   
  TKIID, KIND, STATE
);

CREATE INDEX TI_ST_KND_TI_NAME ON TASK_INSTANCE_T
(   
  STATE, KIND, TKIID, NAME
);

CREATE INDEX TI_TT_KND ON TASK_INSTANCE_T
(   
  TKTID, KIND
);

CREATE INDEX TI_WOBA ON TASK_INSTANCE_T
(   
  WORK_BASKET
);

CREATE INDEX TI_TYPE ON TASK_INSTANCE_T
(   
  TYPE
);

CREATE TABLE TASK_CONTEXT_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  SERVICE_CONTEXT                    BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX TC_CCID ON TASK_CONTEXT_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE CONTACT_QUERIES_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  CONTACTS_QTIDS                     BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CQ_CCID ON CONTACT_QUERIES_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE UISETTINGS_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  UI_SETTINGS                        BYTE                          NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX UIS_CCID ON UISETTINGS_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE REPLY_HANDLER_T
(
  TKIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  REPLY_HANDLER                      BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX RH_CCID ON REPLY_HANDLER_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_TIMER_T
(
  OID                                CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                  NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( OID, KIND )
) LOCK MODE ROW;

CREATE TABLE TASK_INST_CPROP_T
(
  TKIID                              CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(220)                  NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DATA_TYPE                          VARCHAR(254)                                       ,
  STRING_VALUE                       VARCHAR(254)                                       ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( TKIID, NAME )
) LOCK MODE ROW;

CREATE INDEX TICP_CCID ON TASK_INST_CPROP_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_INST_LDESC_T
(
  TKIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( TKIID, LOCALE )
) LOCK MODE ROW;

CREATE INDEX TILD_CCID ON TASK_INST_LDESC_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TIDOCUMENTATION_T
(
  TKIID                              CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  DOCUMENTATION                      TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( TKIID, LOCALE )
) LOCK MODE ROW;

CREATE INDEX TIDOC_CCID ON TIDOCUMENTATION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE ITASK_MESSAGE_DEFINITION_T
(
  TMTID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TKIID                              CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  KIND                               INTEGER                       NOT NULL             ,
  MESSAGE_TYPE_NS                    VARCHAR(220)                  NOT NULL             ,
  MESSAGE_TYPE_NAME                  VARCHAR(220)                  NOT NULL             ,
  MESSAGE_DEFINITION                 BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX ITMD_IDKITYPE ON ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, MESSAGE_TYPE_NAME, KIND
);

CREATE INDEX ITMD_TKIIDKIND ON ITASK_MESSAGE_DEFINITION_T
(   
  TKIID, KIND
);

CREATE INDEX ITMD_CCID ON ITASK_MESSAGE_DEFINITION_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_MESSAGE_INSTANCE_T
(
  TMIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  TMTID                              CHAR(24)                                           ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  FAULT_NAME                         VARCHAR(254)                                       ,
  KIND                               INTEGER                       NOT NULL             ,
  MESSAGE_TYPE_NS                    VARCHAR(220)                  NOT NULL             ,
  MESSAGE_TYPE_NAME                  VARCHAR(220)                  NOT NULL             ,
  DATA                               BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX TMI_TI_K ON TASK_MESSAGE_INSTANCE_T
(   
  TKIID, KIND
);

CREATE INDEX TMI_TMTID ON TASK_MESSAGE_INSTANCE_T
(   
  TMTID
);

CREATE INDEX TMI_CCID ON TASK_MESSAGE_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_AUDIT_LOG_T
(
  ALID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  AUDIT_EVENT                        INTEGER                       NOT NULL             ,
  TKIID                              CHAR(24)                                           ,
  TKTID                              CHAR(24)                                           ,
  ESIID                              CHAR(24)                                           ,
  ESTID                              CHAR(24)                                           ,
  TOP_TKIID                          CHAR(24)                                           ,
  FOLLOW_ON_TKIID                    CHAR(24)                                           ,
  PARENT_TKIID                       CHAR(24)                                           ,
  PARENT_CONTEXT_ID                  CHAR(24)                                           ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                                           ,
  WI_REASON                          INTEGER                                            ,
  NAME                               VARCHAR(254)                                       ,
  NAMESPACE                          VARCHAR(254)                                       ,
  VALID_FROM_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  EVENT_TIME_UTC                     DATETIME YEAR TO FRACTION(3)                       ,
  PARENT_TASK_NAME                   VARCHAR(254)                                       ,
  PARENT_TASK_NAMESPACE              VARCHAR(254)                                       ,
  TASK_KIND                          INTEGER                                            ,
  TASK_STATE                         INTEGER                                            ,
  FAULT_TYPE_NAME                    VARCHAR(220)                                       ,
  FAULT_NAMESPACE                    VARCHAR(220)                                       ,
  FAULT_NAME                         VARCHAR(220)                                       ,
  NEW_USER                           VARCHAR(128)                                       ,
  OLD_USER                           VARCHAR(128)                                       ,
  PRINCIPAL                          VARCHAR(128)                                       ,
  USERS                              TEXT                                               ,
  DESCRIPTION                        TEXT                                               ,
  MESSAGE_DATA                       BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE TABLE IMAIL_T
(
  OBJECT_ID                          CHAR(24)                      NOT NULL             ,
  FROM_STATE                         INTEGER                       NOT NULL             ,
  TO_STATE                           INTEGER                       NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  SUBJECT                            VARCHAR(254)                  NOT NULL             ,
  URI                                VARCHAR(254)                                       ,
  BODY_TEXT                          TEXT                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( OBJECT_ID, FROM_STATE, TO_STATE, LOCALE )
) LOCK MODE ROW;

CREATE INDEX IMN_CTX ON IMAIL_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE TASK_HISTORY_T
(
  PKID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  EVENT                              INTEGER                       NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  PARENT_TKIID                       CHAR(24)                                           ,
  ESIID                              CHAR(24)                                           ,
  REASON                             INTEGER                       NOT NULL             ,
  EVENT_TIME                         DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  NEXT_TIME                          DATETIME YEAR TO FRACTION(3)                       ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  PRINCIPAL                          VARCHAR(128)                  NOT NULL             ,
  WORK_ITEM_KIND                     INTEGER                       NOT NULL             ,
  FROM_ID                            VARCHAR(128)                                       ,
  TO_ID                              VARCHAR(128)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX TH_TKIID ON TASK_HISTORY_T
(   
  TKIID
);

CREATE INDEX TH_CTXID ON TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE COMPLETION_INSTANCE_T
(
  CMIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  COMPL_CONDITION                    BYTE                                               ,
  CRITERION_FOR                      VARCHAR(254)                                       ,
  CRITERION_FOR_TIME                 DATETIME YEAR TO FRACTION(3)                       ,
  COMPLETION_NAME                    VARCHAR(220)                                       ,
  IS_DEFAULT_COMPLETION              SMALLINT                      NOT NULL             ,
  PREFIX_MAP                         BYTE                                               ,
  USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                      NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX CMPI_TKIID_ORDER ON COMPLETION_INSTANCE_T
(   
  TKIID, ORDER_NUMBER
);

CREATE INDEX CMPI_CCID ON COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE RESULT_AGGREGATION_INSTANCE_T
(
  RAIID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  ORDER_NUMBER                       INTEGER                       NOT NULL             ,
  CMIID                              CHAR(24)                      NOT NULL             ,
  TKIID                              CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  AGGR_PART                          VARCHAR(254)                                       ,
  AGGR_LOCATION                      BYTE                                               ,
  AGGR_FUNCTION                      VARCHAR(254)                  NOT NULL             ,
  AGGR_CONDITION                     BYTE                                               ,
  PREFIX_MAP                         BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX RAGI_CMIID_ORDER ON RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, ORDER_NUMBER
);

CREATE INDEX RAGI_CCID ON RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE SAVED_TASK_MESSAGE_T
(
  STMID                              CHAR(24)                      NOT NULL  PRIMARY KEY,
  RELATED_OID                        CHAR(24)                      NOT NULL             ,
  CONTAINMENT_CONTEXT_ID             CHAR(24)                      NOT NULL             ,
  KIND                               INTEGER                       NOT NULL             ,
  SCHEDULER_ID                       VARCHAR(254)                                       ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  EXPECTED_ARRIVAL_TIME              DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  MESSAGE                            BYTE                                               ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX STM_ROID ON SAVED_TASK_MESSAGE_T
(   
  RELATED_OID
);

CREATE INDEX STM_SID ON SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
);

CREATE INDEX STM_CTXID ON SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
);

CREATE TABLE WORK_BASKET_T
(
  WBID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(254)                  NOT NULL             ,
  TYPE                               INTEGER                       NOT NULL             ,
  OWNER                              VARCHAR(128)                                       ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)                                        ,
  CUSTOM_TEXT1                       VARCHAR(254)                                       ,
  CUSTOM_TEXT2                       VARCHAR(254)                                       ,
  CUSTOM_TEXT3                       VARCHAR(254)                                       ,
  CUSTOM_TEXT4                       VARCHAR(254)                                       ,
  CUSTOM_TEXT5                       VARCHAR(254)                                       ,
  CUSTOM_TEXT6                       VARCHAR(254)                                       ,
  CUSTOM_TEXT7                       VARCHAR(254)                                       ,
  CUSTOM_TEXT8                       VARCHAR(254)                                       ,
  EXTENDED_DATA                      BYTE                                               ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  LAST_MODIFICATION_TIME             DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX WBK_NAME ON WORK_BASKET_T
(   
  NAME
);

CREATE INDEX WBK_TYPE ON WORK_BASKET_T
(   
  TYPE
);

CREATE TABLE WORK_BASKET_LDESC_T
(
  WBID                               CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( WBID, LOCALE )
) LOCK MODE ROW;

CREATE TABLE WORK_BASKET_DIST_TARGET_T
(
  SOURCE_WBID                        CHAR(24)                      NOT NULL             ,
  TARGET_WBID                        CHAR(24)                      NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( SOURCE_WBID, TARGET_WBID )
) LOCK MODE ROW;

CREATE INDEX WBDT_TWB ON WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
);

CREATE TABLE BUSINESS_CATEGORY_T
(
  BCID                               CHAR(24)                      NOT NULL  PRIMARY KEY,
  PARENT_BCID                        CHAR(24)                                           ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  NAME                               VARCHAR(254)                  NOT NULL             ,
  PRIORITY                           INTEGER                                            ,
  SUBSTITUTION_POLICY                INTEGER                       NOT NULL             ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                  NOT NULL             ,
  DEFAULT_QUERY_TABLE                VARCHAR(32)                                        ,
  CUSTOM_TEXT1                       VARCHAR(254)                                       ,
  CUSTOM_TEXT2                       VARCHAR(254)                                       ,
  CUSTOM_TEXT3                       VARCHAR(254)                                       ,
  CUSTOM_TEXT4                       VARCHAR(254)                                       ,
  CUSTOM_TEXT5                       VARCHAR(254)                                       ,
  CUSTOM_TEXT6                       VARCHAR(254)                                       ,
  CUSTOM_TEXT7                       VARCHAR(254)                                       ,
  CUSTOM_TEXT8                       VARCHAR(254)                                       ,
  EXTENDED_DATA                      BYTE                                               ,
  CREATION_TIME                      DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  LAST_MODIFICATION_TIME             DATETIME YEAR TO FRACTION(3)  NOT NULL             ,
  CREATED_WITH_VERSION               INTEGER                       NOT NULL             ,
  VERSION_ID                         SMALLINT                      NOT NULL             
) LOCK MODE ROW;

CREATE INDEX BCG_PARENTBCID ON BUSINESS_CATEGORY_T
(   
  PARENT_BCID
);

CREATE INDEX BCG_NAME ON BUSINESS_CATEGORY_T
(   
  NAME
);

CREATE TABLE BUSINESS_CATEGORY_LDESC_T
(
  BCID                               CHAR(24)                      NOT NULL             ,
  LOCALE                             VARCHAR(32)                   NOT NULL             ,
  WSID_1                             CHAR(24)                                           ,
  WSID_1_HC                          INTEGER                                            ,
  WSID_2                             CHAR(24)                                           ,
  WSID_2_HC                          INTEGER                                            ,
  DISPLAY_NAME                       VARCHAR(64)                                        ,
  DESCRIPTION                        VARCHAR(254)                                       ,
  VERSION_ID                         SMALLINT                      NOT NULL             ,
  PRIMARY KEY ( BCID, LOCALE )
) LOCK MODE ROW;
-- set schema version to: 700
INSERT INTO SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 0 );


-- View: ProcessTemplate
CREATE VIEW PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT PROCESS_TEMPLATE_B_T.PTID, PROCESS_TEMPLATE_B_T.NAME, PROCESS_TEMPLATE_B_T.DISPLAY_NAME, PROCESS_TEMPLATE_B_T.VALID_FROM, PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, PROCESS_TEMPLATE_B_T.APPLICATION_NAME, PROCESS_TEMPLATE_B_T.VERSION, PROCESS_TEMPLATE_B_T.CREATED, PROCESS_TEMPLATE_B_T.STATE, PROCESS_TEMPLATE_B_T.EXECUTION_MODE, PROCESS_TEMPLATE_B_T.DESCRIPTION, PROCESS_TEMPLATE_B_T.CAN_CALL, PROCESS_TEMPLATE_B_T.CAN_INITIATE, PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM PROCESS_TEMPLATE_B_T;

-- View: ProcessTemplAttr
CREATE VIEW PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT PROCESS_INSTANCE_B_T.PTID, PROCESS_INSTANCE_B_T.PIID, PROCESS_INSTANCE_B_T.NAME, PROCESS_INSTANCE_B_T.STATE, PROCESS_INSTANCE_B_T.CREATED, PROCESS_INSTANCE_B_T.STARTED, PROCESS_INSTANCE_B_T.COMPLETED, PROCESS_INSTANCE_B_T.PARENT_NAME, PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, PROCESS_INSTANCE_B_T.PARENT_PIID, PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, PROCESS_INSTANCE_B_T.STARTER, PROCESS_INSTANCE_B_T.DESCRIPTION, PROCESS_TEMPLATE_B_T.NAME, PROCESS_TEMPLATE_B_T.DESCRIPTION, PROCESS_INSTANCE_B_T.RESUMES, PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, PROCESS_INSTANCE_B_T.IS_MIGRATED, PROCESS_INSTANCE_B_T.WSID_1, PROCESS_INSTANCE_B_T.WSID_2
 FROM PROCESS_INSTANCE_B_T, PROCESS_TEMPLATE_B_T
 WHERE PROCESS_INSTANCE_B_T.PTID = PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT PROCESS_INSTANCE_ATTRIBUTE_T.PIID, PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT ACTIVITY_INSTANCE_B_T.PIID, ACTIVITY_INSTANCE_B_T.AIID, ACTIVITY_INSTANCE_B_T.PTID, ACTIVITY_INSTANCE_B_T.ATID, ACTIVITY_INSTANCE_B_T.SIID, ACTIVITY_TEMPLATE_B_T.PARENT_STID, ACTIVITY_INSTANCE_B_T.EHIID, ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, ACTIVITY_TEMPLATE_B_T.KIND, ACTIVITY_INSTANCE_B_T.FINISHED, ACTIVITY_INSTANCE_B_T.ACTIVATED, ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, ACTIVITY_INSTANCE_B_T.STARTED, ACTIVITY_INSTANCE_B_T.STATE, ACTIVITY_INSTANCE_B_T.SUB_STATE, ACTIVITY_INSTANCE_B_T.STOP_REASON, ACTIVITY_INSTANCE_B_T.OWNER, ACTIVITY_INSTANCE_B_T.DESCRIPTION, ACTIVITY_INSTANCE_B_T.EXPIRES, ACTIVITY_TEMPLATE_B_T.NAME, ACTIVITY_TEMPLATE_B_T.DESCRIPTION, ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, ACTIVITY_INSTANCE_B_T.WSID_1, ACTIVITY_INSTANCE_B_T.WSID_2
 FROM ACTIVITY_INSTANCE_B_T, ACTIVITY_TEMPLATE_B_T
 WHERE ACTIVITY_INSTANCE_B_T.ATID = ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT ACTIVITY_INSTANCE_ATTR_B_T.AIID, ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT EVENT_INSTANCE_B_T.EIID, EVENT_INSTANCE_B_T.AIID, EVENT_INSTANCE_B_T.PIID, EVENT_INSTANCE_B_T.EHTID, EVENT_INSTANCE_B_T.SIID, SERVICE_TEMPLATE_B_T.NAME, EVENT_INSTANCE_B_T.WSID_1, EVENT_INSTANCE_B_T.WSID_2
 FROM EVENT_INSTANCE_B_T, SERVICE_TEMPLATE_B_T
 WHERE EVENT_INSTANCE_B_T.STATE = 2 AND EVENT_INSTANCE_B_T.VTID = SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT WORK_ITEM_T.WIID, WORK_ITEM_T.OWNER_ID, WORK_ITEM_T.GROUP_NAME, WORK_ITEM_T.EVERYBODY, WORK_ITEM_T.OBJECT_TYPE, WORK_ITEM_T.OBJECT_ID, WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, WORK_ITEM_T.ASSOCIATED_OID, WORK_ITEM_T.REASON, WORK_ITEM_T.CREATION_TIME, WORK_ITEM_T.QIID, WORK_ITEM_T.KIND
 FROM WORK_ITEM_T
 WHERE WORK_ITEM_T.AUTH_INFO = 1
 UNION ALL SELECT WORK_ITEM_T.WIID, WORK_ITEM_T.OWNER_ID, WORK_ITEM_T.GROUP_NAME, WORK_ITEM_T.EVERYBODY, WORK_ITEM_T.OBJECT_TYPE, WORK_ITEM_T.OBJECT_ID, WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, WORK_ITEM_T.ASSOCIATED_OID, WORK_ITEM_T.REASON, WORK_ITEM_T.CREATION_TIME, WORK_ITEM_T.QIID, WORK_ITEM_T.KIND
 FROM WORK_ITEM_T
 WHERE WORK_ITEM_T.AUTH_INFO = 2
 UNION ALL SELECT WORK_ITEM_T.WIID, WORK_ITEM_T.OWNER_ID, WORK_ITEM_T.GROUP_NAME, WORK_ITEM_T.EVERYBODY, WORK_ITEM_T.OBJECT_TYPE, WORK_ITEM_T.OBJECT_ID, WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, WORK_ITEM_T.ASSOCIATED_OID, WORK_ITEM_T.REASON, WORK_ITEM_T.CREATION_TIME, WORK_ITEM_T.QIID, WORK_ITEM_T.KIND
 FROM WORK_ITEM_T
 WHERE WORK_ITEM_T.AUTH_INFO = 3
 UNION ALL SELECT WORK_ITEM_T.WIID, RETRIEVED_USER_T.OWNER_ID, WORK_ITEM_T.GROUP_NAME, WORK_ITEM_T.EVERYBODY, WORK_ITEM_T.OBJECT_TYPE, WORK_ITEM_T.OBJECT_ID, WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, WORK_ITEM_T.ASSOCIATED_OID, WORK_ITEM_T.REASON, WORK_ITEM_T.CREATION_TIME, WORK_ITEM_T.QIID, WORK_ITEM_T.KIND
 FROM WORK_ITEM_T, RETRIEVED_USER_T
 WHERE WORK_ITEM_T.AUTH_INFO = 0 AND WORK_ITEM_T.QIID = RETRIEVED_USER_T.QIID;

-- View: ActivityService
CREATE VIEW ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT EVENT_INSTANCE_B_T.EIID, EVENT_INSTANCE_B_T.AIID, EVENT_INSTANCE_B_T.PIID, EVENT_INSTANCE_B_T.VTID, SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,URI_TEMPLATE_B_T.URI, SERVICE_TEMPLATE_B_T.OPERATION_NAME, EVENT_INSTANCE_B_T.WSID_1, EVENT_INSTANCE_B_T.WSID_2
 FROM EVENT_INSTANCE_B_T, SERVICE_TEMPLATE_B_T, URI_TEMPLATE_B_T
 WHERE EVENT_INSTANCE_B_T.STATE = 2 AND EVENT_INSTANCE_B_T.VTID = SERVICE_TEMPLATE_B_T.VTID AND SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT QUERYABLE_VARIABLE_INSTANCE_T.PIID, QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT QUERYABLE_VARIABLE_TEMPLATE_T.PTID, VARIABLE_TEMPLATE_B_T.NAME, PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, URI_TEMPLATE_B_T.URI, QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM QUERYABLE_VARIABLE_TEMPLATE_T, VARIABLE_TEMPLATE_B_T, PROPERTY_ALIAS_TEMPLATE_B_T, URI_TEMPLATE_B_T
 WHERE QUERYABLE_VARIABLE_TEMPLATE_T.CTID = VARIABLE_TEMPLATE_B_T.CTID AND QUERYABLE_VARIABLE_TEMPLATE_T.PAID = PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT MIGRATION_FRONT_T.PIID, MIGRATION_FRONT_T.AIID, MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, MIGRATION_FRONT_T.STATE, MIGRATION_FRONT_T.SUB_STATE, MIGRATION_FRONT_T.STOP_REASON, MIGRATION_FRONT_T.SOURCE_ATID, MIGRATION_FRONT_T.TARGET_ATID, MIGRATION_FRONT_T.MIGRATION_TIME, MIGRATION_FRONT_T.WSID_1, MIGRATION_FRONT_T.WSID_2
 FROM MIGRATION_FRONT_T, MIGRATION_PLAN_TEMPLATE_T
 WHERE MIGRATION_FRONT_T.MPTID = MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT AUDIT_LOG_T.ALID,AUDIT_LOG_T.EVENT_TIME,AUDIT_LOG_T.EVENT_TIME_UTC,AUDIT_LOG_T.AUDIT_EVENT,AUDIT_LOG_T.PTID,AUDIT_LOG_T.PIID,AUDIT_LOG_T.AIID,AUDIT_LOG_T.SIID,AUDIT_LOG_T.VARIABLE_NAME,AUDIT_LOG_T.PROCESS_TEMPL_NAME, AUDIT_LOG_T.PROCESS_INST_NAME,AUDIT_LOG_T.TOP_LEVEL_PI_NAME,AUDIT_LOG_T.TOP_LEVEL_PIID,AUDIT_LOG_T.PARENT_PI_NAME,AUDIT_LOG_T.PARENT_PIID,AUDIT_LOG_T.VALID_FROM,AUDIT_LOG_T.VALID_FROM_UTC, AUDIT_LOG_T.ACTIVITY_NAME,AUDIT_LOG_T.ACTIVITY_KIND,AUDIT_LOG_T.ACTIVITY_STATE,AUDIT_LOG_T.CONTROL_LINK_NAME,AUDIT_LOG_T.IMPL_NAME,AUDIT_LOG_T.PRINCIPAL, AUDIT_LOG_T.TERMINAL_NAME,AUDIT_LOG_T.VARIABLE_DATA,AUDIT_LOG_T.EXCEPTION_TEXT,AUDIT_LOG_T.DESCRIPTION,AUDIT_LOG_T.CORR_SET_INFO,AUDIT_LOG_T.USER_NAME, AUDIT_LOG_T.ATID, AUDIT_LOG_T.ADDITIONAL_INFO, AUDIT_LOG_T.OBJECT_META_TYPE
 FROM AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT AUDIT_LOG_T.ALID,AUDIT_LOG_T.EVENT_TIME,AUDIT_LOG_T.EVENT_TIME_UTC,AUDIT_LOG_T.AUDIT_EVENT,AUDIT_LOG_T.PTID,AUDIT_LOG_T.PIID,AUDIT_LOG_T.AIID,AUDIT_LOG_T.SIID,AUDIT_LOG_T.VARIABLE_NAME,AUDIT_LOG_T.PROCESS_TEMPL_NAME, AUDIT_LOG_T.TOP_LEVEL_PIID,AUDIT_LOG_T.PARENT_PIID,AUDIT_LOG_T.VALID_FROM,AUDIT_LOG_T.VALID_FROM_UTC,AUDIT_LOG_T.ATID, AUDIT_LOG_T.ACTIVITY_NAME,AUDIT_LOG_T.ACTIVITY_KIND,AUDIT_LOG_T.ACTIVITY_STATE,AUDIT_LOG_T.CONTROL_LINK_NAME,AUDIT_LOG_T.PRINCIPAL, AUDIT_LOG_T.VARIABLE_DATA,AUDIT_LOG_T.EXCEPTION_TEXT,AUDIT_LOG_T.DESCRIPTION,AUDIT_LOG_T.CORR_SET_INFO,AUDIT_LOG_T.USER_NAME, AUDIT_LOG_T.ADDITIONAL_INFO
 FROM AUDIT_LOG_T
 WHERE AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT APPLICATION_COMPONENT_T.ACOID, APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, APPLICATION_COMPONENT_T.NAME, APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM APPLICATION_COMPONENT_T;

-- View: Task
CREATE VIEW TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT TASK_INSTANCE_T.TKIID, TASK_INSTANCE_T.ACTIVATION_TIME, TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, TASK_INSTANCE_T.APPLICATION_NAME, TASK_INSTANCE_T.BUSINESS_RELEVANCE, TASK_INSTANCE_T.COMPLETION_TIME, TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, TASK_INSTANCE_T.DUE_TIME, TASK_INSTANCE_T.EXPIRATION_TIME, TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, TASK_INSTANCE_T.FOLLOW_ON_TKIID, TASK_INSTANCE_T.IS_AD_HOC, TASK_INSTANCE_T.IS_ESCALATED, TASK_INSTANCE_T.IS_INLINE, TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, TASK_INSTANCE_T.KIND, TASK_INSTANCE_T.LAST_MODIFICATION_TIME, TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, TASK_INSTANCE_T.NAME, TASK_INSTANCE_T.NAMESPACE, TASK_INSTANCE_T.ORIGINATOR, TASK_INSTANCE_T.OWNER, TASK_INSTANCE_T.PARENT_CONTEXT_ID, TASK_INSTANCE_T.PRIORITY, TASK_INSTANCE_T.START_TIME, TASK_INSTANCE_T.STARTER, TASK_INSTANCE_T.STATE, TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, TASK_INSTANCE_T.SUPPORTS_DELEGATION, TASK_INSTANCE_T.SUPPORTS_SUB_TASK, TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, TASK_INSTANCE_T.HIERARCHY_POSITION, TASK_INSTANCE_T.IS_CHILD, TASK_INSTANCE_T.IS_SUSPENDED, TASK_INSTANCE_T.TKTID, TASK_INSTANCE_T.TOP_TKIID, TASK_INSTANCE_T.TYPE, TASK_INSTANCE_T.RESUMES, TASK_INSTANCE_T.ASSIGNMENT_TYPE, TASK_INSTANCE_T.INHERITED_AUTH, TASK_INSTANCE_T.INVOKED_INSTANCE_ID, TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, TASK_INSTANCE_T.WORK_BASKET, TASK_INSTANCE_T.IS_READ, TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, TASK_INSTANCE_T.WSID_1, TASK_INSTANCE_T.WSID_2
 FROM TASK_INSTANCE_T;

-- View: TaskTempl
CREATE VIEW TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT TASK_TEMPLATE_T.TKTID, TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, TASK_TEMPLATE_T.APPLICATION_NAME, TASK_TEMPLATE_T.BUSINESS_RELEVANCE, TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, TASK_TEMPLATE_T.DEFINITION_NAME, TASK_TEMPLATE_T.TARGET_NAMESPACE, TASK_TEMPLATE_T.IS_AD_HOC, TASK_TEMPLATE_T.IS_INLINE, TASK_TEMPLATE_T.KIND, TASK_TEMPLATE_T.NAME, TASK_TEMPLATE_T.NAMESPACE, TASK_TEMPLATE_T.PRIORITY, TASK_TEMPLATE_T.STATE, TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, TASK_TEMPLATE_T.SUPPORTS_DELEGATION, TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, TASK_TEMPLATE_T.TYPE, TASK_TEMPLATE_T.VALID_FROM, TASK_TEMPLATE_T.AUTONOMY, TASK_TEMPLATE_T.ASSIGNMENT_TYPE, TASK_TEMPLATE_T.INHERITED_AUTH, TASK_TEMPLATE_T.WORK_BASKET
 FROM TASK_TEMPLATE_T;

-- View: Escalation
CREATE VIEW ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT ESCALATION_INSTANCE_T.ESIID, ESCALATION_INSTANCE_T.ACTION, ESCALATION_INSTANCE_T.ACTIVATION_STATE, ESCALATION_INSTANCE_T.ACTIVATION_TIME, ESCALATION_INSTANCE_T.ESCALATION_TIME, ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, ESCALATION_INSTANCE_T.ESTID, ESCALATION_INSTANCE_T.FIRST_ESIID, ESCALATION_INSTANCE_T.INCREASE_PRIORITY, ESCALATION_INSTANCE_T.NAME, ESCALATION_INSTANCE_T.STATE, ESCALATION_INSTANCE_T.TKIID, ESCALATION_INSTANCE_T.WSID_1, ESCALATION_INSTANCE_T.WSID_2
 FROM ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT ESCALATION_TEMPLATE_T.ESTID, ESCALATION_TEMPLATE_T.FIRST_ESTID, ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, ESCALATION_TEMPLATE_T.TKTID, ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, ESCALATION_TEMPLATE_T.NAME, ESCALATION_TEMPLATE_T.ACTIVATION_STATE, ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, ESCALATION_TEMPLATE_T.ACTION
 FROM ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT ESC_TEMPL_LDESC_T.ESTID, ESC_TEMPL_LDESC_T.LOCALE, ESC_TEMPL_LDESC_T.TKTID, ESC_TEMPL_LDESC_T.DISPLAY_NAME, ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT TASK_TEMPL_CPROP_T.TKTID, TASK_TEMPL_CPROP_T.NAME, TASK_TEMPL_CPROP_T.DATA_TYPE, TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT ESC_TEMPL_CPROP_T.ESTID, ESC_TEMPL_CPROP_T.NAME, ESC_TEMPL_CPROP_T.TKTID, ESC_TEMPL_CPROP_T.DATA_TYPE, ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT TASK_TEMPL_LDESC_T.TKTID, TASK_TEMPL_LDESC_T.LOCALE, TASK_TEMPL_LDESC_T.DESCRIPTION, TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT TASK_INST_CPROP_T.TKIID, TASK_INST_CPROP_T.NAME, TASK_INST_CPROP_T.DATA_TYPE, TASK_INST_CPROP_T.STRING_VALUE, TASK_INST_CPROP_T.WSID_1, TASK_INST_CPROP_T.WSID_2
 FROM TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT TASK_INST_LDESC_T.TKIID, TASK_INST_LDESC_T.LOCALE, TASK_INST_LDESC_T.DESCRIPTION, TASK_INST_LDESC_T.DISPLAY_NAME, TASK_INST_LDESC_T.WSID_1, TASK_INST_LDESC_T.WSID_2
 FROM TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT ESC_INST_CPROP_T.ESIID, ESC_INST_CPROP_T.NAME, ESC_INST_CPROP_T.DATA_TYPE, ESC_INST_CPROP_T.STRING_VALUE, ESC_INST_CPROP_T.WSID_1, ESC_INST_CPROP_T.WSID_2
 FROM ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT TASK_HISTORY_T.TKIID, TASK_HISTORY_T.ESIID, TASK_HISTORY_T.PARENT_TKIID, TASK_HISTORY_T.EVENT, TASK_HISTORY_T.REASON, TASK_HISTORY_T.EVENT_TIME, TASK_HISTORY_T.NEXT_TIME, TASK_HISTORY_T.PRINCIPAL, TASK_HISTORY_T.WORK_ITEM_KIND, TASK_HISTORY_T.FROM_ID, TASK_HISTORY_T.TO_ID, TASK_HISTORY_T.WSID_1, TASK_HISTORY_T.WSID_2
 FROM TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT ESC_INST_LDESC_T.ESIID, ESC_INST_LDESC_T.LOCALE, ESC_INST_LDESC_T.DESCRIPTION, ESC_INST_LDESC_T.DISPLAY_NAME, ESC_INST_LDESC_T.WSID_1, ESC_INST_LDESC_T.WSID_2
 FROM ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT TASK_AUDIT_LOG_T.ALID, TASK_AUDIT_LOG_T.AUDIT_EVENT, TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, TASK_AUDIT_LOG_T.ESIID, TASK_AUDIT_LOG_T.ESTID, TASK_AUDIT_LOG_T.EVENT_TIME_UTC, TASK_AUDIT_LOG_T.FAULT_NAME, TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, TASK_AUDIT_LOG_T.FAULT_NAMESPACE, TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, TASK_AUDIT_LOG_T.NAME, TASK_AUDIT_LOG_T.NAMESPACE, TASK_AUDIT_LOG_T.NEW_USER, TASK_AUDIT_LOG_T.OLD_USER, TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, TASK_AUDIT_LOG_T.PARENT_TASK_NAME, TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, TASK_AUDIT_LOG_T.PARENT_TKIID, TASK_AUDIT_LOG_T.PRINCIPAL, TASK_AUDIT_LOG_T.TASK_KIND, TASK_AUDIT_LOG_T.TASK_STATE, TASK_AUDIT_LOG_T.TKIID, TASK_AUDIT_LOG_T.TKTID, TASK_AUDIT_LOG_T.TOP_TKIID, TASK_AUDIT_LOG_T.VALID_FROM_UTC, TASK_AUDIT_LOG_T.WI_REASON, TASK_AUDIT_LOG_T.USERS, TASK_AUDIT_LOG_T.DESCRIPTION, TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT WORK_BASKET_T.WBID, WORK_BASKET_T.NAME, WORK_BASKET_T.TYPE, WORK_BASKET_T.OWNER, WORK_BASKET_T.DEFAULT_QUERY_TABLE, WORK_BASKET_T.CUSTOM_TEXT1, WORK_BASKET_T.CUSTOM_TEXT2, WORK_BASKET_T.CUSTOM_TEXT3, WORK_BASKET_T.CUSTOM_TEXT4, WORK_BASKET_T.CUSTOM_TEXT5, WORK_BASKET_T.CUSTOM_TEXT6, WORK_BASKET_T.CUSTOM_TEXT7, WORK_BASKET_T.CUSTOM_TEXT8, WORK_BASKET_T.CREATION_TIME, WORK_BASKET_T.LAST_MODIFICATION_TIME, WORK_BASKET_T.WSID_1, WORK_BASKET_T.WSID_2
 FROM WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT WORK_BASKET_LDESC_T.WBID, WORK_BASKET_LDESC_T.LOCALE, WORK_BASKET_LDESC_T.DISPLAY_NAME, WORK_BASKET_LDESC_T.DESCRIPTION, WORK_BASKET_LDESC_T.WSID_1, WORK_BASKET_LDESC_T.WSID_2
 FROM WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT WORK_BASKET_DIST_TARGET_T.TARGET_WBID, WORK_BASKET_T.NAME, WORK_BASKET_T.TYPE, WORK_BASKET_T.OWNER, WORK_BASKET_T.DEFAULT_QUERY_TABLE, WORK_BASKET_T.CUSTOM_TEXT1, WORK_BASKET_T.CUSTOM_TEXT2, WORK_BASKET_T.CUSTOM_TEXT3, WORK_BASKET_T.CUSTOM_TEXT4, WORK_BASKET_T.CUSTOM_TEXT5, WORK_BASKET_T.CUSTOM_TEXT6, WORK_BASKET_T.CUSTOM_TEXT7, WORK_BASKET_T.CUSTOM_TEXT8, WORK_BASKET_T.CREATION_TIME, WORK_BASKET_T.LAST_MODIFICATION_TIME, WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, WORK_BASKET_T.WSID_1, WORK_BASKET_T.WSID_2
 FROM WORK_BASKET_DIST_TARGET_T, WORK_BASKET_T
 WHERE WORK_BASKET_T.WBID = WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT BUSINESS_CATEGORY_T.BCID, BUSINESS_CATEGORY_T.PARENT_BCID, BUSINESS_CATEGORY_T.NAME, BUSINESS_CATEGORY_T.PRIORITY, BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, BUSINESS_CATEGORY_T.CUSTOM_TEXT1, BUSINESS_CATEGORY_T.CUSTOM_TEXT2, BUSINESS_CATEGORY_T.CUSTOM_TEXT3, BUSINESS_CATEGORY_T.CUSTOM_TEXT4, BUSINESS_CATEGORY_T.CUSTOM_TEXT5, BUSINESS_CATEGORY_T.CUSTOM_TEXT6, BUSINESS_CATEGORY_T.CUSTOM_TEXT7, BUSINESS_CATEGORY_T.CUSTOM_TEXT8, BUSINESS_CATEGORY_T.CREATION_TIME, BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, BUSINESS_CATEGORY_T.WSID_1, BUSINESS_CATEGORY_T.WSID_2
 FROM BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT BUSINESS_CATEGORY_LDESC_T.BCID, BUSINESS_CATEGORY_LDESC_T.LOCALE, BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, BUSINESS_CATEGORY_LDESC_T.WSID_1, BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM BUSINESS_CATEGORY_LDESC_T;


-- start import scheduler DDL: createSchemaInformix.sql



CREATE TABLE SCHED_TASK ( TASKID DECIMAL(19,
               0) NOT NULL PRIMARY KEY ,
               VERSION VARCHAR(5) NOT NULL ,
               ROW_VERSION INTEGER NOT NULL ,
               TASKTYPE INTEGER NOT NULL ,
               TASKSUSPENDED SMALLINT NOT NULL ,
               CANCELLED SMALLINT NOT NULL ,
               NEXTFIRETIME DECIMAL(19,
               0) NOT NULL ,
               STARTBYINTERVAL VARCHAR(254) ,
               STARTBYTIME DECIMAL(19,
               0) ,
               VALIDFROMTIME DECIMAL(19,
               0) ,
               VALIDTOTIME DECIMAL(19,
               0) ,
               REPEATINTERVAL VARCHAR(254) ,
               MAXREPEATS INTEGER NOT NULL ,
               REPEATSLEFT INTEGER NOT NULL ,
               TASKINFO BYTE ,
               NAME VARCHAR(254) NOT NULL ,
               AUTOPURGE INTEGER NOT NULL ,
               FAILUREACTION INTEGER ,
               MAXATTEMPTS INTEGER ,
               QOS INTEGER  ,
               PARTITIONID INTEGER ,
               OWNERTOKEN VARCHAR(200) NOT NULL ,
               CREATETIME DECIMAL(19,
               0) NOT NULL ) LOCK MODE ROW;

CREATE INDEX SCHED_TASK_IDX1 ON SCHED_TASK ( TASKID,
               OWNERTOKEN ) ;

CREATE CLUSTER INDEX SCHED_TASK_IDX2 ON SCHED_TASK ( NEXTFIRETIME ASC,
               REPEATSLEFT,
               PARTITIONID );

CREATE TABLE SCHED_TREG ( REGKEY VARCHAR(254) NOT NULL PRIMARY KEY,
               REGVALUE VARCHAR(254) ) LOCK MODE ROW;

CREATE TABLE SCHED_LMGR ( LEASENAME VARCHAR(254) NOT NULL PRIMARY KEY,
               LEASEOWNER VARCHAR(254) NOT NULL,
               LEASE_EXPIRE_TIME NUMERIC(19,
               0),
               DISABLED VARCHAR(5) ) LOCK MODE ROW;

CREATE TABLE SCHED_LMPR ( LEASENAME VARCHAR(254) NOT NULL,
               NAME VARCHAR(254) NOT NULL,
               VALUE VARCHAR(254) NOT NULL ) LOCK MODE ROW;

CREATE INDEX SCHED_LMPR_IDX1 ON SCHED_LMPR ( LEASENAME );

-- end import scheduler DDL: createSchemaInformix.sql


