--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
----------------------------------------------------------------------
-- The following variable needs to be changed for customization and
-- before running this script.
-- @SCHEMA@ = Schema name
----------------------------------------------------------------------
-- Scriptfile to upgrade schema for Oracle
-- Process this script using SQL*Plus
-- example: sqlplus scott/tiger@mydb @upgradeSchema602.sql
-- or, at the sqlplus prompt, enter
-- SQL> @upgradeSchema602.sql
--


----------------
-- Drop views --
----------------

DROP VIEW @SCHEMA@.PROCESS_TEMPLATE;

DROP VIEW @SCHEMA@.PROCESS_TEMPL_ATTR;

DROP VIEW @SCHEMA@.PROCESS_INSTANCE;

DROP VIEW @SCHEMA@.PROCESS_ATTRIBUTE;

DROP VIEW @SCHEMA@.ACTIVITY;

DROP VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE;

DROP VIEW @SCHEMA@.EVENT;

DROP VIEW @SCHEMA@.WORK_ITEM;

DROP VIEW @SCHEMA@.ACTIVITY_SERVICE;

DROP VIEW @SCHEMA@.QUERY_PROPERTY;

DROP VIEW @SCHEMA@.AUDIT_LOG;

DROP VIEW @SCHEMA@.AUDIT_LOG_B;

DROP VIEW @SCHEMA@.APPLICATION_COMP;

DROP VIEW @SCHEMA@.TASK;

DROP VIEW @SCHEMA@.TASK_TEMPL;

DROP VIEW @SCHEMA@.ESCALATION;

DROP VIEW @SCHEMA@.ESC_TEMPL;

DROP VIEW @SCHEMA@.ESC_TEMPL_DESC;

DROP VIEW @SCHEMA@.TASK_TEMPL_CPROP;

DROP VIEW @SCHEMA@.ESC_TEMPL_CPROP;

DROP VIEW @SCHEMA@.TASK_TEMPL_DESC;

DROP VIEW @SCHEMA@.TASK_CPROP;

DROP VIEW @SCHEMA@.TASK_DESC;

DROP VIEW @SCHEMA@.ESCALATION_CPROP;

DROP VIEW @SCHEMA@.ESCALATION_DESC;

DROP VIEW @SCHEMA@.CUSTOM_PROPERTY;

DROP VIEW @SCHEMA@.DESCRIPTION;

DROP VIEW @SCHEMA@.TASK_AUDIT_LOG;

------------------
-- Drop indexes --
------------------

DROP INDEX @SCHEMA@.AIB_ATID_PI_EH_FE;

DROP INDEX @SCHEMA@.EI_PIID_VTID;

DROP INDEX @SCHEMA@.EI_STATE_VTID;

DROP INDEX @SCHEMA@.WI_ASSOBJ_REASON;

DROP INDEX @SCHEMA@.WI_EVERYBODY;

DROP INDEX @SCHEMA@.WI_ASSOBJ_QIID;

DROP INDEX @SCHEMA@.COS_PIID;

DROP INDEX @SCHEMA@.CP_COORDHOME;


-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL ,
  TARGET_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T ADD(
  PRIMARY KEY ( MPTID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE UNIQUE INDEX @SCHEMA@.MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  SOURCE_PTID, TARGET_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
  TARGET_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_OID                         RAW(16)              NOT NULL ,
  TARGET_OID                         RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T ADD(
  PRIMARY KEY ( MPTID, SOURCE_OID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
  CGTID                              RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL ,
  MANDATORY                          NUMBER(5,0)          NOT NULL ,
  CHANGES                            CLOB                 NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING
  LOB (CHANGES) STORE AS
  (
    TABLESPACE @TEMPLATE@
    ENABLE STORAGE IN ROW
    NOCACHE
  );

ALTER TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T ADD(
  PRIMARY KEY ( CGTID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  MPTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
  CGTID                              RAW(16)              NOT NULL ,
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL ,
  RELATIONSHIP                       NUMBER(10,0)         NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T ADD(
  PRIMARY KEY ( CGTID, SOURCE_ATID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  MPTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
  MPTID                              RAW(16)              NOT NULL ,
  TARGET_CTID                        RAW(16)              NOT NULL ,
  TARGET_STID                        RAW(16)              NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T ADD(
  PRIMARY KEY ( MPTID, TARGET_CTID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
  RTID                               RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL ,
  BEGIN_ATID                         RAW(16)                       ,
  END_ATID                           RAW(16)                       ,
  REGION_TYPE                        NUMBER(10,0)         NOT NULL ,
  BEGIN_ORDER_NUMBER                 NUMBER(10,0)         NOT NULL ,
  PARENT_RTID                        RAW(16)                       
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.REGION_TEMPLATE_T ADD(
  PRIMARY KEY ( RTID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
  PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
  RTID                               RAW(16)              NOT NULL ,
  CONTAINED_ATID                     RAW(16)              NOT NULL ,
  PTID                               RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T ADD(
  PRIMARY KEY ( RTID, CONTAINED_ATID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
  PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
  PKID                               RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  PROPERTY                           NUMBER(10,0)         NOT NULL ,
  DISPLAY_ID_EXT                     VARCHAR2(32)         NOT NULL ,
  CHANGE_TYPE                        NUMBER(10,0)         NOT NULL ,
  SOURCE_PTID                        RAW(16)              NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.CHANGE_TEMPLATE_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE UNIQUE INDEX @SCHEMA@.CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  MPTID, PROPERTY, DISPLAY_ID_EXT
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
  SOURCE_PTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.PROGRESS_COUNTER_T
(
  PIID                               RAW(16)              NOT NULL ,
  COUNTER                            NUMBER(20,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.PROGRESS_COUNTER_T ADD(
  PRIMARY KEY ( PIID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(
  SIID                               RAW(16)              NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.RELEVANT_SCOPE_ATASK_T ADD(
  PRIMARY KEY ( SIID, TKIID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
  PIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.CONFIG_INFO_T
(
  IDENTIFIER                         VARCHAR2(64)         NOT NULL ,
  DESCRIPTION                        VARCHAR2(128)                 ,
  PROPERTY                           NUMBER(10,0)                  ,
  COUNTER                            NUMBER(20,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.CONFIG_INFO_T ADD(
  PRIMARY KEY ( IDENTIFIER )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.SYNC_T
(
  IDENTIFIER                         VARCHAR2(254)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SYNC_T ADD(
  PRIMARY KEY ( IDENTIFIER )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.MV_CTR_T
(
  ID                                 NUMBER(10,0)         NOT NULL ,
  SELECT_CLAUSE                      VARCHAR2(1024)       NOT NULL ,
  WHERE_CLAUSE                       VARCHAR2(1024)                ,
  ORDER_CLAUSE                       VARCHAR2(512)                 ,
  TBL_SPACE                          VARCHAR2(32)         NOT NULL ,
  UPDATED                            TIMESTAMP            NOT NULL ,
  UPD_STARTED                        TIMESTAMP                     ,
  AVG_UPD_TIME                       NUMBER(20,0)                  ,
  UPD_INTERVAL                       NUMBER(20,0)         NOT NULL ,
  IS_UPDATING                        NUMBER(5,0)          NOT NULL ,
  ACTIVE_MV                          NUMBER(5,0)          NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.MV_CTR_T ADD(
  PRIMARY KEY ( ID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.MV_MODS_T
(
  PKID                               RAW(16)              NOT NULL ,
  OID                                RAW(16)              NOT NULL ,
  MODIFIED                           TIMESTAMP            NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.MV_MODS_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)                       ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  ENGINE_MESSAGE_S                   RAW(2000)                     ,
  ENGINE_MESSAGE_L                   BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.SEM_PIID ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  PIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
  REASON, CREATION_TIME
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T
(
  PKID                               RAW(16)              NOT NULL ,
  SCHEDULED_TIME                     TIMESTAMP            NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.NAVIGATION_CLEANUP_TIMER_B_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.SCHEDULER_ACTION_T
(
  SCHEDULER_ID                       VARCHAR2(254)        NOT NULL ,
  OID                                RAW(16)              NOT NULL ,
  ACTION_OBJECT                      BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCHEDULER_ACTION_T ADD(
  PRIMARY KEY ( SCHEDULER_ID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.SCEACT_OID ON @SCHEMA@.SCHEDULER_ACTION_T
(   
  OID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.QUERY_TABLE_T
(
  NAME                               VARCHAR2(32)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  TYPE                               NUMBER(10,0)         NOT NULL ,
  VERSION                            NUMBER(10,0)         NOT NULL ,
  LAST_UPDATED                       TIMESTAMP            NOT NULL ,
  PRIMARY_VIEW                       VARCHAR2(32)                  ,
  DEFINITION                         BLOB                 NOT NULL ,
  VV_CFG                             BLOB                          ,
  DV_CFG                             BLOB                          ,
  MV_CFG                             BLOB                          ,
  MT_CFG                             BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.QUERY_TABLE_T ADD(
  PRIMARY KEY ( NAME )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.QT_KI ON @SCHEMA@.QUERY_TABLE_T
(   
  KIND
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.QT_TY ON @SCHEMA@.QUERY_TABLE_T
(   
  TYPE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.QUERY_TABLE_REF_T
(
  REFEREE                            VARCHAR2(32)         NOT NULL ,
  SOURCE                             VARCHAR2(32)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.QUERY_TABLE_REF_T ADD(
  PRIMARY KEY ( REFEREE, SOURCE )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.QTR_SRC ON @SCHEMA@.QUERY_TABLE_REF_T
(   
  SOURCE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
  PIID                               RAW(16)              NOT NULL ,
  MPTID                              RAW(16)              NOT NULL ,
  AIID                               RAW(16)              NOT NULL ,
  STATE                              NUMBER(10,0)         NOT NULL ,
  SUB_STATE                          NUMBER(10,0)         NOT NULL ,
  STOP_REASON                        NUMBER(10,0)         NOT NULL ,
  SOURCE_ATID                        RAW(16)              NOT NULL ,
  TARGET_ATID                        RAW(16)              NOT NULL ,
  MIGRATION_TIME                     TIMESTAMP            NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.MIGRATION_FRONT_T ADD(
  PRIMARY KEY ( PIID, MPTID, AIID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
  MPTID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
  SIID                               RAW(16)              NOT NULL ,
  PIID                               RAW(16)              NOT NULL ,
  COUNTER                            NUMBER(20,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T ADD(
  PRIMARY KEY ( SIID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
  PIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
  QIID                               RAW(16)              NOT NULL ,
  GROUP_NAME                         VARCHAR2(128)        NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.RETRIEVED_GROUP_T ADD(
  PRIMARY KEY ( QIID, GROUP_NAME )
  USING INDEX TABLESPACE @WORKITEM@
);

CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
  WSID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  LAST_CHECK                         TIMESTAMP            NOT NULL ,
  UNUSED                             NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_RETRIEVED_USER           NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_OWNER_ID                 NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_EVERYBODY                NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_GROUP                    NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_RETRIEVED_GROUP          NUMBER(5,0)          NOT NULL ,
  AUTH_INFO_EMPTY                    NUMBER(5,0)          NOT NULL ,
  SHARING_PATTERN                    NUMBER(10,0)         NOT NULL ,
  REASONS                            RAW(32)              NOT NULL ,
  PARAMETER_A                        NUMBER(10,0)                  ,
  PARAMETER_B                        NUMBER(10,0)                  ,
  PARAMETER_C                        NUMBER(10,0)                  ,
  PARAMETER_D                        RAW(16)                       ,
  PARAMETER_E                        TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.WIS_META_DATA_T ADD(
  PRIMARY KEY ( WSID )
  USING INDEX TABLESPACE @WORKITEM@
);

CREATE TABLE @SCHEMA@.WIS_EMPTY_T
(
  WIID                               RAW(16)              NOT NULL ,
  WSID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  WIS_HASH_CODE                      NUMBER(10,0)                  ,
  PARENT_WIID                        RAW(16)                       ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  INHERITED                          NUMBER(5,0)                   ,
  QIID                               RAW(16)                       ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  SHARING_PATTERN                    NUMBER(10,0)         NOT NULL ,
  ACCESS_KEY                         NUMBER(10,0)         NOT NULL ,
  PARAMETER_A                        NUMBER(10,0)                  ,
  PARAMETER_B                        NUMBER(10,0)                  ,
  PARAMETER_C                        NUMBER(10,0)                  ,
  PARAMETER_D                        RAW(16)                       ,
  PARAMETER_E                        TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.WIS_EMPTY_T ADD(
  PRIMARY KEY ( WIID )
  USING INDEX TABLESPACE @WORKITEM@
);

CREATE TABLE @SCHEMA@.SHARED_WORK_ITEM_T
(
  PKID                               RAW(16)              NOT NULL ,
  WIID                               RAW(16)              NOT NULL ,
  PARENT_WIID                        RAW(16)                       ,
  OWNER_ID                           VARCHAR2(128)                 ,
  GROUP_NAME                         VARCHAR2(128)                 ,
  EVERYBODY                          NUMBER(5,0)          NOT NULL ,
  QIID                               RAW(16)                       ,
  OBJECT_TYPE                        NUMBER(10,0)         NOT NULL ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  AUTH_INFO                          NUMBER(10,0)         NOT NULL ,
  SHARING_PATTERN                    NUMBER(10,0)         NOT NULL ,
  ACCESS_KEY                         NUMBER(10,0)         NOT NULL ,
  WSID                               RAW(16)              NOT NULL ,
  HASH_CODE                          NUMBER(10,0)         NOT NULL ,
  WIS_HASH_CODE                      NUMBER(10,0)                  ,
  INHERITED                          NUMBER(5,0)                   ,
  PARAMETER_A                        NUMBER(10,0)                  ,
  PARAMETER_B                        NUMBER(10,0)                  ,
  PARAMETER_C                        NUMBER(10,0)                  ,
  PARAMETER_D                        RAW(16)                       ,
  PARAMETER_E                        TIMESTAMP                     ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @WORKITEM@
  LOGGING;

ALTER TABLE @SCHEMA@.SHARED_WORK_ITEM_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @WORKITEM@
);

CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
  CMTID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  COMPL_CONDITION                    BLOB                          ,
  CRITERION_FOR                      VARCHAR2(254)                 ,
  COMPLETION_NAME                    VARCHAR2(220)                 ,
  IS_DEFAULT_COMPLETION              NUMBER(5,0)          NOT NULL ,
  PREFIX_MAP                         BLOB                          ,
  USE_DEFAULT_RESULT_CONSTRUCT       NUMBER(5,0)          NOT NULL 
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.COMPLETION_TEMPLATE_T ADD(
  PRIMARY KEY ( CMTID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  TKTID, ORDER_NUMBER
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
  RATID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  CMTID                              RAW(16)              NOT NULL ,
  TKTID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  AGGR_PART                          VARCHAR2(254)                 ,
  AGGR_LOCATION                      BLOB                          ,
  AGGR_FUNCTION                      VARCHAR2(254)        NOT NULL ,
  AGGR_CONDITION                     BLOB                          ,
  PREFIX_MAP                         BLOB                          
) TABLESPACE @TEMPLATE@
  LOGGING;

ALTER TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T ADD(
  PRIMARY KEY ( RATID )
  USING INDEX TABLESPACE @TEMPLATE@
);

CREATE INDEX @SCHEMA@.RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CMTID, ORDER_NUMBER, TKTID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE TABLE @SCHEMA@.TASK_HISTORY_T
(
  PKID                               RAW(16)              NOT NULL ,
  EVENT                              NUMBER(10,0)         NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  PARENT_TKIID                       RAW(16)                       ,
  ESIID                              RAW(16)                       ,
  REASON                             NUMBER(10,0)         NOT NULL ,
  EVENT_TIME                         TIMESTAMP            NOT NULL ,
  NEXT_TIME                          TIMESTAMP                     ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  PRINCIPAL                          VARCHAR2(128)        NOT NULL ,
  WORK_ITEM_KIND                     NUMBER(10,0)         NOT NULL ,
  FROM_ID                            VARCHAR2(128)                 ,
  TO_ID                              VARCHAR2(128)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.TASK_HISTORY_T ADD(
  PRIMARY KEY ( PKID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.TH_TKIID ON @SCHEMA@.TASK_HISTORY_T
(   
  TKIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.TH_CTXID ON @SCHEMA@.TASK_HISTORY_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
  CMIID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  COMPL_CONDITION                    BLOB                          ,
  CRITERION_FOR                      VARCHAR2(254)                 ,
  CRITERION_FOR_TIME                 TIMESTAMP                     ,
  COMPLETION_NAME                    VARCHAR2(220)                 ,
  IS_DEFAULT_COMPLETION              NUMBER(5,0)          NOT NULL ,
  PREFIX_MAP                         BLOB                          ,
  USE_DEFAULT_RESULT_CONSTRUCT       NUMBER(5,0)          NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.COMPLETION_INSTANCE_T ADD(
  PRIMARY KEY ( CMIID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  TKIID, ORDER_NUMBER
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
  RAIID                              RAW(16)              NOT NULL ,
  ORDER_NUMBER                       NUMBER(10,0)         NOT NULL ,
  CMIID                              RAW(16)              NOT NULL ,
  TKIID                              RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  AGGR_PART                          VARCHAR2(254)                 ,
  AGGR_LOCATION                      BLOB                          ,
  AGGR_FUNCTION                      VARCHAR2(254)        NOT NULL ,
  AGGR_CONDITION                     BLOB                          ,
  PREFIX_MAP                         BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T ADD(
  PRIMARY KEY ( RAIID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CMIID, ORDER_NUMBER
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
  STMID                              RAW(16)              NOT NULL ,
  RELATED_OID                        RAW(16)              NOT NULL ,
  CONTAINMENT_CONTEXT_ID             RAW(16)              NOT NULL ,
  KIND                               NUMBER(10,0)         NOT NULL ,
  SCHEDULER_ID                       VARCHAR2(254)                 ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  EXPECTED_ARRIVAL_TIME              TIMESTAMP            NOT NULL ,
  MESSAGE                            BLOB                          ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T ADD(
  PRIMARY KEY ( STMID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  RELATED_OID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  SCHEDULER_ID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
  CONTAINMENT_CONTEXT_ID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
  WBID                               RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(254)        NOT NULL ,
  TYPE                               NUMBER(10,0)         NOT NULL ,
  OWNER                              VARCHAR2(128)                 ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)        NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR2(32)                  ,
  CUSTOM_TEXT1                       VARCHAR2(254)                 ,
  CUSTOM_TEXT2                       VARCHAR2(254)                 ,
  CUSTOM_TEXT3                       VARCHAR2(254)                 ,
  CUSTOM_TEXT4                       VARCHAR2(254)                 ,
  CUSTOM_TEXT5                       VARCHAR2(254)                 ,
  CUSTOM_TEXT6                       VARCHAR2(254)                 ,
  CUSTOM_TEXT7                       VARCHAR2(254)                 ,
  CUSTOM_TEXT8                       VARCHAR2(254)                 ,
  EXTENDED_DATA                      BLOB                          ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP            NOT NULL ,
  CREATED_WITH_VERSION               NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_BASKET_T ADD(
  PRIMARY KEY ( WBID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
  NAME
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
  TYPE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
  WBID                               RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_BASKET_LDESC_T ADD(
  PRIMARY KEY ( WBID, LOCALE )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
  SOURCE_WBID                        RAW(16)              NOT NULL ,
  TARGET_WBID                        RAW(16)              NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T ADD(
  PRIMARY KEY ( SOURCE_WBID, TARGET_WBID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
  TARGET_WBID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
  BCID                               RAW(16)              NOT NULL ,
  PARENT_BCID                        RAW(16)                       ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  NAME                               VARCHAR2(254)        NOT NULL ,
  PRIORITY                           NUMBER(10,0)                  ,
  SUBSTITUTION_POLICY                NUMBER(10,0)         NOT NULL ,
  JNDI_NAME_STAFF_PROVIDER           VARCHAR2(254)        NOT NULL ,
  DEFAULT_QUERY_TABLE                VARCHAR2(32)                  ,
  CUSTOM_TEXT1                       VARCHAR2(254)                 ,
  CUSTOM_TEXT2                       VARCHAR2(254)                 ,
  CUSTOM_TEXT3                       VARCHAR2(254)                 ,
  CUSTOM_TEXT4                       VARCHAR2(254)                 ,
  CUSTOM_TEXT5                       VARCHAR2(254)                 ,
  CUSTOM_TEXT6                       VARCHAR2(254)                 ,
  CUSTOM_TEXT7                       VARCHAR2(254)                 ,
  CUSTOM_TEXT8                       VARCHAR2(254)                 ,
  EXTENDED_DATA                      BLOB                          ,
  CREATION_TIME                      TIMESTAMP            NOT NULL ,
  LAST_MODIFICATION_TIME             TIMESTAMP            NOT NULL ,
  CREATED_WITH_VERSION               NUMBER(10,0)         NOT NULL ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.BUSINESS_CATEGORY_T ADD(
  PRIMARY KEY ( BCID )
  USING INDEX TABLESPACE @INSTANCE@
);

CREATE INDEX @SCHEMA@.BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  PARENT_BCID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
  NAME
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
  BCID                               RAW(16)              NOT NULL ,
  LOCALE                             VARCHAR2(32)         NOT NULL ,
  WSID_1                             RAW(16)                       ,
  WSID_1_HC                          NUMBER(10,0)                  ,
  WSID_2                             RAW(16)                       ,
  WSID_2_HC                          NUMBER(10,0)                  ,
  DISPLAY_NAME                       VARCHAR2(64)                  ,
  DESCRIPTION                        VARCHAR2(254)                 ,
  VERSION_ID                         NUMBER(5,0)          NOT NULL 
) TABLESPACE @INSTANCE@
  LOGGING;

ALTER TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T ADD(
  PRIMARY KEY ( BCID, LOCALE )
  USING INDEX TABLESPACE @INSTANCE@
);
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
 ADD 
    EXTENDED_AUTO_DELETE               NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    CONTINUE_ON_ERROR                  NUMBER(5,0)         DEFAULT 1 NOT NULL
 ADD 
    IGNORE_MISSING_DATA                NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    EAR_VERSION                        NUMBER(10,0)        DEFAULT 0 NOT NULL
;

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
 ADD 
    A_TKTID                            RAW(16)             
 ADD 
    IS_IMPLICIT                        NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    HAS_COMPENSATION_HANDLER           NUMBER(5,0)         DEFAULT 1 NOT NULL
;

ALTER TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    EXIT_CONDITION                     NUMBER(10,0)        DEFAULT 1 NOT NULL
 ADD 
    EXIT_CONDITION_NAME                VARCHAR2(254)       
 ADD 
    EXIT_CONDITION_EXECUTE_AT          NUMBER(10,0)        DEFAULT 3 NOT NULL
 ADD 
    SOURCES_TYPE                       NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    TARGETS_TYPE                       NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    PARENT_ATID                        RAW(16)             
 ADD 
    HAS_CROSSING_LINK                  NUMBER(5,0)         
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
 ADD 
    EXIT_EXPRESSION                    CLOB                
 ADD 
    COMPENSATION_ATID                  RAW(16)             
 ADD 
    IS_IN_GFLOW                        NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    IS_REGION_BEGIN                    NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    CORRESPONDING_IORATID              RAW(16)             
 ADD 
    IS_GFLOW                           NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    EXPRESSION_MAP                     BLOB                
 ADD 
    EXIT_EXPRESSION_MAP                BLOB                
 ADD 
    GENERATED_BY                       VARCHAR2(220)       
;

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ADD 
    EXPRESSION_MAP                     BLOB                
 ADD 
    REPEAT_EXPRESSION_MAP              BLOB                
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    FAULT_LINK_SOURCE_ATID             RAW(16)             
 ADD 
    FAULT_LINK_TARGET_ATID             RAW(16)             
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
 ADD 
    EXPRESSION_MAP                     BLOB                
 ADD 
    GENERATED_BY                       VARCHAR2(220)       
 ADD 
    RTID                               RAW(16)             
;

ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
 ADD 
    GENERATED_BY                       VARCHAR2(220)       
 ADD 
    SEQUENCE_NUMBER                    NUMBER(10,0)        DEFAULT 1 NOT NULL
 ADD 
    FROM_VARIABLE_CTID                 RAW(16)             
 ADD 
    FROM_PARAMETER2                    VARCHAR2(254)       
 ADD 
    FROM_PARAMETER3                    BLOB                
 ADD 
    FROM_PARAMETER3_LANGUAGE           NUMBER(10,0)        DEFAULT 1 NOT NULL
 ADD 
    FROM_EXPRESSION_MAP                BLOB                
;

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.ASSIGN_TEMPLATE_B_T
 ADD 
    FROM_EXPRESSION_MAP                BLOB                
 ADD 
    TO_EXPRESSION_MAP                  BLOB                
;

ALTER TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.EHALARM_TEMPLATE_B_T
 ADD 
    EXPRESSION_MAP                     BLOB                
 ADD 
    REPEAT_EXPRESSION_MAP              BLOB                
;

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
;

ALTER TABLE @SCHEMA@.FOR_EACH_TEMPLATE_B_T
 ADD 
    START_COUNTER_EXPRESSION_MAP       BLOB                
 ADD 
    FINAL_COUNTER_EXPRESSION_MAP       BLOB                
 ADD 
    COMPLETION_COND_EXPRESSION_MAP     BLOB                
;

ALTER TABLE @SCHEMA@.STAFF_QUERY_TEMPLATE_T
 ADD 
    STAFF_VERB                         BLOB                
;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    SHARED_PC_ID                       RAW(16)             
 ADD 
    SCHEDULER_TASK_ID                  VARCHAR2(254)       
 ADD 
    RESUMES                            TIMESTAMP           
 ADD 
    PENDING_SKIP_REQUEST               NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    IS_MIGRATED                        NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    UNHANDLED_EXCEPTION                BLOB                
 ADD 
    CREATED_WITH_VERSION               NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
 ADD 
    A_TKIID                            RAW(16)             
 ADD 
    HAS_COMPENSATION_WORK              NUMBER(5,0)         DEFAULT 1 NOT NULL
;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    INVOKED_INSTANCE_ID                RAW(16)             
 ADD 
    INVOKED_INSTANCE_TYPE              NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    STOP_REASON                        NUMBER(10,0)        DEFAULT 1 NOT NULL
 ADD 
    PREVIOUS_STATE                     NUMBER(10,0)        
 ADD 
    SKIP_REQUESTED                     NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    JUMP_TARGET_ATID                   RAW(16)             
 ADD 
    SUB_STATE                          NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    PENDING_REQUEST_DATA               BLOB                
 ADD 
    XTID                               RAW(16)             
 ADD 
    EXPIRATION_COUNTER                 NUMBER(10,0)        
 ADD 
    PREVIOUS_EXPIRATION_DATE           TIMESTAMP           
 ADD 
    TARGET_IORAIID                     RAW(16)             
 ADD 
    DISPLAY_ID_EXT                     VARCHAR2(32)        
 ADD 
    MAX_COMPENSATION_NUMBER            NUMBER(20,0)        
 ADD 
    HAS_WORK_ITEM                      NUMBER(5,0)         
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    ATID                               RAW(16)             
 ADD 
    COMPENSATE_AIID                    RAW(16)             
;

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    DATA_TYPE                          VARCHAR2(254)       
 ADD 
    DATA                               BLOB                
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.PROCESS_CONTEXT_T
 ADD 
    SHARED                             NUMBER(5,0)         
 ADD 
    STARTER_EXPIRES                    TIMESTAMP           
;

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    DATA_TYPE                          VARCHAR2(254)       
 ADD 
    DATA                               BLOB                
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
 ADD 
    PIID                               RAW(16)             
;

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.WORK_ITEM_T
 ADD 
    PARENT_WIID                        RAW(16)             
 ADD 
    AUTH_INFO                          NUMBER(10,0)        DEFAULT 0 NOT NULL
;

ALTER TABLE @SCHEMA@.WI_ASSOC_OID_T
 ADD 
    MIGRATED                           NUMBER(5,0)         DEFAULT 0 NOT NULL
;

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    NORMALIZED                         NUMBER(5,0)         
 ADD 
    DENORMALIZED                       NUMBER(5,0)         
;

ALTER TABLE @SCHEMA@.APPLICATION_COMPONENT_T
 ADD 
    SUBSTITUTION_POLICY                NUMBER(10,0)        DEFAULT 0 NOT NULL
;

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    AUTO_DELETE_MODE                   NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    AUTONOMY                           NUMBER(10,0)        DEFAULT 1 NOT NULL
 ADD 
    PRIORITY_DEFINITION                VARCHAR2(254)       
 ADD 
    SUBSTITUTION_POLICY                NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    ASSIGNMENT_TYPE                    NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    INHERITED_AUTH                     NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    PARALLEL_INHERITED_AUTH            NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    NATIVE_LOOKUP_NAME                 VARCHAR2(254)       
 ADD 
    WORK_BASKET                        VARCHAR2(254)       
 ADD 
    EAR_VERSION                        NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    SCHEMA_VERSION                     NUMBER(10,0)        DEFAULT 0 NOT NULL
;

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
 ADD 
    ESCALATION_TIME                    TIMESTAMP           
;

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    AUTO_DELETE_MODE                   NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    IS_CHILD                           NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    HAS_ESCALATIONS                    NUMBER(5,0)         
 ADD 
    RESUMES                            TIMESTAMP           
 ADD 
    SUBSTITUTION_POLICY                NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    DELETION_TIME                      TIMESTAMP           
 ADD 
    ASSIGNMENT_TYPE                    NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    INHERITED_AUTH                     NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    PARALLEL_INHERITED_AUTH            NUMBER(10,0)        DEFAULT 2 NOT NULL
 ADD 
    INVOKED_INSTANCE_ID                RAW(16)             
 ADD 
    INVOKED_INSTANCE_TYPE              NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    WORK_BASKET                        VARCHAR2(254)       
 ADD 
    IS_READ                            NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    IS_TRANSFERRED_TO_WORK_BASKET      NUMBER(5,0)         DEFAULT 0 NOT NULL
 ADD 
    CREATED_WITH_VERSION               NUMBER(10,0)        DEFAULT 0 NOT NULL
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1                             RAW(16)             
 ADD 
    WSID_1_HC                          NUMBER(10,0)        
 ADD 
    WSID_2                             RAW(16)             
 ADD 
    WSID_2_HC                          NUMBER(10,0)        
;


CREATE INDEX @SCHEMA@.PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
  S_BEAN60_LOOKUP_NAME
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PI_ATID_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, ATID, EHIID, ENCLOSING_FEIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
  ATID, STATE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_PIID_PRIM ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, IS_PRIMARY_EVENT_INSTANCE, STATE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_PIID_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  PIID, VTID, IS_PRIMARY_EVENT_INSTANCE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.EI_STATE_VTID ON @SCHEMA@.EVENT_INSTANCE_B_T
(   
  VTID, STATE, EIID, AIID, PIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.PIA_DATY ON @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
(   
  DATA_TYPE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.AIA_DATY ON @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
(   
  DATA_TYPE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
  PIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.AWI_AIID ON @SCHEMA@.AWAITED_INVOCATION_T
(   
  AIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_ASSOBJ_REASON ON @SCHEMA@.WORK_ITEM_T
(   
  ASSOCIATED_OID, ASSOCIATED_OBJECT_TYPE, REASON, PARENT_WIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_L ON @SCHEMA@.WORK_ITEM_T
(   
  EVERYBODY, GROUP_NAME, OWNER_ID, QIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_U ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, QIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_O ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, OWNER_ID DESC
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_G ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, EVERYBODY
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_R ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, REASON DESC
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_QI_OID_RS_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, REASON, OWNER_ID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_QI_OID_OWN ON @SCHEMA@.WORK_ITEM_T
(   
  QIID, OBJECT_ID, OWNER_ID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_OT_OID_RS ON @SCHEMA@.WORK_ITEM_T
(   
  OBJECT_TYPE, OBJECT_ID, REASON
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_WI_QI ON @SCHEMA@.WORK_ITEM_T
(   
  WIID, QIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, OBJECT_ID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
  PARENT_WIID, QIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WI_AUTH_GR_O_E ON @SCHEMA@.WORK_ITEM_T
(   
  AUTH_INFO, GROUP_NAME, OWNER_ID, EVERYBODY
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WIASS_WI ON @SCHEMA@.WI_ASSOC_OID_T
(   
  WIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.WIASS_MIG ON @SCHEMA@.WI_ASSOC_OID_T
(   
  MIGRATED, WIID, OBJECT_ID, OBJECT_TYPE, ASSOCIATED_OID, REASON
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.RUT_QIID ON @SCHEMA@.RETRIEVED_USER_T
(   
  QIID
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.RUT_OWN_QIDESC ON @SCHEMA@.RETRIEVED_USER_T
(   
  OWNER_ID, QIID DESC
) TABLESPACE @WORKITEM@
  LOGGING;

CREATE INDEX @SCHEMA@.TT_KND_INLN_VAL ON @SCHEMA@.TASK_TEMPLATE_T
(   
  KIND, IS_INLINE, VALID_FROM
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.TT_NATLOOK_ADHOC ON @SCHEMA@.TASK_TEMPLATE_T
(   
  NATIVE_LOOKUP_NAME, IS_AD_HOC
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.TTLD_TT_LOC ON @SCHEMA@.TASK_TEMPL_LDESC_T
(   
  TKTID, LOCALE DESC
) TABLESPACE @TEMPLATE@
  LOGGING;

CREATE INDEX @SCHEMA@.ESI_EST_ESI ON @SCHEMA@.ESCALATION_INSTANCE_T
(   
  ESTID, ESIID
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TI_KND_ST ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKIID, KIND, STATE
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_ST_KND_TI_NAME ON @SCHEMA@.TASK_INSTANCE_T
(   
  STATE, KIND, TKIID, NAME
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TT_KND ON @SCHEMA@.TASK_INSTANCE_T
(   
  TKTID, KIND
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_WOBA ON @SCHEMA@.TASK_INSTANCE_T
(   
  WORK_BASKET
) TABLESPACE @INSTANCE@
  LOGGING;

CREATE INDEX @SCHEMA@.TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
  TYPE
) TABLESPACE @INSTANCE@
  LOGGING;

-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T;

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T;

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID;

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T;

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID;

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T;

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID;

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID IS NULL OR @SCHEMA@.WORK_ITEM_T.EVERYBODY = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_TYPE, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WI_ASSOC_OID_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.WI_ASSOC_OID_T
 WHERE @SCHEMA@.WORK_ITEM_T.WIID = @SCHEMA@.WI_ASSOC_OID_T.WIID AND (@SCHEMA@.WORK_ITEM_T.QIID IS NULL OR @SCHEMA@.WORK_ITEM_T.EVERYBODY = 1)
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_TYPE, @SCHEMA@.WI_ASSOC_OID_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WI_ASSOC_OID_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T, @SCHEMA@.WI_ASSOC_OID_T
 WHERE @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID AND @SCHEMA@.WORK_ITEM_T.WIID = @SCHEMA@.WI_ASSOC_OID_T.WIID;

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T;

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID;

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID;

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T;

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1;

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T;

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID, @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME, @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME, @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_INSTANCE_T.DUE_TIME, @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC, @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED, @SCHEMA@.TASK_INSTANCE_T.IS_INLINE, @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, @SCHEMA@.TASK_INSTANCE_T.KIND, @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME, @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE, @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER, @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.PRIORITY, @SCHEMA@.TASK_INSTANCE_T.START_TIME, @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION, @SCHEMA@.TASK_INSTANCE_T.IS_CHILD, @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID, @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES, @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.IS_READ, @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2
 FROM @SCHEMA@.TASK_INSTANCE_T;

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME, @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME, @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC, @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND, @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM, @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY, @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH, @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET
 FROM @SCHEMA@.TASK_TEMPLATE_T;

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T;

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T;

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T;

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T;

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T;

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T;

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T;

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T;

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T;

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T;

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T;

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T;

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T;

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T;

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID;

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T;

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T;

-- update schema version to: 700
-- (a warning for the following statement can be ignored)
DELETE FROM @SCHEMA@.SCHEMA_VERSION WHERE SCHEMA_VERSION = 700;
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 1 );

COMMIT;
