--
-- Licensed Materials - Property of IBM
-- 5655-FLW (C) Copyright IBM Corporation 2006, 2010.
-- All Rights Reserved.
-- US Government Users Restricted Rights- 
-- Use, duplication or disclosure restricted 
-- by GSA ADP Schedule Contract with IBM Corp.
--
----------------------------------------------------------------------
-- The following variable needs to be changed for customization and
-- before running this script.
-- @SCHEMA@ = Schema (userId) name
----------------------------------------------------------------------
-- Scriptfile to upgrade schema in Microsoft SQL Server
-- Process this script using the isql command line processor
-- example: isql -U<userid> -P<password> -d<databasename> -i upgradeSchema620.sql
--


----------------
-- Drop views --
----------------

DROP VIEW @SCHEMA@.PROCESS_TEMPLATE
go

DROP VIEW @SCHEMA@.PROCESS_TEMPL_ATTR
go

DROP VIEW @SCHEMA@.PROCESS_INSTANCE
go

DROP VIEW @SCHEMA@.PROCESS_ATTRIBUTE
go

DROP VIEW @SCHEMA@.ACTIVITY
go

DROP VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE
go

DROP VIEW @SCHEMA@.EVENT
go

DROP VIEW @SCHEMA@.WORK_ITEM
go

DROP VIEW @SCHEMA@.ACTIVITY_SERVICE
go

DROP VIEW @SCHEMA@.QUERY_PROPERTY
go

DROP VIEW @SCHEMA@.QUERY_PROP_TEMPL
go

DROP VIEW @SCHEMA@.AUDIT_LOG
go

DROP VIEW @SCHEMA@.AUDIT_LOG_B
go

DROP VIEW @SCHEMA@.APPLICATION_COMP
go

DROP VIEW @SCHEMA@.TASK
go

DROP VIEW @SCHEMA@.TASK_TEMPL
go

DROP VIEW @SCHEMA@.ESCALATION
go

DROP VIEW @SCHEMA@.ESC_TEMPL
go

DROP VIEW @SCHEMA@.ESC_TEMPL_DESC
go

DROP VIEW @SCHEMA@.TASK_TEMPL_CPROP
go

DROP VIEW @SCHEMA@.ESC_TEMPL_CPROP
go

DROP VIEW @SCHEMA@.TASK_TEMPL_DESC
go

DROP VIEW @SCHEMA@.TASK_CPROP
go

DROP VIEW @SCHEMA@.TASK_DESC
go

DROP VIEW @SCHEMA@.ESCALATION_CPROP
go

DROP VIEW @SCHEMA@.TASK_HISTORY
go

DROP VIEW @SCHEMA@.ESCALATION_DESC
go

DROP VIEW @SCHEMA@.TASK_AUDIT_LOG
go

------------------
-- Drop indexes --
------------------

DROP INDEX @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T.SEM_REAS
go

DROP INDEX @SCHEMA@.WORK_ITEM_T.WI_PARENT_WIID
go

-------------------
-- Create tables --
-------------------

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    TARGET_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MPTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MIGRATION_PLAN_TEMPLATE_P ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
( 
    MPTID
)
go


CREATE UNIQUE INDEX MPT_PTIDS ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
    SOURCE_PTID, TARGET_PTID
)
go

CREATE INDEX MPT_TPTID ON @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
(   
    TARGET_PTID
)
go

CREATE TABLE @SCHEMA@.IDMAPPING_TEMPLATE_T
(
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_OID                         BINARY(16)                         NOT NULL ,
    TARGET_OID                         BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MPTID, SOURCE_OID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX IDMAPPING_TEMPLATE_P ON @SCHEMA@.IDMAPPING_TEMPLATE_T
( 
    MPTID, SOURCE_OID
)
go


CREATE INDEX IDMT_PTID ON @SCHEMA@.IDMAPPING_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(
    CGTID                              BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    MANDATORY                          SMALLINT                           NOT NULL ,
    CHANGES                            TEXT                               NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CGTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CHANGE_GROUP_TEMPLATE_P ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
( 
    CGTID
)
go


CREATE INDEX CGT_MT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
    MPTID
)
go

CREATE INDEX CGT_PT ON @SCHEMA@.CHANGE_GROUP_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(
    CGTID                              BINARY(16)                         NOT NULL ,
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    RELATIONSHIP                       INTEGER                            NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CGTID, SOURCE_ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CHANGE_GROUP_IMPACT_TEMPLATE_P ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
( 
    CGTID, SOURCE_ATID
)
go


CREATE INDEX CGIT_MT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
    MPTID
)
go

CREATE INDEX CGIT_PT ON @SCHEMA@.CHANGE_GROUP_IMPACT_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(
    MPTID                              BINARY(16)                         NOT NULL ,
    TARGET_CTID                        BINARY(16)                         NOT NULL ,
    TARGET_STID                        BINARY(16)                         NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( MPTID, TARGET_CTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MIGRATION_PLAN_VAR_TEMPLATE_P ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
( 
    MPTID, TARGET_CTID
)
go


CREATE INDEX MPVT_PT ON @SCHEMA@.MIGRATION_PLAN_VAR_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.REGION_TEMPLATE_T
(
    RTID                               BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    BEGIN_ATID                         BINARY(16)                             NULL ,
    END_ATID                           BINARY(16)                             NULL ,
    REGION_TYPE                        INTEGER                            NOT NULL ,
    BEGIN_ORDER_NUMBER                 INTEGER                            NOT NULL ,
    PARENT_RTID                        BINARY(16)                             NULL ,
    PRIMARY KEY NONCLUSTERED ( RTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX REGION_TEMPLATE_P ON @SCHEMA@.REGION_TEMPLATE_T
( 
    RTID
)
go


CREATE INDEX RGT_PTID ON @SCHEMA@.REGION_TEMPLATE_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(
    RTID                               BINARY(16)                         NOT NULL ,
    CONTAINED_ATID                     BINARY(16)                         NOT NULL ,
    PTID                               BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( RTID, CONTAINED_ATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX REGION_CONTENT_TEMPLATE_P ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
( 
    RTID, CONTAINED_ATID
)
go


CREATE INDEX RCT_PTID ON @SCHEMA@.REGION_CONTENT_TEMPLATE_T
(   
    PTID
)
go

CREATE TABLE @SCHEMA@.CHANGE_TEMPLATE_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    PROPERTY                           INTEGER                            NOT NULL ,
    DISPLAY_ID_EXT                     VARCHAR(32)                        NOT NULL ,
    CHANGE_TYPE                        INTEGER                            NOT NULL ,
    SOURCE_PTID                        BINARY(16)                         NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX CHANGE_TEMPLATE_P ON @SCHEMA@.CHANGE_TEMPLATE_T
( 
    PKID
)
go


CREATE UNIQUE INDEX CT_MTPDIS ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
    MPTID, PROPERTY, DISPLAY_ID_EXT
)
go

CREATE INDEX CGT_PTID ON @SCHEMA@.CHANGE_TEMPLATE_T
(   
    SOURCE_PTID
)
go

CREATE TABLE @SCHEMA@.MIGRATION_FRONT_T
(
    PIID                               BINARY(16)                         NOT NULL ,
    MPTID                              BINARY(16)                         NOT NULL ,
    AIID                               BINARY(16)                         NOT NULL ,
    STATE                              INTEGER                            NOT NULL ,
    SUB_STATE                          INTEGER                            NOT NULL ,
    STOP_REASON                        INTEGER                            NOT NULL ,
    SOURCE_ATID                        BINARY(16)                         NOT NULL ,
    TARGET_ATID                        BINARY(16)                         NOT NULL ,
    MIGRATION_TIME                     DATETIME                           NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PIID, MPTID, AIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX MIGRATION_FRONT_P ON @SCHEMA@.MIGRATION_FRONT_T
( 
    PIID, MPTID, AIID
)
go


CREATE INDEX MGF_MPTID ON @SCHEMA@.MIGRATION_FRONT_T
(   
    MPTID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.MIGRATION_FRONT_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(
    SIID                               BINARY(16)                         NOT NULL ,
    PIID                               BINARY(16)                         NOT NULL ,
    COUNTER                            BIGINT                                 NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SCOPE_COMPLETION_COUNTER_P ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
( 
    SIID
)
go


CREATE INDEX SCC_PIID ON @SCHEMA@.SCOPE_COMPLETION_COUNTER_T
(   
    PIID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SCOPE_COMPLETION_COUNTER_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RETRIEVED_GROUP_T
(
    QIID                               BINARY(16)                         NOT NULL ,
    GROUP_NAME                         VARCHAR(128)                       NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( QIID, GROUP_NAME )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RETRIEVED_GROUP_P ON @SCHEMA@.RETRIEVED_GROUP_T
( 
    QIID, GROUP_NAME
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.RETRIEVED_GROUP_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WIS_META_DATA_T
(
    WSID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    LAST_CHECK                         DATETIME                           NOT NULL ,
    UNUSED                             SMALLINT                           NOT NULL ,
    AUTH_INFO_RETRIEVED_USER           SMALLINT                           NOT NULL ,
    AUTH_INFO_OWNER_ID                 SMALLINT                           NOT NULL ,
    AUTH_INFO_EVERYBODY                SMALLINT                           NOT NULL ,
    AUTH_INFO_GROUP                    SMALLINT                           NOT NULL ,
    AUTH_INFO_RETRIEVED_GROUP          SMALLINT                           NOT NULL ,
    AUTH_INFO_EMPTY                    SMALLINT                           NOT NULL ,
    SHARING_PATTERN                    INTEGER                            NOT NULL ,
    REASONS                            BINARY(32)                         NOT NULL ,
    PARAMETER_A                        INTEGER                                NULL ,
    PARAMETER_B                        INTEGER                                NULL ,
    PARAMETER_C                        INTEGER                                NULL ,
    PARAMETER_D                        BINARY(16)                             NULL ,
    PARAMETER_E                        DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WSID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WIS_META_DATA_P ON @SCHEMA@.WIS_META_DATA_T
( 
    WSID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.WIS_META_DATA_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WIS_EMPTY_T
(
    WIID                               BINARY(16)                         NOT NULL ,
    WSID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    WIS_HASH_CODE                      INTEGER                                NULL ,
    PARENT_WIID                        BINARY(16)                             NULL ,
    REASON                             INTEGER                            NOT NULL ,
    INHERITED                          SMALLINT                               NULL ,
    QIID                               BINARY(16)                             NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    SHARING_PATTERN                    INTEGER                            NOT NULL ,
    ACCESS_KEY                         INTEGER                            NOT NULL ,
    PARAMETER_A                        INTEGER                                NULL ,
    PARAMETER_B                        INTEGER                                NULL ,
    PARAMETER_C                        INTEGER                                NULL ,
    PARAMETER_D                        BINARY(16)                             NULL ,
    PARAMETER_E                        DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WIS_EMPTY_P ON @SCHEMA@.WIS_EMPTY_T
( 
    WIID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.WIS_EMPTY_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SHARED_WORK_ITEM_T
(
    PKID                               BINARY(16)                         NOT NULL ,
    WIID                               BINARY(16)                         NOT NULL ,
    PARENT_WIID                        BINARY(16)                             NULL ,
    OWNER_ID                           VARCHAR(128)                           NULL ,
    GROUP_NAME                         VARCHAR(128)                           NULL ,
    EVERYBODY                          SMALLINT                           NOT NULL ,
    QIID                               BINARY(16)                             NULL ,
    OBJECT_TYPE                        INTEGER                            NOT NULL ,
    REASON                             INTEGER                            NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    AUTH_INFO                          INTEGER                            NOT NULL ,
    SHARING_PATTERN                    INTEGER                            NOT NULL ,
    ACCESS_KEY                         INTEGER                            NOT NULL ,
    WSID                               BINARY(16)                         NOT NULL ,
    HASH_CODE                          INTEGER                            NOT NULL ,
    WIS_HASH_CODE                      INTEGER                                NULL ,
    INHERITED                          SMALLINT                               NULL ,
    PARAMETER_A                        INTEGER                                NULL ,
    PARAMETER_B                        INTEGER                                NULL ,
    PARAMETER_C                        INTEGER                                NULL ,
    PARAMETER_D                        BINARY(16)                             NULL ,
    PARAMETER_E                        DATETIME                               NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( PKID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SHARED_WORK_ITEM_P ON @SCHEMA@.SHARED_WORK_ITEM_T
( 
    PKID
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.SHARED_WORK_ITEM_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.COMPLETION_TEMPLATE_T
(
    CMTID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    COMPL_CONDITION                    IMAGE                                  NULL ,
    CRITERION_FOR                      VARCHAR(254)                           NULL ,
    COMPLETION_NAME                    VARCHAR(220)                           NULL ,
    IS_DEFAULT_COMPLETION              SMALLINT                           NOT NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CMTID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX COMPLETION_TEMPLATE_P ON @SCHEMA@.COMPLETION_TEMPLATE_T
( 
    CMTID
)
go


CREATE INDEX CMPT_TKTID_ORDER ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
    TKTID, ORDER_NUMBER
)
go

CREATE INDEX CMPT_CCID ON @SCHEMA@.COMPLETION_TEMPLATE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(
    RATID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    CMTID                              BINARY(16)                         NOT NULL ,
    TKTID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    AGGR_PART                          VARCHAR(254)                           NULL ,
    AGGR_LOCATION                      IMAGE                                  NULL ,
    AGGR_FUNCTION                      VARCHAR(254)                       NOT NULL ,
    AGGR_CONDITION                     IMAGE                                  NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    PRIMARY KEY NONCLUSTERED ( RATID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RESULT_AGGREGATION_TEMPLATE_P ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
( 
    RATID
)
go


CREATE INDEX RAGT_CMTID_ORD_TT ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
    CMTID, ORDER_NUMBER, TKTID
)
go

CREATE INDEX RAGT_CCID ON @SCHEMA@.RESULT_AGGREGATION_TEMPLATE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

CREATE TABLE @SCHEMA@.COMPLETION_INSTANCE_T
(
    CMIID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    COMPL_CONDITION                    IMAGE                                  NULL ,
    CRITERION_FOR                      VARCHAR(254)                           NULL ,
    CRITERION_FOR_TIME                 DATETIME                               NULL ,
    COMPLETION_NAME                    VARCHAR(220)                           NULL ,
    IS_DEFAULT_COMPLETION              SMALLINT                           NOT NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    USE_DEFAULT_RESULT_CONSTRUCT       SMALLINT                           NOT NULL ,
    SCHEDULER_ID                       VARCHAR(254)                           NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( CMIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX COMPLETION_INSTANCE_P ON @SCHEMA@.COMPLETION_INSTANCE_T
( 
    CMIID
)
go


CREATE INDEX CMPI_TKIID_ORDER ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
    TKIID, ORDER_NUMBER
)
go

CREATE INDEX CMPI_CCID ON @SCHEMA@.COMPLETION_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.COMPLETION_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(
    RAIID                              BINARY(16)                         NOT NULL ,
    ORDER_NUMBER                       INTEGER                            NOT NULL ,
    CMIID                              BINARY(16)                         NOT NULL ,
    TKIID                              BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    AGGR_PART                          VARCHAR(254)                           NULL ,
    AGGR_LOCATION                      IMAGE                                  NULL ,
    AGGR_FUNCTION                      VARCHAR(254)                       NOT NULL ,
    AGGR_CONDITION                     IMAGE                                  NULL ,
    PREFIX_MAP                         IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( RAIID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX RESULT_AGGREGATION_INSTANCE_P ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
( 
    RAIID
)
go


CREATE INDEX RAGI_CMIID_ORDER ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
    CMIID, ORDER_NUMBER
)
go

CREATE INDEX RAGI_CCID ON @SCHEMA@.RESULT_AGGREGATION_INSTANCE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.RESULT_AGGREGATION_INSTANCE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.SAVED_TASK_MESSAGE_T
(
    STMID                              BINARY(16)                         NOT NULL ,
    RELATED_OID                        BINARY(16)                         NOT NULL ,
    CONTAINMENT_CONTEXT_ID             BINARY(16)                         NOT NULL ,
    KIND                               INTEGER                            NOT NULL ,
    SCHEDULER_ID                       VARCHAR(254)                           NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    EXPECTED_ARRIVAL_TIME              DATETIME                           NOT NULL ,
    MESSAGE                            IMAGE                                  NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( STMID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX SAVED_TASK_MESSAGE_P ON @SCHEMA@.SAVED_TASK_MESSAGE_T
( 
    STMID
)
go


CREATE INDEX STM_ROID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
    RELATED_OID
)
go

CREATE INDEX STM_SID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
    SCHEDULER_ID
)
go

CREATE INDEX STM_CTXID ON @SCHEMA@.SAVED_TASK_MESSAGE_T
(   
    CONTAINMENT_CONTEXT_ID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.SAVED_TASK_MESSAGE_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_BASKET_T
(
    WBID                               BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    NAME                               VARCHAR(254)                       NOT NULL ,
    TYPE                               INTEGER                            NOT NULL ,
    OWNER                              VARCHAR(128)                           NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                       NOT NULL ,
    DEFAULT_QUERY_TABLE                VARCHAR(32)                            NULL ,
    CUSTOM_TEXT1                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT2                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT3                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT4                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT5                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT6                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT7                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT8                       VARCHAR(254)                           NULL ,
    EXTENDED_DATA                      IMAGE                                  NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    LAST_MODIFICATION_TIME             DATETIME                           NOT NULL ,
    CREATED_WITH_VERSION               INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WBID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_BASKET_P ON @SCHEMA@.WORK_BASKET_T
( 
    WBID
)
go


CREATE INDEX WBK_NAME ON @SCHEMA@.WORK_BASKET_T
(   
    NAME
)
go

CREATE INDEX WBK_TYPE ON @SCHEMA@.WORK_BASKET_T
(   
    TYPE
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.WORK_BASKET_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_BASKET_LDESC_T
(
    WBID                               BINARY(16)                         NOT NULL ,
    LOCALE                             VARCHAR(32)                        NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    DISPLAY_NAME                       VARCHAR(64)                            NULL ,
    DESCRIPTION                        VARCHAR(254)                           NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( WBID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_BASKET_LDESC_P ON @SCHEMA@.WORK_BASKET_LDESC_T
( 
    WBID, LOCALE
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.WORK_BASKET_LDESC_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(
    SOURCE_WBID                        BINARY(16)                         NOT NULL ,
    TARGET_WBID                        BINARY(16)                         NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( SOURCE_WBID, TARGET_WBID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX WORK_BASKET_DIST_TARGET_P ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
( 
    SOURCE_WBID, TARGET_WBID
)
go


CREATE INDEX WBDT_TWB ON @SCHEMA@.WORK_BASKET_DIST_TARGET_T
(   
    TARGET_WBID
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.WORK_BASKET_DIST_TARGET_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_T
(
    BCID                               BINARY(16)                         NOT NULL ,
    PARENT_BCID                        BINARY(16)                             NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    NAME                               VARCHAR(254)                       NOT NULL ,
    PRIORITY                           INTEGER                                NULL ,
    SUBSTITUTION_POLICY                INTEGER                            NOT NULL ,
    JNDI_NAME_STAFF_PROVIDER           VARCHAR(254)                       NOT NULL ,
    DEFAULT_QUERY_TABLE                VARCHAR(32)                            NULL ,
    CUSTOM_TEXT1                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT2                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT3                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT4                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT5                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT6                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT7                       VARCHAR(254)                           NULL ,
    CUSTOM_TEXT8                       VARCHAR(254)                           NULL ,
    EXTENDED_DATA                      IMAGE                                  NULL ,
    CREATION_TIME                      DATETIME                           NOT NULL ,
    LAST_MODIFICATION_TIME             DATETIME                           NOT NULL ,
    CREATED_WITH_VERSION               INTEGER                            NOT NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( BCID )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX BUSINESS_CATEGORY_P ON @SCHEMA@.BUSINESS_CATEGORY_T
( 
    BCID
)
go


CREATE INDEX BCG_PARENTBCID ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
    PARENT_BCID
)
go

CREATE INDEX BCG_NAME ON @SCHEMA@.BUSINESS_CATEGORY_T
(   
    NAME
)
go

-- disable page locks
sp_indexoption '@SCHEMA@.BUSINESS_CATEGORY_T', 'AllowPageLocks', FALSE
go


CREATE TABLE @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
(
    BCID                               BINARY(16)                         NOT NULL ,
    LOCALE                             VARCHAR(32)                        NOT NULL ,
    WSID_1                             BINARY(16)                             NULL ,
    WSID_1_HC                          INTEGER                                NULL ,
    WSID_2                             BINARY(16)                             NULL ,
    WSID_2_HC                          INTEGER                                NULL ,
    DISPLAY_NAME                       VARCHAR(64)                            NULL ,
    DESCRIPTION                        VARCHAR(254)                           NULL ,
    VERSION_ID                         SMALLINT                           NOT NULL ,
    PRIMARY KEY NONCLUSTERED ( BCID, LOCALE )
)
go

-- index for primary key is not generated by default ...
CREATE INDEX BUSINESS_CATEGORY_LDESC_P ON @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
( 
    BCID, LOCALE
)
go


-- disable page locks
sp_indexoption '@SCHEMA@.BUSINESS_CATEGORY_LDESC_T', 'AllowPageLocks', FALSE
go

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_B_T
 ADD 
    EAR_VERSION                        INTEGER                            DEFAULT 0 NOT NULL
go

ALTER TABLE @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go
ALTER TABLE @SCHEMA@.SCOPE_TEMPLATE_B_T
 ADD 
    HAS_COMPENSATION_HANDLER           SMALLINT                           DEFAULT 1 NOT NULL
go

ALTER TABLE @SCHEMA@.ACTIVITY_SERVICE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    COMPENSATION_ATID                  BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_IN_GFLOW                        SMALLINT                           DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_REGION_BEGIN                    SMALLINT                           DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    CORRESPONDING_IORATID              BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 ADD 
    IS_GFLOW                           SMALLINT                           DEFAULT 0 NOT NULL
go

ALTER TABLE @SCHEMA@.ALARM_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.FAULT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go
ALTER TABLE @SCHEMA@.LINK_TEMPLATE_B_T
 ADD 
    RTID                               BINARY(16)                             NULL 
go

ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    SEQUENCE_NUMBER                    INTEGER                            DEFAULT 1 NOT NULL
go
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_VARIABLE_CTID                 BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER2                    VARCHAR(254)                           NULL 
go
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER3                    IMAGE                                  NULL 
go
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_PARAMETER3_LANGUAGE           INTEGER                            DEFAULT 1 NOT NULL
go
ALTER TABLE @SCHEMA@.VARIABLE_TEMPLATE_B_T
 ADD 
    FROM_EXPRESSION_MAP                IMAGE                                  NULL 
go

ALTER TABLE @SCHEMA@.PARTNER_LINK_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.CORRELATION_SET_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.EVENT_HANDLER_TEMPLATE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.ACTIVITY_TEMPLATE_ATTR_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    SHARED_PC_ID                       BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    IS_MIGRATED                        SMALLINT                           DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    CREATED_WITH_VERSION               INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.SCOPE_INSTANCE_B_T
 ADD 
    HAS_COMPENSATION_WORK              SMALLINT                           DEFAULT 1 NOT NULL
go

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    SUB_STATE                          INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PENDING_REQUEST_DATA               IMAGE                                  NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    XTID                               BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    EXPIRATION_COUNTER                 INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    PREVIOUS_EXPIRATION_DATE           DATETIME                               NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    TARGET_IORAIID                     BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    DISPLAY_ID_EXT                     VARCHAR(32)                            NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    MAX_COMPENSATION_NUMBER            BIGINT                                 NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    HAS_WORK_ITEM                      SMALLINT                               NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.EVENT_INSTANCE_B_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    ATID                               BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.COMP_PARENT_ACTIVITY_INST_B_T
 ADD 
    COMPENSATE_AIID                    BINARY(16)                             NULL 
go

ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.PROCESS_CONTEXT_T
 ADD 
    SHARED                             SMALLINT                               NULL 
go

ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.NAVIGATION_EXCEPTION_T
 ADD 
    PIID                               BINARY(16)                             NULL 
go

ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    NORMALIZED                         SMALLINT                               NULL 
go
ALTER TABLE @SCHEMA@.STAFF_QUERY_INSTANCE_T
 ADD 
    DENORMALIZED                       SMALLINT                               NULL 
go

ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    ASSIGNMENT_TYPE                    INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    INHERITED_AUTH                     INTEGER                            DEFAULT 2 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    PARALLEL_INHERITED_AUTH            INTEGER                            DEFAULT 2 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    NATIVE_LOOKUP_NAME                 VARCHAR(254)                           NULL 
go
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    WORK_BASKET                        VARCHAR(254)                           NULL 
go
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    EAR_VERSION                        INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_TEMPLATE_T
 ADD 
    SCHEMA_VERSION                     INTEGER                            DEFAULT 0 NOT NULL
go

ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ESCALATION_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ESC_INST_CPROP_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.ESC_INST_LDESC_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    ASSIGNMENT_TYPE                    INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INHERITED_AUTH                     INTEGER                            DEFAULT 2 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    PARALLEL_INHERITED_AUTH            INTEGER                            DEFAULT 2 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INVOKED_INSTANCE_ID                BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    INVOKED_INSTANCE_TYPE              INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WORK_BASKET                        VARCHAR(254)                           NULL 
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_READ                            SMALLINT                           DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    IS_TRANSFERRED_TO_WORK_BASKET      SMALLINT                           DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    CREATED_WITH_VERSION               INTEGER                            DEFAULT 0 NOT NULL
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INSTANCE_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INST_CPROP_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_INST_LDESC_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go

ALTER TABLE @SCHEMA@.TASK_HISTORY_T
 ADD 
    WSID_1                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_HISTORY_T
 ADD 
    WSID_1_HC                          INTEGER                                NULL 
go
ALTER TABLE @SCHEMA@.TASK_HISTORY_T
 ADD 
    WSID_2                             BINARY(16)                             NULL 
go
ALTER TABLE @SCHEMA@.TASK_HISTORY_T
 ADD 
    WSID_2_HC                          INTEGER                                NULL 
go


CREATE INDEX PTB_SBLKN ON @SCHEMA@.PROCESS_TEMPLATE_B_T
(   
    S_BEAN60_LOOKUP_NAME
)
go

CREATE INDEX AIB_PI_DIS_EH_FE ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    PIID, DISPLAY_ID_EXT, EHIID, ENCLOSING_FEIID
)
go

CREATE INDEX AIB_ATID_STAT ON @SCHEMA@.ACTIVITY_INSTANCE_B_T
(   
    ATID, STATE
)
go

CREATE INDEX RSAT_PIID ON @SCHEMA@.RELEVANT_SCOPE_ATASK_T
(   
    PIID
)
go

CREATE INDEX NE_PIID ON @SCHEMA@.NAVIGATION_EXCEPTION_T
(   
    PIID
)
go

CREATE INDEX SEM_REAS ON @SCHEMA@.SAVED_ENGINE_MESSAGE_B_T
(   
    REASON, CREATION_TIME
)
go

CREATE INDEX WI_PWIID_OID ON @SCHEMA@.WORK_ITEM_T
(   
    PARENT_WIID, OBJECT_ID
)
go

CREATE INDEX WI_PWIID_QIID ON @SCHEMA@.WORK_ITEM_T
(   
    PARENT_WIID, QIID
)
go

CREATE INDEX TT_NATLOOK_ADHOC ON @SCHEMA@.TASK_TEMPLATE_T
(   
    NATIVE_LOOKUP_NAME, IS_AD_HOC
)
go

CREATE INDEX TI_WOBA ON @SCHEMA@.TASK_INSTANCE_T
(   
    WORK_BASKET
)
go

CREATE INDEX TI_TYPE ON @SCHEMA@.TASK_INSTANCE_T
(   
    TYPE
)
go

-- View: ProcessTemplate
CREATE VIEW @SCHEMA@.PROCESS_TEMPLATE(PTID, NAME, DISPLAY_NAME, VALID_FROM, TARGET_NAMESPACE, APPLICATION_NAME, VERSION, CREATED, STATE, EXECUTION_MODE, DESCRIPTION, CAN_RUN_SYNC, CAN_RUN_INTERRUP, COMP_SPHERE, CONTINUE_ON_ERROR ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DISPLAY_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VALID_FROM, @SCHEMA@.PROCESS_TEMPLATE_B_T.TARGET_NAMESPACE, @SCHEMA@.PROCESS_TEMPLATE_B_T.APPLICATION_NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.VERSION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CREATED, @SCHEMA@.PROCESS_TEMPLATE_B_T.STATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.EXECUTION_MODE, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_CALL, @SCHEMA@.PROCESS_TEMPLATE_B_T.CAN_INITIATE, @SCHEMA@.PROCESS_TEMPLATE_B_T.COMPENSATION_SPHERE, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR
 FROM @SCHEMA@.PROCESS_TEMPLATE_B_T
go

-- View: ProcessTemplAttr
CREATE VIEW @SCHEMA@.PROCESS_TEMPL_ATTR(PTID, NAME, VALUE ) AS
 SELECT @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.PTID, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.ATTR_KEY, @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T.VALUE
 FROM @SCHEMA@.PROCESS_TEMPLATE_ATTRIBUTE_B_T
go

-- View: ProcessInstance
CREATE VIEW @SCHEMA@.PROCESS_INSTANCE(PTID, PIID, NAME, STATE, CREATED, STARTED, COMPLETED, PARENT_NAME, TOP_LEVEL_NAME, PARENT_PIID, TOP_LEVEL_PIID, STARTER, DESCRIPTION, TEMPLATE_NAME, TEMPLATE_DESCR, RESUMES, CONTINUE_ON_ERROR, IS_MIGRATED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_B_T.PTID, @SCHEMA@.PROCESS_INSTANCE_B_T.PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.STATE, @SCHEMA@.PROCESS_INSTANCE_B_T.CREATED, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTED, @SCHEMA@.PROCESS_INSTANCE_B_T.COMPLETED, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_NAME, @SCHEMA@.PROCESS_INSTANCE_B_T.PARENT_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.TOP_LEVEL_PIID, @SCHEMA@.PROCESS_INSTANCE_B_T.STARTER, @SCHEMA@.PROCESS_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_TEMPLATE_B_T.NAME, @SCHEMA@.PROCESS_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.PROCESS_INSTANCE_B_T.RESUMES, @SCHEMA@.PROCESS_TEMPLATE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.PROCESS_INSTANCE_B_T.IS_MIGRATED, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_B_T, @SCHEMA@.PROCESS_TEMPLATE_B_T
 WHERE @SCHEMA@.PROCESS_INSTANCE_B_T.PTID = @SCHEMA@.PROCESS_TEMPLATE_B_T.PTID
go

-- View: ProcessAttribute
CREATE VIEW @SCHEMA@.PROCESS_ATTRIBUTE(PIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.PIID, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.ATTR_KEY, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.VALUE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.DATA_TYPE, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_1, @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T.WSID_2
 FROM @SCHEMA@.PROCESS_INSTANCE_ATTRIBUTE_T
go

-- View: Activity
CREATE VIEW @SCHEMA@.ACTIVITY(PIID, AIID, PTID, ATID, SIID, STID, EHIID, ENCLOSING_FEIID, KIND, COMPLETED, ACTIVATED, FIRST_ACTIVATED, STARTED, STATE, SUB_STATE, STOP_REASON, OWNER, DESCRIPTION, EXPIRES, TEMPLATE_NAME, TEMPLATE_DESCR, BUSINESS_RELEVANCE, SKIP_REQUESTED, CONTINUE_ON_ERROR, INVOKED_INST_ID, INVOKED_INST_TYPE, PREVIOUS_EXPIRATION_TIME, HAS_WORK_ITEM, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_B_T.PIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PTID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.PARENT_STID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EHIID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ENCLOSING_FEIID, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.KIND, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FINISHED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.FIRST_ACTIVATED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STARTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SUB_STATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.STOP_REASON, @SCHEMA@.ACTIVITY_INSTANCE_B_T.OWNER, @SCHEMA@.ACTIVITY_INSTANCE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_INSTANCE_B_T.EXPIRES, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.NAME, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.DESCRIPTION, @SCHEMA@.ACTIVITY_TEMPLATE_B_T.BUSINESS_RELEVANCE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.SKIP_REQUESTED, @SCHEMA@.ACTIVITY_INSTANCE_B_T.CONTINUE_ON_ERROR, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_ID, @SCHEMA@.ACTIVITY_INSTANCE_B_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.PREVIOUS_EXPIRATION_DATE, @SCHEMA@.ACTIVITY_INSTANCE_B_T.HAS_WORK_ITEM, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_B_T, @SCHEMA@.ACTIVITY_TEMPLATE_B_T
 WHERE @SCHEMA@.ACTIVITY_INSTANCE_B_T.ATID = @SCHEMA@.ACTIVITY_TEMPLATE_B_T.ATID
go

-- View: ActivityAttribute
CREATE VIEW @SCHEMA@.ACTIVITY_ATTRIBUTE(AIID, NAME, VALUE, DATA_TYPE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.AIID, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_KEY, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.ATTR_VALUE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.DATA_TYPE, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_1, @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T.WSID_2
 FROM @SCHEMA@.ACTIVITY_INSTANCE_ATTR_B_T
go

-- View: Event
CREATE VIEW @SCHEMA@.EVENT(EIID, AIID, PIID, EHTID, SIID, NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.EHTID, @SCHEMA@.EVENT_INSTANCE_B_T.SIID, @SCHEMA@.SERVICE_TEMPLATE_B_T.NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID
go

-- View: WorkItem
CREATE VIEW @SCHEMA@.WORK_ITEM(WIID, OWNER_ID, GROUP_NAME, EVERYBODY, OBJECT_TYPE, OBJECT_ID, ASSOC_OBJECT_TYPE, ASSOC_OID, REASON, CREATION_TIME, QIID, KIND ) AS
 SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 1
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 2
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.WORK_ITEM_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 3
 UNION ALL SELECT @SCHEMA@.WORK_ITEM_T.WIID, @SCHEMA@.RETRIEVED_USER_T.OWNER_ID, @SCHEMA@.WORK_ITEM_T.GROUP_NAME, @SCHEMA@.WORK_ITEM_T.EVERYBODY, @SCHEMA@.WORK_ITEM_T.OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.OBJECT_ID, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OBJECT_TYPE, @SCHEMA@.WORK_ITEM_T.ASSOCIATED_OID, @SCHEMA@.WORK_ITEM_T.REASON, @SCHEMA@.WORK_ITEM_T.CREATION_TIME, @SCHEMA@.WORK_ITEM_T.QIID, @SCHEMA@.WORK_ITEM_T.KIND
 FROM @SCHEMA@.WORK_ITEM_T, @SCHEMA@.RETRIEVED_USER_T
 WHERE @SCHEMA@.WORK_ITEM_T.AUTH_INFO = 0 AND @SCHEMA@.WORK_ITEM_T.QIID = @SCHEMA@.RETRIEVED_USER_T.QIID
go

-- View: ActivityService
CREATE VIEW @SCHEMA@.ACTIVITY_SERVICE(EIID, AIID, PIID, VTID, PORT_TYPE, NAME_SPACE_URI, OPERATION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.EVENT_INSTANCE_B_T.EIID, @SCHEMA@.EVENT_INSTANCE_B_T.AIID, @SCHEMA@.EVENT_INSTANCE_B_T.PIID, @SCHEMA@.EVENT_INSTANCE_B_T.VTID, @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_NAME,@SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.SERVICE_TEMPLATE_B_T.OPERATION_NAME, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_1, @SCHEMA@.EVENT_INSTANCE_B_T.WSID_2
 FROM @SCHEMA@.EVENT_INSTANCE_B_T, @SCHEMA@.SERVICE_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.EVENT_INSTANCE_B_T.STATE = 2 AND @SCHEMA@.EVENT_INSTANCE_B_T.VTID = @SCHEMA@.SERVICE_TEMPLATE_B_T.VTID AND @SCHEMA@.SERVICE_TEMPLATE_B_T.PORT_TYPE_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID
go

-- View: QueryProperty
CREATE VIEW @SCHEMA@.QUERY_PROPERTY(PIID, VARIABLE_NAME, NAME, NAMESPACE, GENERIC_VALUE, STRING_VALUE, NUMBER_VALUE, DECIMAL_VALUE, TIMESTAMP_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PIID, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.VARIABLE_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAME, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.PROPERTY_NAMESPACE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.GENERIC_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.STRING_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.NUMBER_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.DECIMAL_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.TIMESTAMP_VALUE, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_1, @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T.WSID_2
 FROM @SCHEMA@.QUERYABLE_VARIABLE_INSTANCE_T
go

-- View: QueryPropTempl
CREATE VIEW @SCHEMA@.QUERY_PROP_TEMPL(PTID, NAME, PROPERTY_NAME, URI, QUERY_TYPE, JAVA_TYPE ) AS
 SELECT @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PTID, @SCHEMA@.VARIABLE_TEMPLATE_B_T.NAME, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_NAME, @SCHEMA@.URI_TEMPLATE_B_T.URI, @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.QUERY_TYPE, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.JAVA_TYPE
 FROM @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T, @SCHEMA@.VARIABLE_TEMPLATE_B_T, @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T, @SCHEMA@.URI_TEMPLATE_B_T
 WHERE @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.CTID = @SCHEMA@.VARIABLE_TEMPLATE_B_T.CTID AND @SCHEMA@.QUERYABLE_VARIABLE_TEMPLATE_T.PAID = @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PAID AND @SCHEMA@.PROPERTY_ALIAS_TEMPLATE_B_T.PROPERTY_UTID = @SCHEMA@.URI_TEMPLATE_B_T.UTID
go

-- View: MigrationFront
CREATE VIEW @SCHEMA@.MIGRATION_FRONT(PIID, AIID, SOURCE_PTID, TARGET_PTID, STATE, SUB_STATE, STOP_REASON, SOURCE_ATID, TARGET_ATID, MIGRATION_TIME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.MIGRATION_FRONT_T.PIID, @SCHEMA@.MIGRATION_FRONT_T.AIID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.SOURCE_PTID, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.TARGET_PTID, @SCHEMA@.MIGRATION_FRONT_T.STATE, @SCHEMA@.MIGRATION_FRONT_T.SUB_STATE, @SCHEMA@.MIGRATION_FRONT_T.STOP_REASON, @SCHEMA@.MIGRATION_FRONT_T.SOURCE_ATID, @SCHEMA@.MIGRATION_FRONT_T.TARGET_ATID, @SCHEMA@.MIGRATION_FRONT_T.MIGRATION_TIME, @SCHEMA@.MIGRATION_FRONT_T.WSID_1, @SCHEMA@.MIGRATION_FRONT_T.WSID_2
 FROM @SCHEMA@.MIGRATION_FRONT_T, @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T
 WHERE @SCHEMA@.MIGRATION_FRONT_T.MPTID = @SCHEMA@.MIGRATION_PLAN_TEMPLATE_T.MPTID
go

-- View: AuditLog
CREATE VIEW @SCHEMA@.AUDIT_LOG(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, SCOPE_NAME, PROCESS_TEMPL_NAME, PROCESS_INST_NAME, TOP_LEVEL_PI_NAME, TOP_LEVEL_PIID, PARENT_PI_NAME, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, IMPL_NAME, PRINCIPAL, TERMINAL_NAME, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ATID, ADDITIONAL_INFO, OBJECT_META_TYPE ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.PROCESS_INST_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PI_NAME,@SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PI_NAME,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.IMPL_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.TERMINAL_NAME,@SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO, @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE
 FROM @SCHEMA@.AUDIT_LOG_T
go

-- View: AuditLogB
CREATE VIEW @SCHEMA@.AUDIT_LOG_B(ALID, EVENT_TIME, EVENT_TIME_UTC, AUDIT_EVENT, PTID, PIID, AIID, SIID, VARIABLE_NAME, PROCESS_TEMPL_NAME, TOP_LEVEL_PIID, PARENT_PIID, VALID_FROM, VALID_FROM_UTC, ATID, ACTIVITY_NAME, ACTIVITY_KIND, ACTIVITY_STATE, CONTROL_LINK_NAME, PRINCIPAL, VARIABLE_DATA, EXCEPTION_TEXT, DESCRIPTION, CORR_SET_INFO, USER_NAME, ADDITIONAL_INFO ) AS
 SELECT @SCHEMA@.AUDIT_LOG_T.ALID,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME,@SCHEMA@.AUDIT_LOG_T.EVENT_TIME_UTC,@SCHEMA@.AUDIT_LOG_T.AUDIT_EVENT,@SCHEMA@.AUDIT_LOG_T.PTID,@SCHEMA@.AUDIT_LOG_T.PIID,@SCHEMA@.AUDIT_LOG_T.AIID,@SCHEMA@.AUDIT_LOG_T.SIID,@SCHEMA@.AUDIT_LOG_T.VARIABLE_NAME,@SCHEMA@.AUDIT_LOG_T.PROCESS_TEMPL_NAME, @SCHEMA@.AUDIT_LOG_T.TOP_LEVEL_PIID,@SCHEMA@.AUDIT_LOG_T.PARENT_PIID,@SCHEMA@.AUDIT_LOG_T.VALID_FROM,@SCHEMA@.AUDIT_LOG_T.VALID_FROM_UTC,@SCHEMA@.AUDIT_LOG_T.ATID, @SCHEMA@.AUDIT_LOG_T.ACTIVITY_NAME,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_KIND,@SCHEMA@.AUDIT_LOG_T.ACTIVITY_STATE,@SCHEMA@.AUDIT_LOG_T.CONTROL_LINK_NAME,@SCHEMA@.AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.AUDIT_LOG_T.VARIABLE_DATA,@SCHEMA@.AUDIT_LOG_T.EXCEPTION_TEXT,@SCHEMA@.AUDIT_LOG_T.DESCRIPTION,@SCHEMA@.AUDIT_LOG_T.CORR_SET_INFO,@SCHEMA@.AUDIT_LOG_T.USER_NAME, @SCHEMA@.AUDIT_LOG_T.ADDITIONAL_INFO
 FROM @SCHEMA@.AUDIT_LOG_T
 WHERE @SCHEMA@.AUDIT_LOG_T.OBJECT_META_TYPE = 1
go

-- View: ApplicationComp
CREATE VIEW @SCHEMA@.APPLICATION_COMP(ACOID, BUSINESS_RELEVANCE, NAME, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON ) AS
 SELECT @SCHEMA@.APPLICATION_COMPONENT_T.ACOID, @SCHEMA@.APPLICATION_COMPONENT_T.BUSINESS_RELEVANCE, @SCHEMA@.APPLICATION_COMPONENT_T.NAME, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_DELEGATION, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_SUB_TASK, @SCHEMA@.APPLICATION_COMPONENT_T.SUPPORTS_FOLLOW_ON_TASK
 FROM @SCHEMA@.APPLICATION_COMPONENT_T
go

-- View: Task
CREATE VIEW @SCHEMA@.TASK(TKIID, ACTIVATED, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, COMPLETED, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DUE, EXPIRES, FIRST_ACTIVATED, FOLLOW_ON_TKIID, IS_AD_HOC, IS_ESCALATED, IS_INLINE, IS_WAIT_FOR_SUB_TK, KIND, LAST_MODIFIED, LAST_STATE_CHANGE, NAME, NAME_SPACE, ORIGINATOR, OWNER, PARENT_CONTEXT_ID, PRIORITY, STARTED, STARTER, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, HIERARCHY_POSITION, IS_CHILD, SUSPENDED, TKTID, TOP_TKIID, TYPE, RESUMES, ASSIGNMENT_TYPE, INHERITED_AUTH, INVOKED_INSTANCE_ID, INVOKED_INSTANCE_TYPE, WORK_BASKET, IS_READ, IS_TRANSFERRED_TO_WORK_BASKET, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INSTANCE_T.TKIID, @SCHEMA@.TASK_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_INSTANCE_T.APPLICATION_NAME, @SCHEMA@.TASK_INSTANCE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_INSTANCE_T.COMPLETION_TIME, @SCHEMA@.TASK_INSTANCE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_INSTANCE_T.DUE_TIME, @SCHEMA@.TASK_INSTANCE_T.EXPIRATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FIRST_ACTIVATION_TIME, @SCHEMA@.TASK_INSTANCE_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_INSTANCE_T.IS_AD_HOC, @SCHEMA@.TASK_INSTANCE_T.IS_ESCALATED, @SCHEMA@.TASK_INSTANCE_T.IS_INLINE, @SCHEMA@.TASK_INSTANCE_T.IS_WAITING_FOR_SUBTASK, @SCHEMA@.TASK_INSTANCE_T.KIND, @SCHEMA@.TASK_INSTANCE_T.LAST_MODIFICATION_TIME, @SCHEMA@.TASK_INSTANCE_T.LAST_STATE_CHANGE_TIME, @SCHEMA@.TASK_INSTANCE_T.NAME, @SCHEMA@.TASK_INSTANCE_T.NAMESPACE, @SCHEMA@.TASK_INSTANCE_T.ORIGINATOR, @SCHEMA@.TASK_INSTANCE_T.OWNER, @SCHEMA@.TASK_INSTANCE_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_INSTANCE_T.PRIORITY, @SCHEMA@.TASK_INSTANCE_T.START_TIME, @SCHEMA@.TASK_INSTANCE_T.STARTER, @SCHEMA@.TASK_INSTANCE_T.STATE, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_INSTANCE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_INSTANCE_T.HIERARCHY_POSITION, @SCHEMA@.TASK_INSTANCE_T.IS_CHILD, @SCHEMA@.TASK_INSTANCE_T.IS_SUSPENDED, @SCHEMA@.TASK_INSTANCE_T.TKTID, @SCHEMA@.TASK_INSTANCE_T.TOP_TKIID, @SCHEMA@.TASK_INSTANCE_T.TYPE, @SCHEMA@.TASK_INSTANCE_T.RESUMES, @SCHEMA@.TASK_INSTANCE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_INSTANCE_T.INHERITED_AUTH, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_ID, @SCHEMA@.TASK_INSTANCE_T.INVOKED_INSTANCE_TYPE, @SCHEMA@.TASK_INSTANCE_T.WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.IS_READ, @SCHEMA@.TASK_INSTANCE_T.IS_TRANSFERRED_TO_WORK_BASKET, @SCHEMA@.TASK_INSTANCE_T.WSID_1, @SCHEMA@.TASK_INSTANCE_T.WSID_2
 FROM @SCHEMA@.TASK_INSTANCE_T
go

-- View: TaskTempl
CREATE VIEW @SCHEMA@.TASK_TEMPL(TKTID, APPLIC_DEFAULTS_ID, APPLIC_NAME, BUSINESS_RELEVANCE, CONTAINMENT_CTX_ID, CTX_AUTHORIZATION, DEFINITION_NAME, DEFINITION_NS, IS_AD_HOC, IS_INLINE, KIND, NAME, NAMESPACE, PRIORITY, STATE, SUPPORT_AUTOCLAIM, SUPPORT_CLAIM_SUSP, SUPPORT_DELEGATION, SUPPORT_SUB_TASK, SUPPORT_FOLLOW_ON, TYPE, VALID_FROM, AUTONOMY, ASSIGNMENT_TYPE, INHERITED_AUTH, WORK_BASKET ) AS
 SELECT @SCHEMA@.TASK_TEMPLATE_T.TKTID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_DEFAULTS_ID, @SCHEMA@.TASK_TEMPLATE_T.APPLICATION_NAME, @SCHEMA@.TASK_TEMPLATE_T.BUSINESS_RELEVANCE, @SCHEMA@.TASK_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_TEMPLATE_T.CONTEXT_AUTHORIZATION, @SCHEMA@.TASK_TEMPLATE_T.DEFINITION_NAME, @SCHEMA@.TASK_TEMPLATE_T.TARGET_NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.IS_AD_HOC, @SCHEMA@.TASK_TEMPLATE_T.IS_INLINE, @SCHEMA@.TASK_TEMPLATE_T.KIND, @SCHEMA@.TASK_TEMPLATE_T.NAME, @SCHEMA@.TASK_TEMPLATE_T.NAMESPACE, @SCHEMA@.TASK_TEMPLATE_T.PRIORITY, @SCHEMA@.TASK_TEMPLATE_T.STATE, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_AUTO_CLAIM, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_CLAIM_SUSPENDED, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_DELEGATION, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_SUB_TASK, @SCHEMA@.TASK_TEMPLATE_T.SUPPORTS_FOLLOW_ON_TASK, @SCHEMA@.TASK_TEMPLATE_T.TYPE, @SCHEMA@.TASK_TEMPLATE_T.VALID_FROM, @SCHEMA@.TASK_TEMPLATE_T.AUTONOMY, @SCHEMA@.TASK_TEMPLATE_T.ASSIGNMENT_TYPE, @SCHEMA@.TASK_TEMPLATE_T.INHERITED_AUTH, @SCHEMA@.TASK_TEMPLATE_T.WORK_BASKET
 FROM @SCHEMA@.TASK_TEMPLATE_T
go

-- View: Escalation
CREATE VIEW @SCHEMA@.ESCALATION(ESIID, ACTION, ACTIVATION_STATE, ACTIVATION_TIME, ESCALATION_TIME, AT_LEAST_EXP_STATE, ESTID, FIRST_ESIID, INCREASE_PRIORITY, NAME, STATE, TKIID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESCALATION_INSTANCE_T.ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.ACTION, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ACTIVATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.ESCALATION_TIME, @SCHEMA@.ESCALATION_INSTANCE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_INSTANCE_T.ESTID, @SCHEMA@.ESCALATION_INSTANCE_T.FIRST_ESIID, @SCHEMA@.ESCALATION_INSTANCE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_INSTANCE_T.NAME, @SCHEMA@.ESCALATION_INSTANCE_T.STATE, @SCHEMA@.ESCALATION_INSTANCE_T.TKIID, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_1, @SCHEMA@.ESCALATION_INSTANCE_T.WSID_2
 FROM @SCHEMA@.ESCALATION_INSTANCE_T
go

-- View: EscTempl
CREATE VIEW @SCHEMA@.ESC_TEMPL(ESTID, FIRST_ESTID, PREVIOUS_ESTID, TKTID, CONTAINMENT_CTX_ID, NAME, ACTIVATION_STATE, AT_LEAST_EXP_STATE, INCREASE_PRIORITY, ACTION ) AS
 SELECT @SCHEMA@.ESCALATION_TEMPLATE_T.ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.FIRST_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.PREVIOUS_ESTID, @SCHEMA@.ESCALATION_TEMPLATE_T.TKTID, @SCHEMA@.ESCALATION_TEMPLATE_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.ESCALATION_TEMPLATE_T.NAME, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTIVATION_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.AT_LEAST_EXPECTED_STATE, @SCHEMA@.ESCALATION_TEMPLATE_T.INCREASE_PRIORITY, @SCHEMA@.ESCALATION_TEMPLATE_T.ACTION
 FROM @SCHEMA@.ESCALATION_TEMPLATE_T
go

-- View: EscTemplDesc
CREATE VIEW @SCHEMA@.ESC_TEMPL_DESC(ESTID, LOCALE, TKTID, DISPLAY_NAME, DESCRIPTION ) AS
 SELECT @SCHEMA@.ESC_TEMPL_LDESC_T.ESTID, @SCHEMA@.ESC_TEMPL_LDESC_T.LOCALE, @SCHEMA@.ESC_TEMPL_LDESC_T.TKTID, @SCHEMA@.ESC_TEMPL_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_TEMPL_LDESC_T.DESCRIPTION
 FROM @SCHEMA@.ESC_TEMPL_LDESC_T
go

-- View: TaskTemplCProp
CREATE VIEW @SCHEMA@.TASK_TEMPL_CPROP(TKTID, NAME, DATA_TYPE, STRING_VALUE ) AS
 SELECT @SCHEMA@.TASK_TEMPL_CPROP_T.TKTID, @SCHEMA@.TASK_TEMPL_CPROP_T.NAME, @SCHEMA@.TASK_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.TASK_TEMPL_CPROP_T
go

-- View: EscTemplCProp
CREATE VIEW @SCHEMA@.ESC_TEMPL_CPROP(ESTID, NAME, TKTID, DATA_TYPE, VALUE ) AS
 SELECT @SCHEMA@.ESC_TEMPL_CPROP_T.ESTID, @SCHEMA@.ESC_TEMPL_CPROP_T.NAME, @SCHEMA@.ESC_TEMPL_CPROP_T.TKTID, @SCHEMA@.ESC_TEMPL_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_TEMPL_CPROP_T.STRING_VALUE
 FROM @SCHEMA@.ESC_TEMPL_CPROP_T
go

-- View: TaskTemplDesc
CREATE VIEW @SCHEMA@.TASK_TEMPL_DESC(TKTID, LOCALE, DESCRIPTION, DISPLAY_NAME ) AS
 SELECT @SCHEMA@.TASK_TEMPL_LDESC_T.TKTID, @SCHEMA@.TASK_TEMPL_LDESC_T.LOCALE, @SCHEMA@.TASK_TEMPL_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_TEMPL_LDESC_T.DISPLAY_NAME
 FROM @SCHEMA@.TASK_TEMPL_LDESC_T
go

-- View: TaskCProp
CREATE VIEW @SCHEMA@.TASK_CPROP(TKIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_CPROP_T.TKIID, @SCHEMA@.TASK_INST_CPROP_T.NAME, @SCHEMA@.TASK_INST_CPROP_T.DATA_TYPE, @SCHEMA@.TASK_INST_CPROP_T.STRING_VALUE, @SCHEMA@.TASK_INST_CPROP_T.WSID_1, @SCHEMA@.TASK_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.TASK_INST_CPROP_T
go

-- View: TaskDesc
CREATE VIEW @SCHEMA@.TASK_DESC(TKIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_INST_LDESC_T.TKIID, @SCHEMA@.TASK_INST_LDESC_T.LOCALE, @SCHEMA@.TASK_INST_LDESC_T.DESCRIPTION, @SCHEMA@.TASK_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.TASK_INST_LDESC_T.WSID_1, @SCHEMA@.TASK_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.TASK_INST_LDESC_T
go

-- View: EscalationCProp
CREATE VIEW @SCHEMA@.ESCALATION_CPROP(ESIID, NAME, DATA_TYPE, STRING_VALUE, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_CPROP_T.ESIID, @SCHEMA@.ESC_INST_CPROP_T.NAME, @SCHEMA@.ESC_INST_CPROP_T.DATA_TYPE, @SCHEMA@.ESC_INST_CPROP_T.STRING_VALUE, @SCHEMA@.ESC_INST_CPROP_T.WSID_1, @SCHEMA@.ESC_INST_CPROP_T.WSID_2
 FROM @SCHEMA@.ESC_INST_CPROP_T
go

-- View: TaskHistory
CREATE VIEW @SCHEMA@.TASK_HISTORY(TKIID, ESIID, PARENT_TKIID, EVENT, REASON, EVENT_TIME, NEXT_TIME, PRINCIPAL, WORK_ITEM_KIND, FROM_ID, TO_ID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.TASK_HISTORY_T.TKIID, @SCHEMA@.TASK_HISTORY_T.ESIID, @SCHEMA@.TASK_HISTORY_T.PARENT_TKIID, @SCHEMA@.TASK_HISTORY_T.EVENT, @SCHEMA@.TASK_HISTORY_T.REASON, @SCHEMA@.TASK_HISTORY_T.EVENT_TIME, @SCHEMA@.TASK_HISTORY_T.NEXT_TIME, @SCHEMA@.TASK_HISTORY_T.PRINCIPAL, @SCHEMA@.TASK_HISTORY_T.WORK_ITEM_KIND, @SCHEMA@.TASK_HISTORY_T.FROM_ID, @SCHEMA@.TASK_HISTORY_T.TO_ID, @SCHEMA@.TASK_HISTORY_T.WSID_1, @SCHEMA@.TASK_HISTORY_T.WSID_2
 FROM @SCHEMA@.TASK_HISTORY_T
go

-- View: EscalationDesc
CREATE VIEW @SCHEMA@.ESCALATION_DESC(ESIID, LOCALE, DESCRIPTION, DISPLAY_NAME, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.ESC_INST_LDESC_T.ESIID, @SCHEMA@.ESC_INST_LDESC_T.LOCALE, @SCHEMA@.ESC_INST_LDESC_T.DESCRIPTION, @SCHEMA@.ESC_INST_LDESC_T.DISPLAY_NAME, @SCHEMA@.ESC_INST_LDESC_T.WSID_1, @SCHEMA@.ESC_INST_LDESC_T.WSID_2
 FROM @SCHEMA@.ESC_INST_LDESC_T
go

-- View: TaskAuditLog
CREATE VIEW @SCHEMA@.TASK_AUDIT_LOG(ALID, AUDIT_EVENT, CONTAINMENT_CTX_ID, ESIID, ESTID, EVENT_TIME, FAULT_NAME, FAULT_TYPE_NAME, FAULT_NAME_SPACE, FOLLOW_ON_TKIID, NAME, NAMESPACE, NEW_USER, OLD_USER, PARENT_CONTEXT_ID, PARENT_TASK_NAME, PARENT_TASK_NAMESP, PARENT_TKIID, PRINCIPAL, TASK_KIND, TASK_STATE, TKIID, TKTID, TOP_TKIID, VAILD_FROM, WORK_ITEM_REASON, USERS, DESCRIPTION, MESSAGE_DATA ) AS
 SELECT @SCHEMA@.TASK_AUDIT_LOG_T.ALID, @SCHEMA@.TASK_AUDIT_LOG_T.AUDIT_EVENT, @SCHEMA@.TASK_AUDIT_LOG_T.CONTAINMENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.ESIID, @SCHEMA@.TASK_AUDIT_LOG_T.ESTID, @SCHEMA@.TASK_AUDIT_LOG_T.EVENT_TIME_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_TYPE_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.FAULT_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.FOLLOW_ON_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.NAME, @SCHEMA@.TASK_AUDIT_LOG_T.NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.NEW_USER, @SCHEMA@.TASK_AUDIT_LOG_T.OLD_USER, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_CONTEXT_ID, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAME, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TASK_NAMESPACE, @SCHEMA@.TASK_AUDIT_LOG_T.PARENT_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.PRINCIPAL, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_KIND, @SCHEMA@.TASK_AUDIT_LOG_T.TASK_STATE, @SCHEMA@.TASK_AUDIT_LOG_T.TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.TKTID, @SCHEMA@.TASK_AUDIT_LOG_T.TOP_TKIID, @SCHEMA@.TASK_AUDIT_LOG_T.VALID_FROM_UTC, @SCHEMA@.TASK_AUDIT_LOG_T.WI_REASON, @SCHEMA@.TASK_AUDIT_LOG_T.USERS, @SCHEMA@.TASK_AUDIT_LOG_T.DESCRIPTION, @SCHEMA@.TASK_AUDIT_LOG_T.MESSAGE_DATA
 FROM @SCHEMA@.TASK_AUDIT_LOG_T
go

-- View: WorkBasket
CREATE VIEW @SCHEMA@.WORK_BASKET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_T.WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_T
go

-- View: WorkBasketLDesc
CREATE VIEW @SCHEMA@.WORK_BASKET_LDESC(WBID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_LDESC_T.WBID, @SCHEMA@.WORK_BASKET_LDESC_T.LOCALE, @SCHEMA@.WORK_BASKET_LDESC_T.DISPLAY_NAME, @SCHEMA@.WORK_BASKET_LDESC_T.DESCRIPTION, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_1, @SCHEMA@.WORK_BASKET_LDESC_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_LDESC_T
go

-- View: WorkBasketDistTarget
CREATE VIEW @SCHEMA@.WORK_BASKET_DIST_TARGET(WBID, NAME, TYPE, OWNER, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, SOURCE_WBID, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID, @SCHEMA@.WORK_BASKET_T.NAME, @SCHEMA@.WORK_BASKET_T.TYPE, @SCHEMA@.WORK_BASKET_T.OWNER, @SCHEMA@.WORK_BASKET_T.DEFAULT_QUERY_TABLE, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT1, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT2, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT3, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT4, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT5, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT6, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT7, @SCHEMA@.WORK_BASKET_T.CUSTOM_TEXT8, @SCHEMA@.WORK_BASKET_T.CREATION_TIME, @SCHEMA@.WORK_BASKET_T.LAST_MODIFICATION_TIME, @SCHEMA@.WORK_BASKET_DIST_TARGET_T.SOURCE_WBID, @SCHEMA@.WORK_BASKET_T.WSID_1, @SCHEMA@.WORK_BASKET_T.WSID_2
 FROM @SCHEMA@.WORK_BASKET_DIST_TARGET_T, @SCHEMA@.WORK_BASKET_T
 WHERE @SCHEMA@.WORK_BASKET_T.WBID = @SCHEMA@.WORK_BASKET_DIST_TARGET_T.TARGET_WBID
go

-- View: BusinessCategory
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY(BCID, PARENT_BCID, NAME, PRIORITY, DEFAULT_QUERY_TABLE, CUSTOM_TEXT1, CUSTOM_TEXT2, CUSTOM_TEXT3, CUSTOM_TEXT4, CUSTOM_TEXT5, CUSTOM_TEXT6, CUSTOM_TEXT7, CUSTOM_TEXT8, CREATED, LAST_MODIFIED, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_T.PARENT_BCID, @SCHEMA@.BUSINESS_CATEGORY_T.NAME, @SCHEMA@.BUSINESS_CATEGORY_T.PRIORITY, @SCHEMA@.BUSINESS_CATEGORY_T.DEFAULT_QUERY_TABLE, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT1, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT2, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT3, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT4, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT5, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT6, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT7, @SCHEMA@.BUSINESS_CATEGORY_T.CUSTOM_TEXT8, @SCHEMA@.BUSINESS_CATEGORY_T.CREATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.LAST_MODIFICATION_TIME, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_T
go

-- View: BusinessCategoryLDesc
CREATE VIEW @SCHEMA@.BUSINESS_CATEGORY_LDESC(BCID, LOCALE, DISPLAY_NAME, DESCRIPTION, WSID_1, WSID_2 ) AS
 SELECT @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.BCID, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.LOCALE, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DISPLAY_NAME, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.DESCRIPTION, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_1, @SCHEMA@.BUSINESS_CATEGORY_LDESC_T.WSID_2
 FROM @SCHEMA@.BUSINESS_CATEGORY_LDESC_T
go

-- update schema version to: 700
-- (a warning for the following statement can be ignored)
DELETE FROM @SCHEMA@.SCHEMA_VERSION WHERE SCHEMA_VERSION = 700;
go
INSERT INTO @SCHEMA@.SCHEMA_VERSION (SCHEMA_VERSION, DATA_MIGRATION) VALUES( 700, 1 )
go

