#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2006, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os.path, sys

from java.lang import System

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "cleanupUnusedStaffQueryInstances.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f cleanupUnusedStaffQueryInstances.py "
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print
  print "Cleanup unused staff query instances in the Process Choreographer database."
  print "Apply changes on server <serverName> on node <nodeName> or of cluster <clusterName>. "
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif


argerr = ""
clusterName = None
nodeName = localNode
serverName = None

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
      argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1  #forNext
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage(str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget():
  usage("Process Choreographer is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

htmMBean = scope.lookupMBean("TaskManager")

if not htmMBean:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  print "Cleanup unused staff query instances ..."
  sqiCount = AdminControl.invoke(htmMBean, "cleanupUnusedStaffQueryInstances")
  print sqiCount + " staff query instance(s) deleted."
#endif
