#
# Licensed Materials - Property of IBM
# 5655-FLW (C) Copyright IBM Corporation 2008, 2010. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#

import os, re

from java.lang import String, System
from com.ibm.wsspi.scripting import ScriptingExtensionHelper

__file__ = "bpclib.py"

#*******************************************************************************************************
# See http://www-01.ibm.com/support/docview.wss?rs=180&uid=swg21305344 for NLS considerations.
#*******************************************************************************************************

#*******************************************************************************************************
# class Scope
#*******************************************************************************************************
class Scope:

  def __init__(self):
    self.cellName = None
    self.clusterName = None
    self.currentNode = None
    self.nodeName = None
    self.serverName = None
  #enddef

  def __init__(self, **args):
    wsadmin = WsAdmin()
    if args.has_key("cellName") and args["cellName"]:
      self.cellName = args["cellName"]
    elif wsadmin.getConnectionStatus() == WsAdmin.CONNECTED:
      self.cellName = AdminControl.getCell()
    else:
      self.cellName = System.getProperty("local.cell")
    #endif
    if args.has_key("nodeName") and args["nodeName"]:
      self.currentNode = args["nodeName"]
    elif wsadmin.getConnectionStatus() == WsAdmin.CONNECTED:
      self.currentNode = AdminControl.getNode()
    else:
      self.currentNode = System.getProperty("local.node")
    #endif
    if args.has_key("clusterName") and args["clusterName"]:
      self.clusterName = args["clusterName"]
      self.nodeName = None
      self.serverName = None
    else:
      self.clusterName = None
      self.nodeName = self.currentNode
      if args.has_key("serverName") and args["serverName"]:
        self.serverName = args["serverName"]
      else:
        self.serverName = None
      #endif
    #endif
  #enddef

  def __str__(self):
    return self.getContainmentPath()
  #enddef

  def getContainmentPath(self):
    path = "/Cell:" + self.cellName
    if self.clusterName:
      path = path + "/ServerCluster:" + self.clusterName
    else:
      if self.nodeName:
        path = path + "/Node:" + self.nodeName
        if self.serverName:
          path = path + "/Server:" + self.serverName
      #endif
    #endif
    return path + "/"
  #enddef

  def getCell(self):
    if self.cellName:
      return "/Cell:" + self.cellName + "/"
    return None
  #endif

  def getNode(self):
    cell = self.getCell()
    if cell and self.nodeName:
      return cell + "Node:" + self.nodeName + "/"
    return None
  #endif

  def getServer(self):
    node = self.getNode()
    if node and self.serverName:
      return node + "Server:" + self.serverName + "/"
    return None
  #endif

  def getCluster(self):
    cell = self.getCell()
    if cell and self.clusterName:
      return cell + "ServerCluster:" + self.clusterName + "/"
    return None
  #endif

  def convertToCluster(self):
    if self.getServer():
      server = self.getConfigID()
      if server:
        self.clusterName = AdminConfig.showAttribute(server, "clusterName")
        return self.getCluster()
      #endif
    #endif
    return 0
  #enddef

  def getConfigID(self):
    return AdminConfig.getid(self.getContainmentPath())
  #enddef

  def asParameterList(self, additionalParms = [], includeClusterNode = 0):
    parms = []
    if self.clusterName:
      parms.append("-clusterName")
      parms.append(self.clusterName)
      if includeClusterNode:
        parms.append("-nodeName")
        parms.append(self.currentNode)
    else:
      if self.nodeName:
        parms.append("-nodeName")
        parms.append(self.nodeName)
        if self.serverName:
          parms.append("-serverName")
          parms.append(self.serverName)
      #endif
    #endif
    if additionalParms:
      parms.extend(additionalParms)
    return parms
  #enddef

  def list(self, type):
    id = self.getConfigID()
    if id:
      return AdminConfig.list(type, id)
    return None
  #enddef

  def listApplications(self, pattern):
    scope = "WebSphere:" + self.getContainmentPath()[:-1].replace("/Cell:", "cell=").\
            replace("/ServerCluster:", ",cluster=").replace("/Node:", ",node=").replace("/Server:", ",server=")
    pattern = re.compile(pattern)
    appNames = []
    for appName in wsadminToList(AdminApp.list(scope)):
      if pattern.match(appName):
        appNames.append(appName)
    return appNames
  #enddef

  def isDeploymentTarget(self):
    return (self.getServer() or self.getCluster()) and self.getConfigID()
  #enddef

  def isBPCDeploymentTarget(self):
    if not self.isDeploymentTarget():
      return 0
    # AdminTask returns 'server1(cells/viennaNode01Cell/nodes/viennaNode01/servers/server1|server.xml)'
    # but getConfigID() returns 'server1(cells/viennaNode01Cell/nodes/viennaNode01/servers/server1|server.xml#Server_1183122130078)'
    id = String(self.getConfigID()).replaceFirst("#[^)]+", "")
    return id in wsadminToList(AdminTask.listBPCContainerDeploymentTargets())
  #enddef

  def isBPCEventCollectorDeploymentTarget(self):
    if not self.isDeploymentTarget():
      return 0
    # AdminTask returns 'server1(cells/viennaNode01Cell/nodes/viennaNode01/servers/server1|server.xml)'
    # but getConfigID() returns 'server1(cells/viennaNode01Cell/nodes/viennaNode01/servers/server1|server.xml#Server_1183122130078)'
    id = String(self.getConfigID()).replaceFirst("#[^)]+", "")
    return id in wsadminToList(AdminTask.listBPCEventCollectorDeploymentTargets())
  #enddef

  def lookup(self, lookupScope, attribute):
    if not attribute or attribute == "":
      return None
    #endif
    object = None
    if not object and self.getServer():
      object = lookupScope(attribute, self.getServer())
    #endif
    if not object and self.getNode():
      object = lookupScope(attribute, self.getNode())
    #endif
    if not object and self.getCluster():
      for member in wsadminToList(self.list("ClusterMember")):
        if AdminConfig.showAttribute(member, "nodeName") == self.currentNode:
          nodeScope = Scope(cellName = self.cellName, nodeName = self.currentNode)
          object = lookupScope(attribute, nodeScope.getContainmentPath())
        #endif
      #endfor
      if not object:
        object = lookupScope(attribute, self.getCluster())
      #endif
    #endif
    if not object:
      object = lookupScope(attribute, self.getCell())
    #endif
    return object
  #enddef

  def displayName(self):
    if self.getServer():
      return "server " + self.serverName + " on node " + self.nodeName
    elif self.getCluster():
      return "cluster " + self.clusterName
    elif self.getNode():
      return "node " + self.nodeName
    #endif
    return None
  #enddef

  def lookupMBean(self, type, all = 0):
    mbeans = []
    if self.getServer():
      mbean = AdminControl.completeObjectName("type=" + type + ",node=" + self.nodeName + ",process=" + self.serverName + ",*")
      if mbean:
        mbeans.append(mbean)
    elif self.getCluster():
      cluster = self.getConfigID()
      for member in wsadminToList(self.list("ClusterMember")):
        nodeName = AdminConfig.showAttribute(member, "nodeName")
        serverName = AdminConfig.showAttribute(member, "memberName")
        mbean = AdminControl.completeObjectName("type=" + type + ",node=" + nodeName + ",process=" + serverName + ",*")
        if mbean:
          mbeans.append(mbean)
          if not all:
            break
        #endif
      #endfor
    #endif
    if mbeans and not all:
      return mbeans[0]
    return mbeans
  #enddef

#endclass

#*******************************************************************************************************
# class WsAdmin
#*******************************************************************************************************
class WsAdmin:

  __connectionStatus = "UNKNOWN"

  CONNECTED = "CONNECTED"
  DISCONNECTED = "DISCONNECTED"
  ERROR = "ERROR"

  def getConnectionStatus (self):
    if WsAdmin.__connectionStatus != "UNKNOWN":
      return WsAdmin.__connectionStatus
    if not ScriptingExtensionHelper.getCurrentScriptingConfigService():
      WsAdmin.__connectionStatus = WsAdmin.ERROR
    elif not ScriptingExtensionHelper.getCurrentScriptingAdminClient():
      WsAdmin.__connectionStatus = WsAdmin.DISCONNECTED
    else:
      WsAdmin.__connectionStatus = WsAdmin.CONNECTED
    #endif
    return WsAdmin.__connectionStatus
  #enddef

  def parse(self, argv, props):
    lastArg = None
    for arg in argv:
      if arg.startswith("-"):
        lastArg = arg[1:]
      else:
        if not lastArg:
          raise StandardError, "No argument for value '" + arg + "'"
        else:
          props[lastArg] = arg
          lastArg = None
        #endif
      #endif
    #endfor
    if lastArg:
      raise StandardError, "No value for argument '-" + lastArg + "'"
    return props
  #enddef

#endclass

#*******************************************************************************************************
# global scripting client
#*******************************************************************************************************
wsadmin = WsAdmin()

#*******************************************************************************************************
# find a DataSource exactly in a give scope
#*******************************************************************************************************
def findDataSource(jndiName, scopePath):
  scope = AdminConfig.getid(scopePath)
  if not scope:
    return None
  for dataSource in AdminConfig.list("DataSource", scope).splitlines():
    if (jndiName == AdminConfig.showAttribute(dataSource, "jndiName")):
      # candidate, but may be in a sub-scope. construct id in desired scope to make sure.
      provider = AdminConfig.showAttribute(dataSource, "provider")
      providerName = AdminConfig.showAttribute(provider, "name")
      # Robustness: apparently, there may be multiple JDBC providers with the same name. In this case
      # the originally used 'AdminConfig.getid(scopePath + "JDBCProvider:" + providerName + "/DataSource:" + dataSourceName + "/")'
      # will return an invalid config id that causes problems upstream.
      for provider in AdminConfig.getid(scopePath + "JDBCProvider:" + providerName + "/").splitlines():
        for dataSource2 in AdminConfig.list("DataSource", provider).splitlines():
          if dataSource == dataSource2:
            break
        #endfor
      #endfor
      if dataSource:
        return dataSource
      #endif
    #endif
  #endfor
  return None
#enddef

#*******************************************************************************************************
# @EF rework: convert a string as returned by AdminConfig.show[Attribute] to a Jython list
#*******************************************************************************************************
def wsadminToList(inStr):
  outList=[]
  if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
    inStr = inStr[1:-1]
    tmpList = inStr.split(" ")
  else:
    tmpList = inStr.split("\n")  #splits for Windows or Linux
  for item in tmpList:
    item = item.rstrip();        #removes any Windows "\r"
    if (len(item)>0):
      outList.append(item)
  return outList
#endDef

#*******************************************************************************************************
# make sure a given time stamp is UTC and contains minutes, hours, and seconds
#*******************************************************************************************************
def normalizeTimeStamp(timeStamp, convertToUTC, mayOmitTime):

  from java.lang import String
  from java.text import SimpleDateFormat
  from java.util import TimeZone

  timeStamp = String(timeStamp)

  if timeStamp.matches("[-:0-9]+T\d{2}:\d{2}"):
    timeStamp = String(timeStamp.concat(":00"))

  try:
    if mayOmitTime and timeStamp.length() < 16:
      s = SimpleDateFormat("yyyy-MM-dd")
    else:
      s = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss")
    s.setLenient(0)
    utc = SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss")
    if convertToUTC:
      utc.setTimeZone(TimeZone.getTimeZone("UTC"))
    timeStamp = utc.format(s.parse(timeStamp))
  except:
    timeStamp = None

  return timeStamp
#enddef
